@@ -4,7 +4,7 @@
  * This file is part of Enfle.
  *
  * Last Modified: Tue Feb 26 05:21:44 2002.
- * $Id: pe_image.c,v 1.1 2003/08/01 13:41:06 makeinu Exp $
+ * $Id: pe_image.c,v 1.2 2004/03/07 12:24:17 makeinu Exp $
  *
  * Enfle is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif /* HAVE_CONFIG_H */
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -37,7 +41,10 @@
 #ifdef __linux__
 # include <asm/ldt.h>
 # include <asm/unistd.h>
-#elif defined(__FreeBSD__)
+# ifdef HAVE_STRUCT_USER_DESC
+#  define modify_ldt_ldt_s user_desc
+# endif
+#elif defined(HAVE_I386_SET_LDT)
 # include <machine/segments.h>
 # include <machine/sysarch.h>
 #else
