@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: tar-ext.c,v 1.14 2003/06/18 09:26:53 makeinu Exp $
+ *  $Id: tar-ext.c,v 1.16 2004/12/20 14:06:51 makeinu Exp $
  */
 
 #include <sys/types.h>
@@ -608,6 +608,71 @@ fr_command_tar_delete (FRCommand *comm,
 }
 
 
+static gchar *
+escape_path (const gchar *path)
+{
+   guint len, i, j = 0;
+   gchar *newpath;
+
+   g_return_val_if_fail (path, NULL);
+
+   len = strlen (path);
+
+   for (i = 0; path[i]; i++) {
+      switch (path[i]) {
+      case '[':
+      case '*':
+      case '?':
+      case '"':
+      case '\'':
+         len += 2;
+         break;
+      default:
+         break;
+      }
+   }
+
+   newpath = g_malloc(len + 1);
+
+   for (i = 0; path[i]; i++) {
+      switch (path[i]) {
+      case '[':
+         newpath[j] = '['; j++;
+         newpath[j] = '['; j++;
+         newpath[j] = ']'; j++;
+         break;
+      case '*':
+         newpath[j] = '['; j++;
+         newpath[j] = '*'; j++;
+         newpath[j] = ']'; j++;
+         break;
+      case '?':
+         newpath[j] = '['; j++;
+         newpath[j] = '?'; j++;
+         newpath[j] = ']'; j++;
+         break;
+      case '"':
+         newpath[j] = '['; j++;
+         newpath[j] = '"'; j++;
+         newpath[j] = ']'; j++;
+         break;
+      case '\'':
+         newpath[j] = '['; j++;
+         newpath[j] = '\''; j++;
+         newpath[j] = ']'; j++;
+         break;
+      default:
+         newpath[j] = path[i]; j++;
+         break;
+      }
+   }
+
+   newpath[len] = '\0';
+
+   return newpath;
+}
+
+
 static void
 fr_command_tar_extract (FRCommand *comm,
                         GList *file_list,
@@ -634,8 +699,14 @@ fr_command_tar_extract (FRCommand *comm,
      fr_process_add_arg (comm->process, "-k");
    */
 
-   for (scan = file_list; scan; scan = scan->next)
-      fr_process_add_arg (comm->process, scan->data);
+   for (scan = file_list; scan; scan = scan->next) {
+      gchar *escaped = escape_path(scan->data);
+
+      if (escaped) {
+         fr_process_add_arg (comm->process, escaped);
+         g_free(escaped);
+      }
+   }
 
    fr_process_end_command (comm->process);
 }
