@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bmp.c,v 1.8 2003/06/14 03:39:49 makeinu Exp $
+ * $Id: bmp.c,v 1.9 2004/09/21 08:44:27 makeinu Exp $
  */
 
 /*
@@ -337,7 +337,7 @@ bmp_read_color_map (GimvIO *gio,
    for (i = 0; i < number ; i++) {
       status = gimv_io_read (gio, rgb, size, &bytes_read);
       if (status != GIMV_IO_STATUS_NORMAL) return FALSE;
-      if (bytes_read != size) return FALSE;
+      if (bytes_read != (guint) size) return FALSE;
 
       if (size == 4) {      
          buffer[i][0] = rgb[2];
