@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: imlib_loader.h,v 1.3.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: imlib_loader.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __IMLIB_LOADER_H__
@@ -32,11 +32,11 @@
 
 #include <glib.h>
 #include <gdk_imlib.h>
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 #include "gimv_image.h"
 
-GimvImage *gimv_imlib_load_file (ImageLoader *loader,
-                                 gpointer     data);
+GimvImage *gimv_imlib_load_file (GimvImageLoader *loader,
+                                 gpointer         data);
 
 #endif /* HAVE_GDK_IMLIB */
 
