@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mag.c,v 1.8 2003/06/14 03:39:50 makeinu Exp $
+ * $Id: mag.c,v 1.9 2004/09/21 08:44:27 makeinu Exp $
  */
 
 /*
@@ -105,7 +105,7 @@ mag_load (GimvImageLoader *loader, gpointer data)
    GimvImage *image = NULL;
    mag_info minfo;
    guchar buffer[32], comment[BUF_SIZE], colormap[256][3], *dest;
-   gint i;
+   guint i;
    guint bytes_read;
    GimvIOStatus status;
 
@@ -197,7 +197,8 @@ mag_decode_image (GimvImageLoader *loader, mag_info *minfo, guchar colormap[256]
 {
    GimvIO *gio;
    guint bytes_read;
-   gint i, j, k, pr, f, t, sa, width, height;
+   guint i, j, k, sa;
+   gint pr, f, t, width, height;
    guchar *flaga, *flagb, *fa, *fb, *pix, *d, *dest, *src;
    guchar bitmask[] = {
       128, 64, 32, 16, 8, 4, 2, 1
