@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mng.h,v 1.3.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: mng.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __MNG_H__
@@ -31,10 +31,10 @@
 #ifdef ENABLE_MNG
 
 #include "gimv_anim.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *mng_load (ImageLoader *loader,
-                     gpointer     data);
+GimvImage *mng_load (GimvImageLoader *loader,
+                     gpointer         data);
 
 #endif
 
