@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: pcx.h,v 1.3.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: pcx.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __PCX_H__
@@ -26,7 +26,7 @@
 
 #include <gtk/gtk.h>
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
 typedef struct
 {
@@ -35,9 +35,10 @@ typedef struct
    gint ncolors;
 } pcx_info;
 
-gboolean   pcx_get_header (GimvIO *gio, pcx_info *info);
-GimvImage *pcx_load       (ImageLoader *loader,
-                           gpointer     data);
+gboolean   pcx_get_header (GimvIO          *gio,
+                           pcx_info        *info);
+GimvImage *pcx_load       (GimvImageLoader *loader,
+                           gpointer         data);
 
 #endif /* __PCX_H__ */
 
