@@ -260,7 +260,7 @@ GimvPluginInfo gimv_plugin_info =
 };
 
 
-void
+static void
 cb_area_prepared (GdkPixbufLoader *loader,
                   gboolean *ret)
 {
@@ -270,7 +270,7 @@ cb_area_prepared (GdkPixbufLoader *loader,
 }
 
 
-void
+static void
 cb_area_updated (GdkPixbufLoader *loader,
                  gint arg1,
                  gint arg2,
@@ -285,7 +285,7 @@ cb_area_updated (GdkPixbufLoader *loader,
 
 
 #ifndef USE_GTK2
-void
+static void
 cb_frame_done (GdkPixbufLoader *loader,
                gpointer arg1,
                gboolean *ret)
