@@ -32,12 +32,12 @@
 
 #include "gimv_io.h"
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *pixbuf_load            (ImageLoader *loader,
-                                   gpointer     data);
-GimvImage *pixbuf_load_file       (ImageLoader *loader,
-                                   gpointer     data);
+GimvImage *pixbuf_load            (GimvImageLoader *loader,
+                                   gpointer         data);
+GimvImage *pixbuf_load_file       (GimvImageLoader *loader,
+                                   gpointer         data);
 
 #endif /* HAVE_GDK_PIXBUF */
 
