@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: png_loader.h,v 1.2.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: png_loader.h,v 1.5 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __PNG_LOADER_H__
 #define __PNG_LOADER_H__
 
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *gimv_png_load (ImageLoader *loader,
-                          gpointer     data);
+GimvImage *gimv_png_load (GimvImageLoader *loader,
+                          gpointer         data);
 
 #endif /* __PNG_LOADER_H__ */
