@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: spi_image_loader.c,v 1.6 2003/06/14 03:39:50 makeinu Exp $
+ * $Id: spi_image_loader.c,v 1.8 2004/09/21 08:44:27 makeinu Exp $
  */
 
 #include "spi_image_loader.h"
@@ -110,7 +110,7 @@ find_bits (gint n, gint *lowest, gint *n_set)
 }
 
 
-gboolean
+static gboolean
 dib_read_bitmasks (guchar *buf,
                    BmpBitFields *bf)
 {
@@ -137,7 +137,7 @@ dib_read_bitmasks (guchar *buf,
 }
 
 
-gboolean
+static gboolean
 dib_read_color_map (guchar *rgb,
                     guchar buffer[256][3],
                     gint number,
@@ -163,7 +163,7 @@ dib_read_color_map (guchar *rgb,
 }
 
 
-GimvImage *
+static GimvImage *
 dib_read_image (guchar *image,
                 BITMAPINFOHEADER *bih,
                 guchar cmap[256][3],
@@ -253,7 +253,7 @@ dib_read_image (guchar *image,
 }
 
 
-GimvImage *
+static GimvImage *
 dib_load(BITMAPINFOHEADER *bih, guchar *image)
 {
    gint maps = 4;
@@ -301,7 +301,7 @@ dib_load(BITMAPINFOHEADER *bih, guchar *image)
 #endif
 
 
-GimvImage *
+static GimvImage *
 spi_image_loader_load (SpiImportFilter *loader, const gchar *filename)
 {
    guchar buf[2048], *image;
@@ -338,8 +338,8 @@ spi_image_loader_load (SpiImportFilter *loader, const gchar *filename)
       goto ERROR0;
 
    result = loader->get_pic((char *) filename, 0, 0,
-                            (HANDLE *) &bih,
-                            (HANDLE *) &image,
+                            (HANDLE) &bih,
+                            (HANDLE) &image,
                             NULL,
                             0);
 
