@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: spi_image_loader.h,v 1.1.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: spi_image_loader.h,v 1.4 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __SPI_IMAGE_LOADER_H__
@@ -31,9 +31,9 @@
 #ifdef ENABLE_SPI
 
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *spi_load_image (ImageLoader *loader,
+GimvImage *spi_load_image (GimvImageLoader *loader,
                            gpointer     data);
 
 #endif
