@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: wmf.c,v 1.3 2003/06/14 03:39:50 makeinu Exp $
+ * $Id: wmf.c,v 1.4 2004/09/21 08:44:27 makeinu Exp $
  */
 
 /*
@@ -148,6 +148,7 @@ gimv_wmf_identify (GimvImageLoader *loader)
    GimvIO *gio;
    gint bytes_read, i;
    guchar *sig[] = {"\xd7\xcd\xc6\x9a", "\x01\x00\x09\x00"};
+   gint n_sig = sizeof (sig) / sizeof (guchar*);
 
    gio = gimv_image_loader_get_gio (loader);
    if (!gio) return FALSE;
@@ -156,7 +157,7 @@ gimv_wmf_identify (GimvImageLoader *loader)
    gimv_io_read (gio, buf, 16, &bytes_read);
    if (bytes_read != 16) return FALSE;
 
-   for (i = 0; i < sizeof (sig) / sizeof (guchar*); i++) {
+   for (i = 0; i < n_sig; i++) {
       if (compare_signature (buf, sig[i]))
          return TRUE;
    }
