@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: wmf.h,v 1.1.2.1 2003/01/06 13:27:37 makeinu Exp $
+ * $Id: wmf.h,v 1.3 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __WMF_H__
@@ -31,10 +31,10 @@
 #ifdef ENABLE_WMF
 
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *gimv_wmf_load (ImageLoader *loader,
-                          gpointer     data);
+GimvImage *gimv_wmf_load (GimvImageLoader *loader,
+                          gpointer         data);
 
 #endif /* ENABLE_WMF */
 
