@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xbm.h,v 1.3.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: xbm.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __XBM_H__
@@ -26,7 +26,7 @@
 
 #include <gtk/gtk.h>
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
 typedef struct
 {
@@ -34,10 +34,10 @@ typedef struct
    gint height;
 } xbm_info;
 
-gboolean   xbm_get_header (const gchar *filename,
-                           xbm_info    *info);
-GimvImage *xbm_load       (ImageLoader *loader,
-                           gpointer     data);
+gboolean   xbm_get_header (const gchar     *filename,
+                           xbm_info        *info);
+GimvImage *xbm_load       (GimvImageLoader *loader,
+                           gpointer         data);
 
 #endif /* __XBM_H__ */
 
