@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xcf.c,v 1.10 2003/07/20 14:38:10 makeinu Exp $
+ * $Id: xcf.c,v 1.11 2004/09/21 08:44:27 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -480,8 +480,8 @@ xcf_load_layer (GimvImageLoader *loader, XcfImage *image)
    XcfHierarchy hierarchy;
    XcfLayer layer;
    guint32 offset;
-   glong pos, len;
-   gint i, left, right, width;
+   gulong pos, len;
+   guint i, left, right, width;
    guchar *pix;
 #ifdef XCF_DEBUG
    guchar name[256];
@@ -602,8 +602,8 @@ xcf_load_channel (GimvImageLoader *loader, XcfImage *image)
    XcfHierarchy hierarchy;
    XcfChannel channel;
    guint32 offset;
-   gint i;
-   glong pos, len;
+   guint i;
+   gulong pos, len;
    guchar *pix;
 #ifdef XCF_DEBUG
    guchar name[256];
@@ -800,7 +800,8 @@ xcf_load_tile (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy
 {
    GimvIO *gio;
    guint32 current, size, bpp, tile_height, tile_width;
-   gint i, j, n, c, t, off, ntile_rows, ntile_columns;
+   guint i, j;
+   gint n, c, t, off, ntile_rows, ntile_columns;
    gint curtile_row, curtile_column;
    gint lastrow_height, lastcolumn_width;
    gint rowi, columni;
@@ -917,7 +918,7 @@ xcf_load_tile (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy
                } else {
                   n = 256 - n;
                }
-               for (j = 0; j < n && current < size; j++) {
+               for (j = 0; (gint) j < n && current < size; j++) {
                   c = gimv_io_getc (gio, NULL);
                   if (c == EOF) return FALSE;
                   rowi = current / tile_width;
@@ -939,7 +940,7 @@ xcf_load_tile (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy
                }
                c = gimv_io_getc (gio, NULL);
                if (c == EOF) return FALSE;
-               for (j = 0; j < n && current < size; j++) {
+               for (j = 0; (gint) j < n && current < size; j++) {
                   rowi = current / tile_width;
                   columni = current % tile_width;
                   data = &hierarchy->data[((rowi + curtile_row * TILE_HEIGHT)
@@ -969,7 +970,7 @@ xcf_load_image_properties (GimvImageLoader *loader, XcfImage *image)
    GimvIO *gio;
    PropType prop_type;
    guint32 prop_size;
-   gint i, j;
+   guint i, j;
    guint8 compression;
 
    gio = gimv_image_loader_get_gio (loader);
@@ -987,7 +988,7 @@ xcf_load_image_properties (GimvImageLoader *loader, XcfImage *image)
          if (!xcf_read_int32 (gio, &image->num_cols, 1)) return FALSE;
          if (image->version == 0) {
             gimv_io_seek (gio, image->num_cols, SEEK_SET);
-            for (i = 0, j = 0; i<image->num_cols; i++) {
+            for (i = 0, j = 0; i < image->num_cols; i++) {
                image->cmap[j++] = i;
                image->cmap[j++] = i;
                image->cmap[j++] = i;
