@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xcf.h,v 1.3.2.1 2002/11/14 13:25:25 makeinu Exp $
+ * $Id: xcf.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __XCF_H__
@@ -24,7 +24,7 @@
 
 #include <gtk/gtk.h>
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
 typedef struct
 {
@@ -35,9 +35,9 @@ typedef struct
 } xcf_info;
 
 
-gboolean   xcf_get_header (GimvIO      *gio,
-                           xcf_info    *info);
-GimvImage *xcf_load       (ImageLoader *loader,
-                           gpointer     data);
+gboolean   xcf_get_header (GimvIO          *gio,
+                           xcf_info        *info);
+GimvImage *xcf_load       (GimvImageLoader *loader,
+                           gpointer         data);
 
 #endif /* __XCF_H */
