@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xvpics.c,v 1.10 2003/06/14 03:39:50 makeinu Exp $
+ * $Id: xvpics.c,v 1.11 2004/09/21 08:44:27 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -106,7 +106,7 @@ xvpics_load (GimvImageLoader *loader, gpointer user_data)
          rgb_data[(i + j * width) * 3 + 2] = (line[i] & 3) * 85;
       }
 
-      if (bytes_read < width) break;
+      if (bytes_read < (guint) width) break;
 
       gimv_io_tell (gio, &pos);
       bytes_count_tmp = pos / step;
