@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xvpics.h,v 1.3.2.1 2002/11/14 13:25:25 makeinu Exp $
+ * $Id: xvpics.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __XVPICS_H__
 #define __XVPICS_H__
 
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *xvpics_load (ImageLoader *loader,
+GimvImage *xvpics_load (GimvImageLoader *loader,
                         gpointer     data);
 
 #endif /* __XVPICS_H__ */
