@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine.c,v 1.4 2004/09/21 08:44:28 makeinu Exp $
+ * $Id: gimv_xine.c,v 1.6 2004/10/03 16:26:40 makeinu Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -250,11 +250,17 @@ gimv_xine_init (GimvXine *this)
     * create a new xine instance, load config values
     */
 
+#if 0
    priv->xine = xine_new ();
 
    g_snprintf (priv->configfile, 255, "%s/.gimv/xinerc", getenv ("HOME"));
    xine_config_load (priv->xine, priv->configfile);
 
+   xine_init (priv->xine);
+#else
+   priv->xine = gimv_xine_priv_get ();
+#endif
+
    priv->stream               = NULL;
    priv->event_queue          = NULL;
    priv->vo_driver            = NULL;
@@ -262,8 +268,6 @@ gimv_xine_init (GimvXine *this)
 
    priv->oldwidth             = 0;
    priv->oldheight            = 0;
-
-   xine_init (priv->xine);
 }
 
 
@@ -280,7 +284,11 @@ gimv_xine_destroy (GtkObject *object)
    if (priv) {
       /* exit xine */
       if (priv->xine)
+#if 0
          xine_exit (priv->xine);
+#else
+         gimv_xine_priv_release (priv->xine);
+#endif
       priv->xine = NULL;
 
       g_free (gtx->private);
@@ -698,7 +706,7 @@ gimv_xine_unrealize (GtkWidget *widget)
 #endif /* defined (GDK_WINDOWING_X11) */
 
    /* save configuration */
-   xine_config_save (priv->xine, priv->configfile);
+   /* xine_config_save (priv->xine, priv->configfile); */
 
    /* Hide all windows */
    if (GTK_WIDGET_MAPPED (widget))
@@ -1140,8 +1148,6 @@ gimv_xine_get_current_frame_rgb (GimvXine *gtx,
 
    image = gimv_xine_priv_image_new (sizeof (guchar) * width * height * 2);
 
-   image->y = image->u = image->v = image->yuy2 = NULL;
-
    err = xine_get_current_frame(priv->stream,
                                 &image->width, &image->height,
                                 &image->ratio_code,
