@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine.h,v 1.3 2003/07/12 15:53:31 makeinu Exp $
+ * $Id: gimv_xine.h,v 1.4 2004/09/21 08:44:28 makeinu Exp $
  *
  * the xine engine in a widget - header
  */
@@ -144,6 +144,22 @@ gchar      **gimv_xine_get_autoplay_mrls              (GimvXine    *gtx,
                                                        const gchar *plugin_id,
                                                        gint        *num_mrls);
 
+gint         gimv_xine_get_audio_lang         (GimvXine    *gtx,
+                                               gint         channel,
+                                               gchar       *lang);
+gint         gimv_xine_get_spu_lang           (GimvXine    *gtx,
+                                               gint         channel,
+                                               gchar       *lang);
+gint         gimv_xine_get_stream_info        (GimvXine    *gtx,
+                                               gint         info);
+const gchar *gimv_xine_get_meta_info          (GimvXine    *gtx,
+                                               gint         info);
+gint         gimv_xine_get_current_frame      (GimvXine    *gtx,
+                                               gint        *width,
+                                               gint        *height,
+                                               gint        *ratio_code,
+                                               gint        *format,
+                                               uint8_t     *img);
 guchar      *gimv_xine_get_current_frame_rgb  (GimvXine    *gtx,
                                                gint        *width_ret,
                                                gint        *height_ret);
@@ -223,7 +239,6 @@ void         gimv_xine_config_save            (GimvXine    *gtx,
                                                const gchar *cfg_filename);
 void         gimv_xine_config_reset           (GimvXine    *gtx);
 
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
