@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine_priv.c,v 1.3 2004/09/21 08:44:28 makeinu Exp $
+ * $Id: gimv_xine_priv.c,v 1.4 2004/10/03 16:25:22 makeinu Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -30,6 +30,39 @@
 #include "gimv_xine.h"
 
 
+static xine_t *xine = NULL;
+static gint ref_count = 0;
+static gchar configfile[256] = { 0 };
+
+xine_t *
+gimv_xine_priv_get (void)
+{
+   if (!xine) {
+      xine = xine_new ();
+      g_snprintf (configfile, 255, "%s/.gimv/xinerc", getenv ("HOME"));
+      xine_config_load (xine, configfile);
+      xine_init (xine);
+      ref_count = 1;
+      return xine;
+   }
+
+   ref_count++;
+   return xine;
+}
+
+void
+gimv_xine_priv_release (xine_t *axine)
+{
+   ref_count--;
+
+   if (ref_count == 0) {
+      xine_config_save (axine, configfile);
+      xine_exit (axine);
+      xine = NULL;
+   }
+}
+
+
 /******************************************************************************
  *
  *   functions for snap shot.
@@ -511,7 +544,7 @@ yuy2toyv12 (GimvXinePrivImage *image)
 
    for (i = 0; i < height; i += 2) {
       for (j = 0; j < w2; j++) {
-	
+
          /* packed YUV 422 is: Y[i] U[i] Y[i+1] V[i] */
          *(y++) = *(input++);
          *(u++) = *(input++);
@@ -549,8 +582,6 @@ yuy2toyv12 (GimvXinePrivImage *image)
 static gint
 yuy2_fudge (GimvXinePrivImage *image)
 {
-   image->yuy2 = image->y;
-
    image->y = g_malloc0 (image->height * image->width);
    if (!image->y) goto ERROR0;
 
@@ -562,9 +593,6 @@ yuy2_fudge (GimvXinePrivImage *image)
 
    yuy2toyv12 (image);
 
-   /* image->yuy2 = NULL; */ /* I will use this value as flag
-                                to free yuv data in scale_image () */
-
    return 1;
 
  ERROR2:
@@ -704,47 +732,27 @@ gimv_xine_priv_yuv2rgb (GimvXinePrivImage *image)
    g_return_val_if_fail (image, NULL);
 
    switch (image->ratio_code) {
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
    case XINE_VO_ASPECT_SQUARE:
-#else
-   case XINE_ASPECT_RATIO_SQUARE:
-#endif
       image->scale_line = scale_line_1_1;
       image->scale_factor = (32768 * 1) / 1;
       break;
 
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
    case XINE_VO_ASPECT_4_3:
-#else
-   case XINE_ASPECT_RATIO_4_3:
-#endif
       image->scale_line = scale_line_15_16;
       image->scale_factor = (32768 * 16) / 15;
       break;
 
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
    case XINE_VO_ASPECT_ANAMORPHIC:
-#else
-   case XINE_ASPECT_RATIO_ANAMORPHIC:
-#endif
       image->scale_line = scale_line_45_64;
       image->scale_factor = (32768 * 64) / 45;
       break;
 
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
    case XINE_VO_ASPECT_DVB:
-#else
-   case XINE_ASPECT_RATIO_211_1:
-#endif
       image->scale_line = scale_line_45_64;
       image->scale_factor = (32768 * 64) / 45;
       break;
 
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
    case XINE_VO_ASPECT_DONT_TOUCH:
-#else
-   case XINE_ASPECT_RATIO_DONT_TOUCH:
-#endif
    default:
       /* the mpeg standard has a few that we don't know about */
       g_print ( "unknown aspect ratio. will assume 1:1\n" ); 
@@ -756,13 +764,11 @@ gimv_xine_priv_yuv2rgb (GimvXinePrivImage *image)
    switch ( image->format ) {
    case XINE_IMGFMT_YV12:
       printf( "XINE_IMGFMT_YV12\n" ); 
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
       image->y        = image->img;
       image->u        = image->img + (image->width*image->height);
       image->v        = image->img
                            + (image->width * image->height)
                            + (image->width * image->height) / 4;
-#endif
       image->u_width  = ((image->width  + 1) / 2);
       image->v_width  = ((image->width  + 1) / 2);
       image->u_height = ((image->height + 1) / 2);
@@ -771,11 +777,9 @@ gimv_xine_priv_yuv2rgb (GimvXinePrivImage *image)
 
    case XINE_IMGFMT_YUY2: 
       printf( "XINE_IMGFMT_YUY2\n" );
-#if (XINE_MAJOR_VERSION >= 1) && (XINE_MINOR_VERSION >= 0) && (XINE_SUB_VERSION >= 0)
       image->yuy2     = image->img;
-#endif
-      image->u_width  = ((image->width  + 1)  / 2);
-      image->v_width  = ((image->width  + 1)  / 2);
+      image->u_width  = ((image->width  + 1) / 2);
+      image->v_width  = ((image->width  + 1) / 2);
       image->u_height = ((image->height + 1) / 2);
       image->v_height = ((image->height + 1) / 2);
       break;
@@ -787,32 +791,13 @@ gimv_xine_priv_yuv2rgb (GimvXinePrivImage *image)
       return NULL;
    }
 
-#if 0
-   switch ( image->format ) {
-   case XINE_IMGFMT_YV12:
-      image->u_width  = ((image->width+1)  / 2);
-      image->v_width  = ((image->width+1)  / 2);
-      image->u_height = ((image->height+1) / 2);
-      image->v_height = ((image->height+1) / 2);
-      break;
-
-   case XINE_IMGFMT_YUY2: 
-      image->u_width  = ((image->width+1)  / 2);
-      image->v_width  = ((image->width+1)  / 2);
-      image->u_height = ((image->height+1) / 2);
-      image->v_height = ((image->height+1) / 2);
-      break;
-
-   default:                
-      return NULL;
-   }
-#endif
-
    /*
     *  If YUY2 convert to YV12
     */
    if (image->format == XINE_IMGFMT_YUY2) {
-      if (!yuy2_fudge (image)) return NULL;
+      if (!yuy2_fudge (image)) {
+         return NULL;
+      }
    }
 
    scale_image (image);
