@@ -151,6 +151,10 @@ typedef struct GimvXinePrivImage_Tag {
 } GimvXinePrivImage;
 
 
+xine_t *gimv_xine_priv_get     (void);
+void    gimv_xine_priv_release (xine_t *xine);
+
+
 GimvXinePrivImage *gimv_xine_priv_image_new    (gint               imgsize);
 void               gimv_xine_priv_image_delete (GimvXinePrivImage *image);
 guchar            *gimv_xine_priv_yuv2rgb      (GimvXinePrivImage *image);
