@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_mplayer.c,v 1.1.2.6 2003/06/09 12:46:10 makeinu Exp $
+ * $Id: image_view_mplayer.c,v 1.5 2003/07/05 16:45:32 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,17 +32,17 @@
 #include "gimv_mplayer.h"
 #include "gimv_image_view.h"
 #include "gimv_plugin.h"
+#include "gimv_thumb_cache.h"
 #include "prefs_mplayer.h"
-#include "thumbnail_support.h"
 
 static gboolean   imageview_mplayer_is_supported     (GimvImageView *iv,
-                                                      ImageInfo *info);
+                                                      GimvImageInfo *info);
 static GtkWidget *imageview_mplayer_create           (GimvImageView *iv);
 static void       imageview_mplayer_create_thumbnail (GimvImageView *iv,
                                                       const gchar *type);
 
 static gboolean   imageview_mplayer_is_playable      (GimvImageView *iv,
-                                                      ImageInfo *info);
+                                                      GimvImageInfo *info);
 static gboolean   imageview_mplayer_is_seekable      (GimvImageView *iv);
 static void       imageview_mplayer_play             (GimvImageView *iv);
 static void       imageview_mplayer_stop             (GimvImageView *iv);
@@ -236,7 +236,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("MPlayer Embeder & Movie Frame Loader"),
-   version:       "0.1.0",
+   version:       "0.1.2",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -287,13 +287,13 @@ imageview_mplayer_real_play (GimvImageView *iv)
 
    g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
 
    mplayer = get_mplayer (iv);
    g_return_if_fail (mplayer);
 
-   filename = image_info_get_path (iv->info);
+   filename = gimv_image_info_get_path (iv->info);
 
    if (gimv_mplayer_set_file (GIMV_MPLAYER (mplayer), filename)) {
       gimv_mplayer_play (GIMV_MPLAYER (mplayer));
@@ -379,12 +379,12 @@ cb_mplayer_identified (GimvMPlayer *mplayer, GimvImageView *iv)
  *
  *****************************************************************************/
 static gboolean
-imageview_mplayer_is_supported (GimvImageView *iv, ImageInfo *info)
+imageview_mplayer_is_supported (GimvImageView *iv, GimvImageInfo *info)
 {
    g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
    if (!info) return FALSE;
 
-   return image_info_is_movie (info) || image_info_is_audio (info);
+   return gimv_image_info_is_movie (info) || gimv_image_info_is_audio (info);
 }
 
 
@@ -429,10 +429,9 @@ imageview_mplayer_create_thumbnail (GimvImageView *iv, const gchar *cache_write_
    GimvImage *imcache;
    GimvMPlayer *mplayer;
    GimvImage *image;
-   ThumbCacheSaveInfo *save_info;
    gchar *filename, *tmpfile;
 
-   if (!image_info_is_movie (iv->info)) return;
+   if (!gimv_image_info_is_movie (iv->info)) return;
 
    mplayer = get_mplayer (iv);
    g_return_if_fail (mplayer);
@@ -446,13 +445,12 @@ imageview_mplayer_create_thumbnail (GimvImageView *iv, const gchar *cache_write_
       return;
    }
 
-   filename = image_info_get_path_with_archive (iv->info);
-   save_info = thumbsupport_save_info_new (iv->info, NULL);
+   filename = gimv_image_info_get_path_with_archive (iv->info);
 
-   imcache = thumbsupport_save_thumbnail_cache (filename,
-                                                cache_write_type,
-                                                image,
-                                                save_info);
+   imcache = gimv_thumb_cache_save (filename,
+                                    cache_write_type,
+                                    image,
+                                    iv->info);
 
    if (imcache) {
       gimv_image_unref (imcache);
@@ -461,7 +459,6 @@ imageview_mplayer_create_thumbnail (GimvImageView *iv, const gchar *cache_write_
                                iv->info);
    }
 
-   thumbsupport_save_info_delete (save_info);
    g_free (filename);
    gimv_image_unref (image);
    g_free (tmpfile);
@@ -469,7 +466,7 @@ imageview_mplayer_create_thumbnail (GimvImageView *iv, const gchar *cache_write_
 
 
 static gboolean
-imageview_mplayer_is_playable (GimvImageView *iv, ImageInfo *info)
+imageview_mplayer_is_playable (GimvImageView *iv, GimvImageInfo *info)
 {
    return TRUE;
 }
@@ -518,7 +515,7 @@ imageview_mplayer_pause (GimvImageView *iv)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
@@ -538,7 +535,7 @@ imageview_mplayer_stop (GimvImageView *iv)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
