@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_xine.c,v 1.7 2004/04/08 10:38:50 makeinu Exp $
+ * $Id: image_view_xine.c,v 1.8 2004/10/03 19:18:57 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -95,7 +95,7 @@ static GimvImageViewPlayableIF playable_if = {
 };
 
 
-static GimvImageViewPlugin plugin_impl[] =
+static GimvImageViewPlugin imageview_xine[] =
 {
    {
       if_version:          GIMV_IMAGE_VIEW_IF_VERSION,
@@ -230,14 +230,38 @@ static GimvMimeTypeEntry xine_mime_types[] =
    },
 };
 
-GIMV_PLUGIN_GET_IMPL(plugin_impl, GIMV_PLUGIN_IMAGEVIEW_EMBEDER)
+/* FIXME */
+#include <xine_image_loader.h>
+static const gchar *
+gimv_plugin_get_impl (guint idx, gpointer *impl, guint *size)
+{
+   g_return_val_if_fail(impl, NULL);
+   *impl = NULL;
+   g_return_val_if_fail(size, NULL);
+   *size = 0;
+
+   switch (idx) {
+   case 0:
+      *impl = &imageview_xine;
+      *size = sizeof(imageview_xine);
+      return GIMV_PLUGIN_IMAGEVIEW_EMBEDER;
+   case 1:
+      gimv_xine_image_loader_get_impl(impl, size);
+      return GIMV_PLUGIN_IMAGE_LOADER;
+   default:
+      return NULL;
+   }
+
+   return NULL;
+}
+/*GIMV_PLUGIN_GET_IMPL(plugin_impl, GIMV_PLUGIN_IMAGEVIEW_EMBEDER)*/
 GIMV_PLUGIN_GET_MIME_TYPE(xine_mime_types)
 
 GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
-   name:          N_("Xine Embeder"),
-   version:       "0.1.1",
+   name:          N_("Xine Embeder & Movie Frame Loader"),
+   version:       "0.2.0",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
