@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mplayer_image_loader.h,v 1.1.2.1 2003/04/05 18:01:40 makeinu Exp $
+ * $Id: mplayer_image_loader.h,v 1.3 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __MPLAYER_IMAGE_LOADER_H__
@@ -31,13 +31,13 @@
 #ifdef ENABLE_MPLAYER
 
 #include <glib.h>
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 #include "gimv_image.h"
 
-extern void gimv_mplayer_image_loader_get_impl (gpointer *impl,
-                                                guint *size);
-GimvImage *gimv_mplayer_image_loader_load_file (ImageLoader *loader,
-                                                gpointer     data);
+extern void gimv_mplayer_image_loader_get_impl (gpointer        *impl,
+                                                guint           *size);
+GimvImage *gimv_mplayer_image_loader_load_file (GimvImageLoader *loader,
+                                                gpointer         data);
 
 #endif /* ENABLE_MPLAYER */
 
