@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_xine.h,v 1.2 2003/06/13 09:43:11 makeinu Exp $
+ * $Id: prefs_xine.h,v 1.3 2004/10/03 19:18:57 makeinu Exp $
  */
 
 #ifndef __PREFS_UI_XINE_H__
@@ -33,6 +33,8 @@
 #include "gimv_plugin.h"
 #include "gimv_prefs_win.h"
 
+gboolean gimv_prefs_xine_get_thumb_enable (void);
+gfloat   gimv_prefs_xine_get_thumb_pos    (void);
 gfloat   gimv_prefs_xine_get_delay   (GimvPluginInfo    *this);
 gboolean gimv_prefs_ui_xine_get_page (guint              idx,
                                       GimvPrefsWinPage **page,
