@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gqview.c,v 1.21 2003/07/13 13:20:18 makeinu Exp $
+ * $Id: gqview.c,v 1.22 2004/09/21 08:44:28 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -152,7 +152,7 @@ get_thumb_size_from_config ()
                                     CACHE_GQVIEW_DEFAULT_SIZE);
    }
 
-   if (size > sizeof (gqview_thumb_size) / sizeof (GQViewThumbSize)
+   if (size > (gint) (sizeof (gqview_thumb_size) / sizeof (GQViewThumbSize))
        || size < 0)
    {
       size = atoi (CACHE_GQVIEW_DEFAULT_SIZE);
