@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: detailview.c,v 1.4 2003/06/18 09:26:54 makeinu Exp $
+ * $Id: detailview.c,v 1.15 2004/09/21 08:44:29 makeinu Exp $
  */
 
 #include "detailview.h"
@@ -31,25 +31,23 @@
 #include "detailview_prefs.h"
 #include "fileutil.h"
 #include "gimv_image_info.h"
-#include "gimv_thumb.h"
 #include "gimv_plugin.h"
-#include "thumbnail_view.h"
+#include "gimv_thumb.h"
+#include "gimv_thumb_view.h"
 
-static ThumbViewPlugin detailview_modes[] =
+static GimvThumbViewPlugin detailview_modes[] =
 {
    {GIMV_THUMBNAIL_VIEW_IF_VERSION,
     N_("Detail"),
     100,
     detailview_create,
-    detailview_append_thumb_frames,
-    detailview_add_thumbnail,
-    detailview_refresh_thumbnail,
-    NULL,
-    detailview_redraw,
-    NULL,
+    detailview_freeze,
+    detailview_thaw,
+    detailview_append_thumb_frame,
+    detailview_update_thumbnail,
+    detailview_remove_thumbnail,
+    detailview_get_load_list,
     detailview_adjust,
-    detailview_remove_thumbview_data,
-    NULL,
     detailview_set_selection,
     detailview_set_focus,
     detailview_get_focus,
@@ -59,15 +57,13 @@ static ThumbViewPlugin detailview_modes[] =
     N_("Detail + Icon"),
     110,
     detailview_create,
-    detailview_append_thumb_frames,
-    detailview_add_thumbnail,
-    detailview_refresh_thumbnail,
-    NULL,
-    detailview_redraw,
-    NULL,
+    detailview_freeze,
+    detailview_thaw,
+    detailview_append_thumb_frame,
+    detailview_update_thumbnail,
+    detailview_remove_thumbnail,
+    detailview_get_load_list,
     detailview_adjust,
-    detailview_remove_thumbview_data,
-    NULL,
     detailview_set_selection,
     detailview_set_focus,
     detailview_get_focus,
@@ -77,15 +73,13 @@ static ThumbViewPlugin detailview_modes[] =
     N_("Detail + Thumbnail"),
     120,
     detailview_create,
-    detailview_append_thumb_frames,
-    detailview_add_thumbnail,
-    detailview_refresh_thumbnail,
-    NULL,
-    detailview_redraw,
-    NULL,
+    detailview_freeze,
+    detailview_thaw,
+    detailview_append_thumb_frame,
+    detailview_update_thumbnail,
+    detailview_remove_thumbnail,
+    detailview_get_load_list,
     detailview_adjust,
-    detailview_remove_thumbview_data,
-    NULL,
     detailview_set_selection,
     detailview_set_focus,
     detailview_get_focus,
@@ -140,7 +134,7 @@ gint detailview_columns_num = sizeof (detailview_columns) / sizeof (DetailViewCo
 
 
 GtkTargetEntry detailview_dnd_targets[] = {
-   {"text/uri-list",              0, TARGET_URI_LIST},
+   {"text/uri-list", 0, TARGET_URI_LIST},
 };
 const gint detailview_dnd_targets_num = sizeof(detailview_dnd_targets) / sizeof(GtkTargetEntry);
 
@@ -162,7 +156,7 @@ typedef struct DetailViewData_Tag
    GtkWidget       *clist;
    gint             page_pos_x[3];
    gint             page_pos_y[3];
-   gchar           *dest_mode;
+   const gchar     *dest_mode;
    gint             hilit_dir;
 } DetailViewData;
 
@@ -175,17 +169,12 @@ static gboolean cb_clist_motion_notify(GtkWidget      *widget,
                                        gpointer        data);
 static void     cb_click_column       (GtkWidget      *widget,
                                        gint            col,
-                                       ThumbView      *tv);
+                                       GimvThumbView  *tv);
 
 /* other private function */
-static DetailViewData *detailview_new (ThumbView *tv);
-static void detailview_set_text_data  (ThumbView *tv,
-                                       gchar     *dest_mode,
-                                       GList     *start);
-static void detailview_set_pixmaps    (ThumbView *tv,
-                                       gchar     *dest_mode);
-static void store_page_pos            (ThumbView *tv);
-static gint idle_reset_page_pos       (gpointer data);
+static DetailViewData *detailview_new (GimvThumbView  *tv);
+static void detailview_set_pixmaps    (GimvThumbView  *tv,
+                                       const gchar    *dest_mode);
 
 static gboolean  detailview_dragging = FALSE;
 
@@ -198,13 +187,13 @@ static gboolean  detailview_dragging = FALSE;
  *
  ******************************************************************************/
 void
-detailview_create_title_idx_list ()
+detailview_create_title_idx_list (void)
 {
    static gchar *config_columns_string = NULL;
    gchar **titles, *data_order;
    gint i = 0;
 
-   detailview_prefs_get_value("data_order", (gpointer *) &data_order);
+   detailview_prefs_get_value("data_order", (gpointer) &data_order);
  
    if (!data_order) {
       config_columns_string = NULL;
@@ -281,16 +270,16 @@ detailview_apply_config (void)
 
    detailview_create_title_idx_list ();
 
-   node = thumbview_get_list();
+   node = gimv_thumb_view_get_list();
 
    while (node) {
-      ThumbView *tv = node->data;
+      GimvThumbView *tv = node->data;
 
-      if (!strcmp (tv->disp_mode, DETAIL_VIEW_LABEL)
-          || !strcmp (tv->disp_mode, DETAIL_ICON_LABEL)
-          || !strcmp (tv->disp_mode, DETAIL_THUMB_LABEL))
+      if (!strcmp (tv->summary_mode, DETAIL_VIEW_LABEL)
+          || !strcmp (tv->summary_mode, DETAIL_ICON_LABEL)
+          || !strcmp (tv->summary_mode, DETAIL_THUMB_LABEL))
       {
-         thumbview_redraw (tv, tv->disp_mode, tv->container, NULL);
+         gimv_thumb_view_set_widget (tv, tv->tw, tv->container, tv->summary_mode);
       }
 
       node = g_list_next (node);
@@ -307,10 +296,10 @@ detailview_apply_config (void)
 static gchar *
 column_data_filename (GimvThumb *thumb)
 {
-   ThumbView *tv;
+   GimvThumbView *tv;
 
    if (!thumb) return NULL;
-   tv = thumb->thumb_view;
+   tv = gimv_thumb_get_parent_thumbview (thumb);
 
    /*
    if (tv->mode == THUMB_VIEW_MODE_DIR)
@@ -323,7 +312,7 @@ column_data_filename (GimvThumb *thumb)
       const gchar *filename;
       gchar *retval;
 
-      if (tv->mode == THUMB_VIEW_MODE_DIR)
+      if (tv->mode == GIMV_THUMB_VIEW_MODE_DIR)
          filename = g_basename (gimv_image_info_get_path (thumb->info));
       else
          filename = gimv_image_info_get_path (thumb->info);
@@ -423,13 +412,13 @@ column_data_mode (GimvThumb *thumb)
 static gchar *
 column_data_cache (GimvThumb *thumb)
 {
-   gchar *cache_type;
+   const gchar *cache_type;
 
    if (!thumb) return NULL;
 
    cache_type = gimv_thumb_get_cache_type (thumb);
 
-   return cache_type;
+   return (gchar *) cache_type;
 }
 
 
@@ -448,7 +437,7 @@ column_data_cache (GimvThumb *thumb)
 static gint
 cb_clist_key_press (GtkWidget *widget,
                     GdkEventKey *event,
-                    ThumbView *tv)
+                    GimvThumbView *tv)
 {
    GimvThumb *thumb = NULL;
 
@@ -458,7 +447,7 @@ cb_clist_key_press (GtkWidget *widget,
       thumb = gtk_clist_get_row_data (GTK_CLIST (widget),
                                       GTK_CLIST (widget)->focus_row);
 
-   if (thumbview_thumb_key_press_cb(widget, event, thumb))
+   if (gimv_thumb_view_thumb_key_press_cb(widget, event, thumb))
       return FALSE;
 
    {
@@ -478,15 +467,15 @@ cb_clist_key_press (GtkWidget *widget,
          if (event->state & GDK_SHIFT_MASK || event->state & GDK_CONTROL_MASK) {
             /* is there somteing to do? */
          } else {
-            thumbview_set_selection_all (tv, FALSE);
+            gimv_thumb_view_set_selection_all (tv, FALSE);
          }
-         thumbview_set_selection (thumb, TRUE);
-         thumbview_open_image (tv, thumb, 0);
+         gimv_thumb_view_set_selection (thumb, TRUE);
+         gimv_thumb_view_open_image (tv, thumb, 0);
          break;
       case GDK_space:
          break;
       case GDK_Delete:
-         thumbview_delete_files (tv);
+         gimv_thumb_view_delete_files (tv);
          break;
       default:
          break;
@@ -500,7 +489,7 @@ cb_clist_key_press (GtkWidget *widget,
 static gboolean
 cb_clist_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    gint row;
    GimvThumb *thumb;
    gboolean clear = TRUE, found = FALSE, success;
@@ -526,7 +515,7 @@ cb_clist_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
    }
 
    if (!success) {
-      thumbview_set_selection_all (tv, FALSE);
+      gimv_thumb_view_set_selection_all (tv, FALSE);
       return FALSE;
    }
 
@@ -539,27 +528,28 @@ cb_clist_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
          if (event->state & GDK_CONTROL_MASK)
             clear = FALSE;
 
-         found = thumbview_set_selection_multiple (thumb, TRUE, clear);
+         found = gimv_thumb_view_set_selection_multiple (tv, thumb,
+                                                         TRUE, clear);
          if (!found)
-            thumbview_set_selection_multiple (thumb, FALSE, clear);
+            gimv_thumb_view_set_selection_multiple (tv, thumb, FALSE, clear);
       } else if (!thumb->selected) {
          if (~event->state & GDK_CONTROL_MASK)
-            thumbview_set_selection_all (tv, FALSE);
-         thumbview_set_selection (thumb, TRUE);
+            gimv_thumb_view_set_selection_all (tv, FALSE);
+         gimv_thumb_view_set_selection (thumb, TRUE);
       } else if (thumb->selected) {
          if (event->state & GDK_CONTROL_MASK)
-            thumbview_set_selection (thumb, FALSE);
+            gimv_thumb_view_set_selection (thumb, FALSE);
       }
    }
 
-   return thumbview_thumb_button_press_cb (widget, event, thumb);
+   return gimv_thumb_view_thumb_button_press_cb (widget, event, thumb);
 }
 
 
 static gboolean
 cb_clist_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    gint row;
    GimvThumb *thumb;
    gboolean success;
@@ -581,7 +571,7 @@ cb_clist_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
    }
 
    if (!success) {
-      thumbview_set_selection_all (tv, FALSE);
+      gimv_thumb_view_set_selection_all (tv, FALSE);
       goto ERROR;
    }
 
@@ -594,11 +584,11 @@ cb_clist_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
        && !(event->state & GDK_CONTROL_MASK)
        && !detailview_dragging)
    {
-      thumbview_set_selection_all (tv, FALSE);
-      thumbview_set_selection (thumb, TRUE);
+      gimv_thumb_view_set_selection_all (tv, FALSE);
+      gimv_thumb_view_set_selection (thumb, TRUE);
    }
 
-   return thumbview_thumb_button_release_cb (widget, event, thumb);
+   return gimv_thumb_view_thumb_button_release_cb (widget, event, thumb);
 
 ERROR:
    detailview_dragging = FALSE;
@@ -609,7 +599,7 @@ ERROR:
 static gboolean
 cb_clist_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    gint row, on_row;
    GimvThumb *thumb = NULL;
 
@@ -623,12 +613,12 @@ cb_clist_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
       thumb = gtk_clist_get_row_data (GTK_CLIST (widget), row);
    }
 
-   return thumbview_motion_notify_cb (widget, event, thumb);
+   return gimv_thumb_view_motion_notify_cb (widget, event, thumb);
 }
 
 
 static void
-cb_click_column(GtkWidget *widget, gint col, ThumbView *tv)
+cb_click_column(GtkWidget *widget, gint col, GimvThumbView *tv)
 {
    GimvThumbWin *tw;
    GtkWidget *sort_item;
@@ -637,7 +627,7 @@ cb_click_column(GtkWidget *widget, gint col, ThumbView *tv)
 
    if (!tv || tv->progress) return;
 
-   tw = tv->thumb_window;
+   tw = tv->tw;
    if (!tw) return;
 
    node = g_list_nth (detailview_title_idx_list, col - 1);
@@ -685,7 +675,7 @@ static void
 cb_select_row (GtkCList *clist, gint row, gint column,
                GdkEventButton *event, gpointer user_data)
 {
-   ThumbView *tv = user_data;
+   GimvThumbView *tv = user_data;
    GimvThumb *thumb;
    GList *node;
 
@@ -705,7 +695,7 @@ static void
 cb_unselect_row (GtkCList *clist, gint row, gint column,
                  GdkEventButton *event, gpointer user_data)
 {
-   ThumbView *tv = user_data;
+   GimvThumbView *tv = user_data;
    GimvThumb *thumb;
    GList *node;
 
@@ -740,7 +730,7 @@ cb_drag_motion (GtkWidget *clist, GdkDragContext *context,
    thumb = gtk_clist_get_row_data (GTK_CLIST (clist), row);
    if (!thumb) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) return;
 
    /* hilight row under cursor */
@@ -769,7 +759,7 @@ cb_drag_leave (GtkWidget *clist, GdkDragContext *context, guint time,
    ThumbView *tv = data;
    DetailViewData *tv_data;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) return;
 
    gtk_clist_set_foreground (GTK_CLIST (clist), tv_data->hilit_dir,
@@ -808,8 +798,8 @@ cb_drag_data_received (GtkWidget *clist,
       tv->dnd_destdir = gimv_thumb_get_image_name (thumb);
 #endif
 
-   thumbview_drag_data_received_cb (clist, context, x, y,
-                                    seldata, info, time, data);
+   gimv_thumb_view_drag_data_received_cb (clist, context, x, y,
+                                          seldata, info, time, data);
 }
 
 
@@ -820,14 +810,14 @@ cb_drag_data_received (GtkWidget *clist,
  *
  ******************************************************************************/
 static DetailViewData *
-detailview_new (ThumbView *tv)
+detailview_new (GimvThumbView *tv)
 {
    DetailViewData *tv_data;
    gint i, num;
 
    g_return_val_if_fail (tv, NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) {
       tv_data = g_new0 (DetailViewData, 1);
       tv_data->clist = NULL;
@@ -837,7 +827,8 @@ detailview_new (ThumbView *tv)
          tv_data->page_pos_y[i] = 0;
       }
       tv_data->hilit_dir = -1;
-      g_hash_table_insert (tv->disp_mode_data, DETAIL_VIEW_LABEL, tv_data);
+      gtk_object_set_data_full (GTK_OBJECT (tv), DETAIL_VIEW_LABEL, tv_data,
+                                (GtkDestroyNotify) g_free);
    }
 
    return tv_data;
@@ -845,69 +836,7 @@ detailview_new (ThumbView *tv)
 
 
 static void
-detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
-{
-   GimvThumb *thumb;
-   DetailViewData *tv_data;
-   GList *node, *data_node;
-   gint i, j, start_pos, num, colnum;
-   gchar **image_data;
-
-   g_return_if_fail (tv);
-   if (!start) return;
-
-   node = start;
-   start_pos = g_list_position (tv->thumblist, start);
-   num = g_list_length (node);
-   colnum = detailview_title_idx_list_num + 1;
-   image_data = g_malloc0 (sizeof (gchar *) * colnum);
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_if_fail (tv_data && tv_data->clist);
-
-   /* set text data */
-   for (i = start_pos ; i < num ; i++) {
-      thumb = node->data;
-
-      image_data[0] = NULL;
-      data_node = detailview_title_idx_list;
-      for (j = 1; j < colnum && data_node; j++) {
-         gint idx = GPOINTER_TO_INT (data_node->data);
-         if (detailview_columns[idx].func) {
-            image_data[j] = detailview_columns[idx].func (thumb);
-         } else {
-            image_data[j] = NULL;
-         }
-         data_node = g_list_next (data_node);
-      }
-
-      gtk_clist_append (GTK_CLIST (tv_data->clist), image_data);
-      gtk_clist_set_row_data (GTK_CLIST (tv_data->clist), i, thumb);
-
-      if (thumb->selected)
-         gtk_clist_select_row (GTK_CLIST (tv_data->clist), i, -1);
-      else
-         gtk_clist_unselect_row (GTK_CLIST (tv_data->clist), i, -1);
-
-      data_node = detailview_title_idx_list;
-      for (j = 1; j < colnum && data_node; j++) {
-         gint idx = GPOINTER_TO_INT (data_node->data);
-         if (detailview_columns[idx].free && image_data[j]) {
-            g_free (image_data[j]);
-         }
-         image_data[j] = NULL;
-         data_node = g_list_next (data_node);
-      }
-
-      node = g_list_next (node);
-   }
-
-   g_free (image_data);
-}
-
-
-static void
-detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
+detailview_set_pixmaps (GimvThumbView *tv, const gchar *dest_mode)
 {
    GimvThumb *thumb;
    GList *node;
@@ -921,155 +850,121 @@ detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
    /* set images */
    for ( i = 0 ; i < num ; i++ ) {
       thumb = node->data;
-      detailview_add_thumbnail (thumb, dest_mode, LOAD_CACHE);
+      detailview_update_thumbnail (tv, thumb, dest_mode);
       node = g_list_next (node);
    }
 }
 
 
-static void
-store_page_pos (ThumbView *tv)
-{
-   DetailViewData *tv_data;
-   GtkScrolledWindow *scrollwin;
-   GtkAdjustment *hadj, *vadj;
-   gchar *label;
-
-   g_return_if_fail (tv);
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_if_fail (tv_data);
-
-   label = tv->disp_mode;
-   scrollwin = GTK_SCROLLED_WINDOW (tv->container);
-   hadj = gtk_scrolled_window_get_hadjustment (scrollwin);
-   vadj = gtk_scrolled_window_get_vadjustment (scrollwin);
-
-   if (!strcmp (label, DETAIL_VIEW_LABEL)) {
-      tv_data->page_pos_x[0] = hadj->value;
-      tv_data->page_pos_y[0] = vadj->value;
-   } else if (!strcmp (label, DETAIL_ICON_LABEL)) {
-      tv_data->page_pos_x[1] = hadj->value;
-      tv_data->page_pos_y[1] = vadj->value;
-   } else if (!strcmp (label, DETAIL_THUMB_LABEL)) {
-      tv_data->page_pos_x[2] = hadj->value;
-      tv_data->page_pos_y[2] = vadj->value;
-   }
-   /* g_print ("store: %s %f\n", label, vadj->value); */
-}
-
-
-static gint
-idle_reset_page_pos (gpointer data)
-{
-   ThumbView *tv = data;
-   DetailViewData *tv_data;
-   GtkScrolledWindow *scrollwin;
-   GtkAdjustment *hadj, *vadj;
-   gchar *label;
-   gfloat page_pos_x, page_pos_y;
-
-   g_return_val_if_fail (tv, FALSE);
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_val_if_fail (tv_data, FALSE);
-
-   label = tv_data->dest_mode;
-   scrollwin = GTK_SCROLLED_WINDOW (tv->container);
-   hadj = gtk_scrolled_window_get_hadjustment (scrollwin);
-   vadj = gtk_scrolled_window_get_vadjustment (scrollwin);
-
-   if (!strcmp (label, DETAIL_VIEW_LABEL)) {
-      page_pos_x = tv_data->page_pos_x[0];
-      page_pos_y = tv_data->page_pos_y[0];
-   } else if (!strcmp (label, DETAIL_ICON_LABEL)) {
-      page_pos_x = tv_data->page_pos_x[1];
-      page_pos_y = tv_data->page_pos_y[1];
-   } else if (!strcmp (label, DETAIL_THUMB_LABEL)) {
-      page_pos_x = tv_data->page_pos_x[2];
-      page_pos_y = tv_data->page_pos_y[2];
-   } else {
-      return FALSE;
-   }
-
-   /* g_print ("reset: %s %f\n", label, page_pos); */
-   gtk_adjustment_set_value (hadj, page_pos_x);
-   gtk_adjustment_set_value (vadj, page_pos_y);
-
-   return FALSE;
-}
-
-
 
 /******************************************************************************
  *
  *   public functions.
  *
  ******************************************************************************/
-/*
- *  detailview_remove_thumbview_data:
- *
- *  thumb : Pointer to the GimvThumb struct.
- */
 void
-detailview_remove_thumbview_data (ThumbView *tv)
+detailview_freeze (GimvThumbView *tv)
 {
    DetailViewData *tv_data;
 
-   if (!tv) return;
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   if (!tv_data) return;
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->clist);
 
-   g_hash_table_remove (tv->disp_mode_data, DETAIL_VIEW_LABEL); 
-   g_free (tv_data);
+   gtk_clist_freeze (GTK_CLIST (tv_data->clist));
 }
 
 
-GList *
-detailview_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
+void
+detailview_thaw (GimvThumbView *tv)
 {
-   GList *loadlist = NULL;
+   DetailViewData *tv_data;
 
-   g_return_val_if_fail (tv && start, FALSE);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   detailview_redraw (tv, dest_mode, tv->container, &loadlist);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->clist);
 
-   return loadlist;
+   gtk_clist_thaw (GTK_CLIST (tv_data->clist));
 }
 
 
-GtkWidget *
-detailview_add_thumbnail (GimvThumb *thumb,
-                          gchar *dest_mode,
-                          ThumbLoadType type)
+void
+detailview_append_thumb_frame (GimvThumbView *tv, GimvThumb *thumb,
+                               const gchar *dest_mode)
+{
+   DetailViewData *tv_data;
+   GList *data_node;
+   gint j, colnum;
+   gchar **image_data;
+   gint pos;
+
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->clist);
+
+   colnum = detailview_title_idx_list_num + 1;
+   image_data = g_malloc0 (sizeof (gchar *) * colnum);
+
+   pos = g_list_index (tv->thumblist, thumb);
+
+   image_data[0] = NULL;
+   data_node = detailview_title_idx_list;
+   for (j = 1; j < colnum && data_node; j++) {
+      gint idx = GPOINTER_TO_INT (data_node->data);
+      if (detailview_columns[idx].func) {
+         image_data[j] = detailview_columns[idx].func (thumb);
+      } else {
+         image_data[j] = NULL;
+      }
+      data_node = g_list_next (data_node);
+   }
+
+   gtk_clist_insert (GTK_CLIST (tv_data->clist), pos, image_data);
+   gtk_clist_set_row_data (GTK_CLIST (tv_data->clist), pos, thumb);
+
+   if (thumb->selected)
+      gtk_clist_select_row (GTK_CLIST (tv_data->clist), pos, -1);
+   else
+      gtk_clist_unselect_row (GTK_CLIST (tv_data->clist), pos, -1);
+
+   data_node = detailview_title_idx_list;
+   for (j = 1; j < colnum && data_node; j++) {
+      gint idx = GPOINTER_TO_INT (data_node->data);
+      if (detailview_columns[idx].free && image_data[j]) {
+         g_free (image_data[j]);
+      }
+      image_data[j] = NULL;
+      data_node = g_list_next (data_node);
+   }
+
+   g_free (image_data);
+}
+
+
+void
+detailview_update_thumbnail (GimvThumbView *tv, GimvThumb *thumb,
+                             const gchar *dest_mode)
 {
-   ThumbView *tv;
    DetailViewData *tv_data;
    GdkPixmap *pixmap = NULL;
    GdkBitmap *mask;
    GList *node;
    gint pos, row, col, i;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, NULL);
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_val_if_fail (tv_data && tv_data->clist, NULL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->clist);
 
    pos = g_list_index (tv->thumblist, thumb);
 
    row = pos;
    col = 0;
 
-   /*
-   thumbnail = gimv_thumb_get_thumb (thumb);
-   if (!thumbnail)
-      thumbnail = create_thumbnail_auto (thumb, tv->ThumbnailSize, type);
-   */
-
    /* set thumbnail */
    if (!strcmp (DETAIL_ICON_LABEL, dest_mode)) {
       gimv_thumb_get_icon (thumb, &pixmap, &mask);
@@ -1077,7 +972,7 @@ detailview_add_thumbnail (GimvThumb *thumb,
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
 
-   if (!pixmap) return NULL;
+   if (!pixmap) return;
 
    gtk_clist_set_pixmap (GTK_CLIST (tv_data->clist),
                          row, col, pixmap, mask);
@@ -1103,83 +998,54 @@ detailview_add_thumbnail (GimvThumb *thumb,
          g_free (str);
    }
 
-   return NULL;
+   return;
 }
 
 
-void
-detailview_redraw (ThumbView *tv, gchar *dest_mode,
-                   GtkWidget *scroll_win, GList **loadlist)
+GList *
+detailview_get_load_list (GimvThumbView *tv)
 {
-   DetailViewData *tv_data;
-   GList *node;
+   GList *loadlist = NULL, *node;
 
-   g_return_if_fail (tv);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   node = g_list_find (thumbview_get_list(), tv);
-   if (!node) return;
+   if (!strcmp (DETAIL_VIEW_LABEL, tv->summary_mode)) return NULL;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   if (!tv_data)
-      tv_data = detailview_new (tv);
-
-   tv_data->dest_mode = dest_mode;
-
-   if (tv_data->clist) {
-      store_page_pos (tv);
-      gtk_widget_destroy (tv_data->clist);
-      tv_data->clist = NULL;
-   }
-
-   if (scroll_win) {
-      if (GTK_BIN (tv->container)->child)
-         gtk_widget_destroy (GTK_BIN (tv->container)->child);   
-      tv_data->clist = detailview_create (tv, dest_mode);
-      gtk_container_add (GTK_CONTAINER (scroll_win), tv_data->clist);
-      gtk_idle_add (idle_reset_page_pos, tv);
-   }
-
-   if (!loadlist || !strcmp (DETAIL_VIEW_LABEL, dest_mode)) return;
-
-   /* create thumbnail load list */
-   *loadlist = NULL;
-   node = tv->thumblist;
-   while (node) {
+   for (node = tv->thumblist; node; node = g_list_next (node)) {
       GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
-         *loadlist = g_list_append (*loadlist, thumb);
-
-      node = g_list_next (node);
+         loadlist = g_list_append (loadlist, thumb);
    }
-}
 
-
-gboolean
-detailview_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
-{
-   GtkWidget *widget;
-   ThumbView *tv;
-
-   if (!thumb) return FALSE;
-
-   tv = thumb->thumb_view;
-   if (!tv) return FALSE;
-
-   widget = detailview_add_thumbnail (thumb, tv->disp_mode, type);
-
-   if (widget)
-      return TRUE;
-   else
-      return FALSE;
+   return loadlist;
 }
 
 
 void
-detailview_adjust (ThumbView *tv, GimvThumb *thumb)
+detailview_remove_thumbnail (GimvThumbView *tv, GimvThumb *thumb)
+{
+   DetailViewData *tv_data;
+   gint pos;
+
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
+
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data);
+
+   pos = g_list_index (tv->thumblist, thumb);
+   if (pos < 0) return;
+
+   gtk_clist_remove (GTK_CLIST (tv_data->clist), pos);
+}
+
+
+void
+detailview_adjust (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -1187,10 +1053,10 @@ detailview_adjust (ThumbView *tv, GimvThumb *thumb)
 
    g_return_if_fail (tv);
 
-   node = g_list_find (thumbview_get_list(), tv);
+   node = g_list_find (gimv_thumb_view_get_list(), tv);
    if (!node) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_if_fail (tv_data);
 
    node = g_list_find (tv->thumblist, thumb);
@@ -1202,19 +1068,17 @@ detailview_adjust (ThumbView *tv, GimvThumb *thumb)
 
 
 gboolean
-detailview_set_selection (GimvThumb *thumb, gboolean select)
+detailview_set_selection (GimvThumbView *tv, GimvThumb *thumb, gboolean select)
 {
-   ThumbView *tv;
    DetailViewData *tv_data;
    gint pos;
 
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, FALSE);
    if (g_list_length (tv->thumblist) < 1) return FALSE;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data && tv_data->clist, FALSE);
 
    pos = g_list_index (tv->thumblist, thumb);
@@ -1232,7 +1096,7 @@ detailview_set_selection (GimvThumb *thumb, gboolean select)
 
 
 void
-detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
+detailview_set_focus (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    gint pos;
@@ -1240,7 +1104,7 @@ detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
 
    g_return_if_fail (tv);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_if_fail (tv_data && tv_data->clist);
 
    pos = g_list_index (tv->thumblist, thumb);
@@ -1258,7 +1122,7 @@ detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
 
 
 GimvThumb *
-detailview_get_focus (ThumbView *tv)
+detailview_get_focus (GimvThumbView *tv)
 {
    DetailViewData *tv_data;
    gint pos;
@@ -1267,7 +1131,7 @@ detailview_get_focus (ThumbView *tv)
 
    g_return_val_if_fail (tv, NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data && tv_data->clist, NULL);
 
    clist = GTK_CLIST (tv_data->clist);
@@ -1285,7 +1149,7 @@ detailview_get_focus (ThumbView *tv)
 
 #define CELL_SPACING 1
 gboolean
-detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
+detailview_thumbnail_is_in_viewport (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -1294,9 +1158,9 @@ detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
    GdkRectangle area, row_area, intersect_area;
 
    g_return_val_if_fail (tv, FALSE);
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
    clist = GTK_CLIST (tv_data->clist);
 
@@ -1324,7 +1188,7 @@ detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 
 
 GtkWidget *
-detailview_create (ThumbView *tv, gchar *dest_mode)
+detailview_create (GimvThumbView *tv, const gchar *dest_mode)
 {
    gint i, num;
    DetailViewData *tv_data;
@@ -1333,7 +1197,7 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
 
    g_return_val_if_fail (tv, NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) {
       tv_data = detailview_new (tv);
       g_return_val_if_fail (tv_data, NULL);
@@ -1380,15 +1244,15 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
    dnd_dest_set (tv_data->clist, detailview_dnd_targets, detailview_dnd_targets_num);
 
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag_begin",
-                       GTK_SIGNAL_FUNC (thumbview_drag_begin_cb), tv);
+                       GTK_SIGNAL_FUNC (gimv_thumb_view_drag_begin_cb), tv);
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag_data_get",
-                       GTK_SIGNAL_FUNC (thumbview_drag_data_get_cb), tv);
+                       GTK_SIGNAL_FUNC (gimv_thumb_view_drag_data_get_cb), tv);
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag_data_received",
                        GTK_SIGNAL_FUNC (cb_drag_data_received), tv);
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag-data-delete",
-                       GTK_SIGNAL_FUNC (thumbview_drag_data_delete_cb), tv);
+                       GTK_SIGNAL_FUNC (gimv_thumb_view_drag_data_delete_cb), tv);
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag_end",
-                       GTK_SIGNAL_FUNC (thumbview_drag_end_cb), tv);
+                       GTK_SIGNAL_FUNC (gimv_thumb_view_drag_end_cb), tv);
 #if 0
    gtk_signal_connect (GTK_OBJECT (tv_data->clist), "drag_motion",
                        GTK_SIGNAL_FUNC (cb_drag_motion), tv);
@@ -1414,7 +1278,7 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
       node = g_list_next (node);
    }
 
-   detailview_prefs_get_value ("show_title", (gpointer *) &show_title);
+   detailview_prefs_get_value ("show_title", (gpointer) &show_title);
 
    if (show_title)
       gtk_clist_column_titles_show (GTK_CLIST (tv_data->clist));
@@ -1424,13 +1288,18 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
       gtk_clist_set_row_height (GTK_CLIST(tv_data->clist), ICON_SIZE);
    }
    if (!strcmp (DETAIL_THUMB_LABEL, dest_mode)) {
-      gtk_clist_set_column_width (GTK_CLIST (tv_data->clist), 0, tv->ThumbnailSize);
-      gtk_clist_set_row_height (GTK_CLIST (tv_data->clist), tv->ThumbnailSize);
+      gtk_clist_set_column_width (GTK_CLIST (tv_data->clist), 0, tv->thumb_size);
+      gtk_clist_set_row_height (GTK_CLIST (tv_data->clist), tv->thumb_size);
    }
 
    /* set data */
-   detailview_set_text_data (tv, dest_mode, tv->thumblist);
-   detailview_set_pixmaps (tv, dest_mode);
+   if (tv->thumblist) {
+      GList *node;
+
+      for (node = tv->thumblist; node; node = g_list_next (node))
+         detailview_append_thumb_frame (tv, node->data, dest_mode);
+      detailview_set_pixmaps (tv, dest_mode);
+   }
 
    return tv_data->clist;
 }
