@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: detailview.h,v 1.3 2003/06/18 09:26:54 makeinu Exp $
+ * $Id: detailview.h,v 1.11 2004/09/21 08:44:29 makeinu Exp $
  */
 
 #ifndef __DETAILVIEW_H__
@@ -26,7 +26,7 @@
 
 #include "gimageview.h"
 #include "fileload.h"
-#include "thumbnail_view.h"
+#include "gimv_thumb_view.h"
 
 #define DETAIL_VIEW_LABEL  "Detail"
 #define DETAIL_ICON_LABEL  "Detail + Icon"
@@ -35,32 +35,33 @@
 #define DETAIL_DEFAULT_COLUMN_ORDER \
    "Name,Image size,Size (byte),Type,Cache type,Modification time,User,Group,Mode"
 
-GList     *detailview_append_thumb_frames      (ThumbView     *tv,
-                                                GList         *start,
-                                                gchar         *dest_mode);
-GtkWidget *detailview_add_thumbnail            (GimvThumb     *thumb,
-                                                gchar         *dest_mode,
-                                                ThumbLoadType  type);
-gboolean   detailview_refresh_thumbnail        (GimvThumb     *thumb,
-                                                ThumbLoadType  type);
-void       detailview_redraw                   (ThumbView     *tv,
-                                                gchar         *dest_mode,
-                                                GtkWidget     *scroll_win,
-                                                GList        **loadlist);
-GtkWidget *detailview_resize                   (ThumbView     *tv);
-void       detailview_adjust                   (ThumbView     *tv,
+void       detailview_freeze                   (GimvThumbView *tv);
+void       detailview_thaw                     (GimvThumbView *tv);
+void       detailview_append_thumb_frame       (GimvThumbView *tv,
+                                                GimvThumb     *thumb,
+                                                const gchar   *dest_mode);
+void       detailview_update_thumbnail         (GimvThumbView *tv,
+                                                GimvThumb     *thumb,
+                                                const gchar   *dest_mode);
+void       detailview_remove_thumbnail         (GimvThumbView *tv,
                                                 GimvThumb     *thumb);
-GtkWidget *detailview_create                   (ThumbView     *tv,
-                                                gchar         *dest_mode);
-void       detailview_remove_thumbview_data    (ThumbView     *tv);
-gboolean   detailview_set_selection            (GimvThumb     *thumb,
+GList     *detailview_get_load_list            (GimvThumbView *tv);
+GtkWidget *detailview_resize                   (GimvThumbView *tv);
+void       detailview_adjust                   (GimvThumbView *tv,
+                                                GimvThumb     *thumb);
+GtkWidget *detailview_create                   (GimvThumbView *tv,
+                                                const gchar   *dest_mode);
+gboolean   detailview_set_selection            (GimvThumbView *tv,
+                                                GimvThumb     *thumb,
                                                 gboolean       select);
-void       detailview_set_focus                (ThumbView     *Tv,
+void       detailview_set_focus                (GimvThumbView *tv,
                                                 GimvThumb     *thumb);
-GimvThumb *detailview_get_focus                (ThumbView     *tv);
-gboolean   detailview_thumbnail_is_in_viewport (ThumbView     *tv,
+GimvThumb *detailview_get_focus                (GimvThumbView *tv);
+gboolean   detailview_thumbnail_is_in_viewport (GimvThumbView *tv,
                                                 GimvThumb     *thumb);
 
+void       detailview_create_title_idx_list    (void);
+
 /* for preference */
 gint   detailview_get_titles_num (void);
 gchar *detailview_get_title      (gint idx);
