@@ -2,7 +2,7 @@
 
 /*
  * GImageView
- * Copyright (C) 2001 Takuro Ashie
+ * Copyright (C) 2001-2004 Takuro Ashie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: detailview2.c,v 1.5 2003/07/06 16:46:20 makeinu Exp $
+ * $Id: detailview2.c,v 1.13 2004/09/21 08:44:29 makeinu Exp $
  */
 
-#ifndef GTK_DISABLE_DEPRECATED
-#  define GTK_DISABLE_DEPRECATED
-#endif /* GTK_DISABLE_DEPRECATED */
-
 #include "detailview.h"
 
 /*
@@ -53,6 +49,7 @@ enum {
    COLUMN_THUMB_DATA,
    COLUMN_PIXMAP,
    COLUMN_MASK,
+   COLUMN_EDITABLE,
    N_COLUMN
 };
 
@@ -76,13 +73,13 @@ static gboolean cb_tree_selected               (GtkTreeSelection  *selection,
                                                 gpointer           data);
 static gboolean cb_treeview_button_press       (GtkWidget         *widget,
                                                 GdkEventButton    *event,
-                                                ThumbView         *tv);
+                                                GimvThumbView     *tv);
 static gboolean cb_treeview_motion_notify      (GtkWidget         *widget,
                                                 GdkEventMotion    *event,
                                                 gpointer           data);
 static gboolean cb_treeview_button_release     (GtkWidget         *widget,
                                                 GdkEventButton    *event,
-                                                ThumbView         *tv);
+                                                GimvThumbView     *tv);
 static void     cb_treeview_drag_data_received (GtkWidget         *widget,
                                                 GdkDragContext    *context,
                                                 gint               x,
@@ -92,19 +89,16 @@ static void     cb_treeview_drag_data_received (GtkWidget         *widget,
                                                 guint              time,
                                                 gpointer           data);
 static void     cb_column_clicked              (GtkTreeViewColumn *column,
-                                                ThumbView         *tv);
+                                                GimvThumbView     *tv);
 
 /* other private function */
-static DetailViewData *detailview_new          (ThumbView      *tv);
-static void            set_column_types        (ThumbView      *tv,
+static DetailViewData *detailview_new          (GimvThumbView  *tv);
+static void            set_column_types        (GimvThumbView  *tv,
                                                 DetailViewData *tv_data,
                                                 GtkListStore   *store,
                                                 const gchar    *dest_mode);
-static void            detailview_set_text_data(ThumbView      *tv,
-                                                gchar          *dest_mode,
-                                                GList          *start);
-static void            detailview_set_pixmaps  (ThumbView      *tv,
-                                                gchar          *dest_mode);
+static void            detailview_set_pixmaps  (GimvThumbView  *tv,
+                                                const gchar    *dest_mode);
 
 
 
@@ -118,16 +112,16 @@ cb_tree_selected (GtkTreeSelection *selection, GtkTreeModel *model,
                   GtkTreePath *treepath, gboolean selected, gpointer data)
 {
    DetailViewData *tv_data;
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    GimvThumb *thumb = NULL;
    GtkTreeIter iter;
    gint sel_row_pos = 0;
    gboolean success;
    gboolean under_cursor = FALSE, under_cursor_is_selected = FALSE;
 
-   g_return_val_if_fail (tv, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    if (tv_data->press_button <= 0 && !tv_data->set_selection)
@@ -184,15 +178,15 @@ cb_tree_selected (GtkTreeSelection *selection, GtkTreeModel *model,
 static gint
 cb_treeview_key_press (GtkWidget *widget,
                        GdkEventKey *event,
-                       ThumbView *tv)
+                       GimvThumbView *tv)
 {
    DetailViewData *tv_data;
    GimvThumb *thumb = NULL;
    GtkTreePath *treepath;
 
-   g_return_val_if_fail (tv, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    gtk_tree_view_get_cursor (GTK_TREE_VIEW (tv_data->treeview),
@@ -211,7 +205,7 @@ cb_treeview_key_press (GtkWidget *widget,
       gtk_tree_path_free (treepath);
    }
 
-   if (thumbview_thumb_key_press_cb(widget, event, thumb))
+   if (gimv_thumb_view_thumb_key_press_cb(widget, event, thumb))
       return FALSE;
 
    {
@@ -227,17 +221,17 @@ cb_treeview_key_press (GtkWidget *widget,
          if (event->state & GDK_SHIFT_MASK || event->state & GDK_CONTROL_MASK) {
             /* is there somteing to do? */
          } else {
-            thumbview_set_selection_all (tv, FALSE);
+            gimv_thumb_view_set_selection_all (tv, FALSE);
          }
-         thumbview_set_selection (thumb, TRUE);
-         thumbview_open_image (tv, thumb, 0);
+         gimv_thumb_view_set_selection (thumb, TRUE);
+         gimv_thumb_view_open_image (tv, thumb, 0);
          break;
       case GDK_space:
          if (!thumb) break;
-         thumbview_set_selection (thumb, !thumb->selected);
+         gimv_thumb_view_set_selection (thumb, !thumb->selected);
          break;
       case GDK_Delete:
-         thumbview_delete_files (tv);
+         gimv_thumb_view_delete_files (tv);
          break;
       default:
          break;
@@ -251,7 +245,7 @@ cb_treeview_key_press (GtkWidget *widget,
 static gboolean
 cb_treeview_button_press (GtkWidget *widget,
                           GdkEventButton *event,
-                          ThumbView *tv)
+                          GimvThumbView *tv)
 {
    DetailViewData *tv_data;
    GtkTreeModel *model;
@@ -262,7 +256,9 @@ cb_treeview_button_press (GtkWidget *widget,
    GimvThumb *thumb = NULL;
    gboolean success, retval1 = FALSE, retval2 = FALSE;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    tv_data->dragging     = FALSE;
@@ -287,7 +283,7 @@ cb_treeview_button_press (GtkWidget *widget,
    }
 
    if (thumb) {
-      retval2 = thumbview_thumb_button_press_cb (widget, event, thumb);
+      retval2 = gimv_thumb_view_thumb_button_press_cb (widget, event, thumb);
    }
 
    if (treepath)
@@ -310,7 +306,7 @@ cb_treeview_motion_notify (GtkWidget *widget,
                            gpointer data)
 {
    DetailViewData *tv_data;
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    GtkTreeModel *model;
    GtkTreeSelection *selection;
    GtkTreePath *treepath;
@@ -319,9 +315,9 @@ cb_treeview_motion_notify (GtkWidget *widget,
    gboolean success;
    gint dx, dy;
 
-   g_return_val_if_fail (tv, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    if (tv_data->dragging) return FALSE;
@@ -348,14 +344,14 @@ cb_treeview_motion_notify (GtkWidget *widget,
    if (treepath)
       gtk_tree_path_free (treepath);
 
-   return thumbview_motion_notify_cb (widget, event, thumb);
+   return gimv_thumb_view_motion_notify_cb (widget, event, thumb);
 }
 
 
 static gboolean
 cb_treeview_button_release (GtkWidget *widget,
                             GdkEventButton *event,
-                            ThumbView *tv)
+                            GimvThumbView *tv)
 {
    DetailViewData *tv_data;
    GtkTreeModel *model;
@@ -366,7 +362,9 @@ cb_treeview_button_release (GtkWidget *widget,
    GimvThumb *thumb = NULL;
    gboolean success, retval1 = FALSE, retval2 = FALSE;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    tv_data->press_button = -1;
@@ -399,13 +397,13 @@ cb_treeview_button_release (GtkWidget *widget,
           && !(event->state & GDK_CONTROL_MASK)
           && !tv_data->dragging)
       {
-         thumbview_set_selection_all (tv, FALSE);
-         thumbview_set_selection (thumb, TRUE);
+         gimv_thumb_view_set_selection_all (tv, FALSE);
+         gimv_thumb_view_set_selection (thumb, TRUE);
       }
    }
 
    if (thumb) {
-      retval2 = thumbview_thumb_button_release_cb (widget, event, thumb);
+      retval2 = gimv_thumb_view_thumb_button_release_cb (widget, event, thumb);
    }
 
    if (treepath)
@@ -422,6 +420,53 @@ cb_treeview_button_release (GtkWidget *widget,
 }
 
 
+static gboolean
+cb_treeview_scroll (GtkWidget *widget, GdkEventScroll *se, GimvThumbView *tv)
+{
+   GdkEventButton be;
+   gboolean retval = FALSE;
+
+   g_return_val_if_fail (GTK_IS_WIDGET(widget), FALSE);
+
+   be.type       = GDK_BUTTON_PRESS;
+   be.window     = se->window;
+   be.send_event = se->send_event;
+   be.time       = se->time;
+   be.x          = se->x;
+   be.y          = se->y;
+   be.axes       = NULL;
+   be.state      = se->state;
+   be.device     = se->device;
+   be.x_root     = se->x_root;
+   be.y_root     = se->y_root;
+   switch ((se)->direction) {
+   case GDK_SCROLL_UP:
+      be.button = 4;
+      break;
+   case GDK_SCROLL_DOWN:
+      be.button = 5;
+      break;
+   case GDK_SCROLL_LEFT:
+      be.button = 6;
+      break;
+   case GDK_SCROLL_RIGHT:
+      be.button = 7;
+      break;
+   default:
+      g_warning ("invalid scroll direction!");
+      be.button = 0;
+      break;
+   }
+
+   retval = cb_treeview_button_press (widget, &be, tv);
+
+   be.type = GDK_BUTTON_RELEASE;
+   retval = cb_treeview_button_release (widget, &be, tv);
+
+   return retval;
+}
+
+
 static void
 cb_treeview_drag_data_received (GtkWidget *widget,
                                 GdkDragContext *context,
@@ -431,8 +476,8 @@ cb_treeview_drag_data_received (GtkWidget *widget,
                                 guint time,
                                 gpointer data)
 {
-   thumbview_drag_data_received_cb (widget, context, x, y,
-                                    seldata, info, time, data);
+   gimv_thumb_view_drag_data_received_cb (widget, context, x, y,
+                                          seldata, info, time, data);
 
    /* F*ck! */
    g_signal_stop_emission_by_name (G_OBJECT (widget), "drag_data_received");
@@ -440,7 +485,7 @@ cb_treeview_drag_data_received (GtkWidget *widget,
 
 
 static void
-cb_column_clicked (GtkTreeViewColumn *column, ThumbView *tv)
+cb_column_clicked (GtkTreeViewColumn *column, GimvThumbView *tv)
 {
    GimvThumbWin *tw;
    DetailViewData *tv_data;
@@ -449,12 +494,14 @@ cb_column_clicked (GtkTreeViewColumn *column, ThumbView *tv)
    GimvSortItem sort_item, current_item;
    GimvSortFlag sort_flag = 0, current_flag;
 
-   if (!tv || tv->progress) return;
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   tw = tv->thumb_window;
-   if (!tw) return;
+   if (tv->progress) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tw = tv->tw;
+   g_return_if_fail (GIMV_IS_THUMB_WIN (tw));
+
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_if_fail (tv_data && tv_data->treeview);
 
    col_list = gtk_tree_view_get_columns (GTK_TREE_VIEW (tv_data->treeview));
@@ -508,23 +555,24 @@ cb_column_clicked (GtkTreeViewColumn *column, ThumbView *tv)
  *
  ******************************************************************************/
 static DetailViewData *
-detailview_new (ThumbView *tv)
+detailview_new (GimvThumbView *tv)
 {
    DetailViewData *tv_data;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) {
       tv_data = g_new0 (DetailViewData, 1);
-      tv_data->treeview = NULL;
+      tv_data->treeview      = NULL;
       tv_data->dragging      = FALSE;
       tv_data->press_button  = -1;
       tv_data->press_mask    = -1;
       tv_data->press_x       = -1;
       tv_data->press_y       = -1;
       tv_data->set_selection = FALSE;
-      g_hash_table_insert (tv->disp_mode_data, DETAIL_VIEW_LABEL, tv_data);
+      g_object_set_data_full (G_OBJECT (tv), DETAIL_VIEW_LABEL, tv_data,
+                              (GDestroyNotify) g_free);
    }
 
    return tv_data;
@@ -532,7 +580,7 @@ detailview_new (ThumbView *tv)
 
 
 static void
-set_column_types (ThumbView *tv, DetailViewData *tv_data,
+set_column_types (GimvThumbView *tv, DetailViewData *tv_data,
                   GtkListStore *store, const gchar *dest_mode)
 {
    GtkTreeViewColumn *col;
@@ -556,8 +604,8 @@ set_column_types (ThumbView *tv, DetailViewData *tv_data,
    }
 
    if (!strcmp (DETAIL_THUMB_LABEL, dest_mode)) {
-      gint xsize = tv->ThumbnailSize + xpad * 2;
-      gint ysize = tv->ThumbnailSize + ypad * 2;
+      gint xsize = tv->thumb_size + xpad * 2;
+      gint ysize = tv->thumb_size + ypad * 2;
       gtk_cell_renderer_set_fixed_size (render, xsize, ysize);
    }
 
@@ -600,7 +648,14 @@ set_column_types (ThumbView *tv, DetailViewData *tv_data,
          break;
       }
       gtk_tree_view_column_pack_start (col, render, TRUE);
-      gtk_tree_view_column_add_attribute (col, render, "text", i);
+      gtk_tree_view_column_add_attribute (col, render,
+                                          "text", i);
+      if (!strcmp (detailview_columns[idx].title, "Name")) {
+         /*
+         gtk_tree_view_column_add_attribute (col, render,
+                                             "editable", COLUMN_EDITABLE);
+         */
+      }
 
       gtk_tree_view_append_column (GTK_TREE_VIEW (tv_data->treeview), col);
 
@@ -612,71 +667,13 @@ set_column_types (ThumbView *tv, DetailViewData *tv_data,
 
 
 static void
-detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
-{
-   GimvThumb *thumb;
-   DetailViewData *tv_data;
-   GtkTreeModel *model;
-   GList *node, *data_node;
-   gint i, j, start_pos, num, colnum;
-
-   g_return_if_fail (tv);
-   if (!start) return;
-
-   node = start;
-   start_pos = g_list_position (tv->thumblist, start);
-   num = g_list_length (node);
-   colnum = detailview_title_idx_list_num + N_COLUMN;
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_if_fail (tv_data && tv_data->treeview);
-
-   model = gtk_tree_view_get_model (GTK_TREE_VIEW (tv_data->treeview));
-
-   /* set text data */
-   for (i = start_pos ; i < num ; i++, node = g_list_next (node)) {
-      GtkTreeIter iter;
-
-      thumb = node->data;
-
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-
-      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                          COLUMN_THUMB_DATA, thumb,
-                          COLUMN_TERMINATOR);
-
-      data_node = detailview_title_idx_list;
-      for (j = N_COLUMN;
-           j < colnum && data_node;
-           j++, data_node = g_list_next (data_node))
-      {
-         gint idx = GPOINTER_TO_INT (data_node->data);
-         gchar *text = NULL;
-
-         if (detailview_columns[idx].func)
-            text = detailview_columns[idx].func (thumb);
-
-         gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                             j, text,
-                             COLUMN_TERMINATOR);
-
-         if (detailview_columns[idx].free && text)
-            g_free (text);
-      }
-
-      detailview_set_selection (thumb, thumb->selected);
-   }
-}
-
-
-static void
-detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
+detailview_set_pixmaps (GimvThumbView *tv, const gchar *dest_mode)
 {
    GimvThumb *thumb;
    GList *node;
    gint i, num;
 
-   if (!tv) return;
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
    node = g_list_first (tv->thumblist);
    num = g_list_length (node);
@@ -684,7 +681,7 @@ detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
    /* set images */
    for (i = 0 ; i < num ; i++) {
       thumb = node->data;
-      detailview_add_thumbnail (thumb, dest_mode, LOAD_CACHE);
+      detailview_update_thumbnail (tv, thumb, dest_mode);
       node = g_list_next (node);
    }
 }
@@ -697,39 +694,73 @@ detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
  *
  ******************************************************************************/
 void
-detailview_remove_thumbview_data (ThumbView *tv)
+detailview_freeze (GimvThumbView *tv)
+{
+}
+
+
+void
+detailview_thaw (GimvThumbView *tv)
+{
+}
+
+
+void
+detailview_append_thumb_frame (GimvThumbView *tv, GimvThumb *thumb,
+                               const gchar *dest_mode)
 {
    DetailViewData *tv_data;
+   GtkTreeModel *model;
+   GList *data_node;
+   gint j, pos, colnum;
+   GtkTreeIter iter;
 
-   if (!tv) return;
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   if (!tv_data) return;
+   pos = g_list_index (tv->thumblist, thumb);
+   colnum = detailview_title_idx_list_num + N_COLUMN;
 
-   g_hash_table_remove (tv->disp_mode_data, DETAIL_VIEW_LABEL); 
-   g_free (tv_data);
+   tv_data = g_object_get_data (G_OBJECT(tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->treeview);
+
+   model = gtk_tree_view_get_model (GTK_TREE_VIEW (tv_data->treeview));
+
+   gtk_list_store_insert (GTK_LIST_STORE (model), &iter, pos);
+   gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                       COLUMN_THUMB_DATA, thumb,
+                       COLUMN_TERMINATOR);
+
+   gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                       COLUMN_EDITABLE, TRUE,
+                       COLUMN_TERMINATOR);
+
+   data_node = detailview_title_idx_list;
+   for (j = N_COLUMN;
+        j < colnum && data_node;
+        j++, data_node = g_list_next (data_node))
+   {
+      gint idx = GPOINTER_TO_INT (data_node->data);
+      gchar *text = NULL;
+
+      if (detailview_columns[idx].func)
+         text = detailview_columns[idx].func (thumb);
+
+      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                          j, text,
+                          COLUMN_TERMINATOR);
+
+      if (detailview_columns[idx].free && text)
+         g_free (text);
+   }
+
+   detailview_set_selection (tv, thumb, thumb->selected);
 }
 
 
-GList *
-detailview_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
+void
+detailview_update_thumbnail (GimvThumbView  *tv, GimvThumb *thumb,
+                             const gchar *dest_mode)
 {
-   GList *loadlist = NULL;
-
-   g_return_val_if_fail (tv && start, FALSE);
-
-   detailview_redraw (tv, dest_mode, tv->container, &loadlist);
-
-   return loadlist;
-}
-
-
-GtkWidget *
-detailview_add_thumbnail (GimvThumb *thumb,
-                          gchar *dest_mode,
-                          ThumbLoadType type)
-{
-   ThumbView *tv;
    DetailViewData *tv_data;
    GdkPixmap *pixmap = NULL;
    GdkBitmap *mask;
@@ -738,13 +769,11 @@ detailview_add_thumbnail (GimvThumb *thumb,
    GtkTreeModel *model;
    GtkTreeIter iter;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, NULL);
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   g_return_val_if_fail (tv_data && tv_data->treeview, NULL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data && tv_data->treeview);
 
    node = g_list_find (tv->thumblist, thumb);
    pos = g_list_position (tv->thumblist, node);
@@ -759,13 +788,13 @@ detailview_add_thumbnail (GimvThumb *thumb,
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
 
-   if (!pixmap) return NULL;
+   if (!pixmap) return;
 
    model = gtk_tree_view_get_model (GTK_TREE_VIEW (tv_data->treeview));
    gtk_tree_model_iter_nth_child (model, &iter, NULL, row);
    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                       COLUMN_PIXMAP, pixmap,
-                       COLUMN_MASK,   mask,
+                       COLUMN_PIXMAP,   pixmap,
+                       COLUMN_MASK,     mask,
                        COLUMN_TERMINATOR);
 
    /* reset column data */
@@ -789,42 +818,19 @@ detailview_add_thumbnail (GimvThumb *thumb,
          g_free (str);
    }
 
-   return NULL;
+   return;
 }
 
 
-void
-detailview_redraw (ThumbView *tv, gchar *dest_mode,
-                   GtkWidget *scroll_win, GList **loadlist)
+GList *
+detailview_get_load_list (GimvThumbView *tv)
 {
-   DetailViewData *tv_data;
-   GList *node;
+   GList *loadlist = NULL, *node;
 
-   g_return_if_fail (tv);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   node = g_list_find (thumbview_get_list(), tv);
-   if (!node) return;
+   if (!strcmp (DETAIL_VIEW_LABEL, tv->summary_mode)) return NULL;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
-   if (!tv_data)
-      tv_data = detailview_new (tv);
-
-   if (tv_data->treeview) {
-      gtk_widget_destroy (tv_data->treeview);
-      tv_data->treeview = NULL;
-   }
-
-   if (scroll_win) {
-      if (GTK_BIN (tv->container)->child)
-         gtk_widget_destroy (GTK_BIN (tv->container)->child);   
-      tv_data->treeview = detailview_create (tv, dest_mode);
-      gtk_container_add (GTK_CONTAINER (scroll_win), tv_data->treeview);
-   }
-
-   if (!loadlist || !strcmp (DETAIL_VIEW_LABEL, dest_mode)) return;
-
-   /* create thumbnail load list */
-   *loadlist = NULL;
    for (node = tv->thumblist; node; node = g_list_next (node)) {
       GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
@@ -832,33 +838,39 @@ detailview_redraw (ThumbView *tv, gchar *dest_mode,
 
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
-         *loadlist = g_list_append (*loadlist, thumb);
+         loadlist = g_list_append (loadlist, thumb);
    }
-}
 
-
-gboolean
-detailview_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
-{
-   GtkWidget *widget;
-   ThumbView *tv;
-
-   if (!thumb) return FALSE;
-
-   tv = thumb->thumb_view;
-   if (!tv) return FALSE;
-
-   widget = detailview_add_thumbnail (thumb, tv->disp_mode, type);
-
-   if (widget)
-      return TRUE;
-   else
-      return FALSE;
+   return loadlist;
 }
 
 
 void
-detailview_adjust (ThumbView *tv, GimvThumb *thumb)
+detailview_remove_thumbnail (GimvThumbView *tv, GimvThumb *thumb)
+{
+   DetailViewData *tv_data;
+   GtkTreeModel *model;
+   GtkTreeIter iter;
+   gint pos;
+
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
+
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
+   g_return_if_fail (tv_data);
+
+   pos = g_list_index (tv->thumblist, thumb);
+   if (pos < 0) return;
+
+   model = gtk_tree_view_get_model (GTK_TREE_VIEW (tv_data->treeview));
+
+   if (gtk_tree_model_iter_nth_child (model, &iter, NULL, pos))
+      gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+}
+
+
+void
+detailview_adjust (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -867,17 +879,16 @@ detailview_adjust (ThumbView *tv, GimvThumb *thumb)
    GtkTreeIter iter;
    gboolean success;
 
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   node = g_list_find (thumbview_get_list(), tv);
+   node = g_list_find (gimv_thumb_view_get_list(), tv);
    if (!node) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_if_fail (tv_data);
 
-   node = g_list_find (tv->thumblist, thumb);
-   if (!node) return;
-   pos = g_list_position (tv->thumblist, node);
+   pos = g_list_index (tv->thumblist, thumb);
+   if (pos < 0) return;
 
    model = gtk_tree_view_get_model (GTK_TREE_VIEW (tv_data->treeview));
    success = gtk_tree_model_iter_nth_child (model, &iter, NULL, pos);
@@ -893,20 +904,18 @@ detailview_adjust (ThumbView *tv, GimvThumb *thumb)
 
 
 gboolean
-detailview_set_selection (GimvThumb *thumb, gboolean select)
+detailview_set_selection (GimvThumbView *tv, GimvThumb *thumb, gboolean select)
 {
-   ThumbView *tv;
    DetailViewData *tv_data;
    GList *node;
    gint pos;
 
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, FALSE);
    if (g_list_length (tv->thumblist) < 1) return FALSE;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data && tv_data->treeview, FALSE);
 
    node = g_list_find (tv->thumblist, thumb);
@@ -937,15 +946,15 @@ detailview_set_selection (GimvThumb *thumb, gboolean select)
 
 
 void
-detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
+detailview_set_focus (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    gint pos;
 
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
    if (g_list_length (tv->thumblist) < 1) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_if_fail (tv_data && tv_data->treeview);
 
    pos = g_list_index (tv->thumblist, thumb);
@@ -969,15 +978,15 @@ detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
 
 
 GimvThumb *
-detailview_get_focus (ThumbView *tv)
+detailview_get_focus (GimvThumbView *tv)
 {
    GimvThumb *thumb = NULL;
    DetailViewData *tv_data;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
    if (g_list_length (tv->thumblist) < 1) return NULL;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data && tv_data->treeview, NULL);
 
    {
@@ -1001,7 +1010,7 @@ detailview_get_focus (ThumbView *tv)
 
 
 gboolean
-detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
+detailview_thumbnail_is_in_viewport (GimvThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -1014,10 +1023,10 @@ detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
    GimvThumb *tmp_thumb;
    gboolean success;
 
-   g_return_val_if_fail (tv, FALSE);
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    node = g_list_find (tv->thumblist, thumb);
@@ -1063,23 +1072,26 @@ detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 
 
 GtkWidget *
-detailview_create (ThumbView *tv, gchar *dest_mode)
+detailview_create (GimvThumbView *tv, const gchar *dest_mode)
 {
    DetailViewData *tv_data;
    GtkListStore *store;
    GtkTreeSelection *selection;
-   GType types[32];
+   GType types[128];
    const gint ntypes   = sizeof (types) / sizeof (GType);
    gint i, ncolumns;
    gboolean show_title;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
    detailview_create_title_idx_list ();
    ncolumns = detailview_title_idx_list_num + N_COLUMN;
-   g_return_val_if_fail (ncolumns < ntypes, NULL);
+   if (ncolumns > ntypes) {
+      g_warning("Too many columns are specified: %d\n", ncolumns - N_COLUMN);
+      ncolumns = ntypes;
+   }
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
+   tv_data = g_object_get_data (G_OBJECT (tv), DETAIL_VIEW_LABEL);
    if (!tv_data) {
       tv_data = detailview_new (tv);
       g_return_val_if_fail (tv_data, NULL);
@@ -1087,7 +1099,6 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
 
 
    /* create tree view widget */
-
    store = gtk_list_store_new (1, G_TYPE_STRING);   /* this column is dummy */
 
    /* set real columns */
@@ -1096,6 +1107,7 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
    types[COLUMN_THUMB_DATA] = G_TYPE_POINTER;
    types[COLUMN_PIXMAP]     = GDK_TYPE_PIXMAP;
    types[COLUMN_MASK]       = GDK_TYPE_PIXMAP;
+   types[COLUMN_EDITABLE]   = G_TYPE_BOOLEAN;
    gtk_list_store_set_column_types (store, ncolumns, types);
 
    tv_data->treeview
@@ -1103,7 +1115,7 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
 
    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tv_data->treeview), TRUE);
    set_column_types (tv, tv_data, store, dest_mode);
-   detailview_prefs_get_value ("show_title", (gpointer *) &show_title);
+   detailview_prefs_get_value ("show_title", (gpointer) &show_title);
    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tv_data->treeview),
                                       show_title);
 
@@ -1123,17 +1135,20 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
    gtk_widget_show (tv_data->treeview);
 
    g_signal_connect (G_OBJECT (tv_data->treeview),
-                     "key_press_event",
+                     "key-press-event",
                      G_CALLBACK (cb_treeview_key_press), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview),
-                     "button_press_event",
+                     "button-press-event",
                      G_CALLBACK (cb_treeview_button_press), tv);
-   SIGNAL_CONNECT_TRANSRATE_SCROLL (tv_data->treeview);
    g_signal_connect (G_OBJECT (tv_data->treeview),
-                     "button_release_event",
+                     "scroll-event",
+                     G_CALLBACK (cb_treeview_scroll), tv);
+   /* SIGNAL_CONNECT_TRANSRATE_SCROLL (tv_data->treeview); */
+   g_signal_connect (G_OBJECT (tv_data->treeview),
+                     "button-release-event",
                      G_CALLBACK (cb_treeview_button_release), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview),
-                     "motion_notify_event",
+                     "motion-notify-event",
                      G_CALLBACK (cb_treeview_motion_notify), tv);
 
    /* for drop file list */
@@ -1141,22 +1156,26 @@ detailview_create (ThumbView *tv, gchar *dest_mode)
    dnd_dest_set (tv_data->treeview, detailview_dnd_targets, detailview_dnd_targets_num);
 
    g_signal_connect (G_OBJECT (tv_data->treeview), "drag_begin",
-                     G_CALLBACK (thumbview_drag_begin_cb), tv);
+                     G_CALLBACK (gimv_thumb_view_drag_begin_cb), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview), "drag_data_get",
-                     G_CALLBACK (thumbview_drag_data_get_cb), tv);
+                     G_CALLBACK (gimv_thumb_view_drag_data_get_cb), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview), "drag_data_received",
                      G_CALLBACK (cb_treeview_drag_data_received), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview), "drag-data-delete",
-                     G_CALLBACK (thumbview_drag_data_delete_cb), tv);
+                     G_CALLBACK (gimv_thumb_view_drag_data_delete_cb), tv);
    g_signal_connect (G_OBJECT (tv_data->treeview), "drag_end",
-                     G_CALLBACK (thumbview_drag_end_cb), tv);
+                     G_CALLBACK (gimv_thumb_view_drag_end_cb), tv);
    g_object_set_data (G_OBJECT (tv_data->treeview), "gimv-tab", tv);
 
 
    /* set data */
+   if (tv->thumblist) {
+      GList *node;
 
-   detailview_set_text_data (tv, dest_mode, tv->thumblist);
-   detailview_set_pixmaps (tv, dest_mode);
+      for (node = tv->thumblist; node; node = g_list_next (node))
+         detailview_append_thumb_frame (tv, node->data, dest_mode);
+      detailview_set_pixmaps (tv, dest_mode);
+   }
 
    return tv_data->treeview;
 }
