@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 3; indent-tabs-mode: nil; c-basic-offset: 3 -*- */
+
 /*
  * GImageView
  * Copyright (C) 2001 Takuro Ashie
@@ -15,14 +17,18 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * $Id: argparse.h,v 1.6 2002/10/02 19:05:00 makeinu Exp $
  */
 
 #ifndef __ARGPARSE_H__
 #define __ARGPARSE_H__
 
 #include <stdio.h>
+#include <gtk/gtk.h>
 
-typedef enum {
+typedef enum
+{
    ARG_NOERR,
    ARG_WITH_VAL,
    ARG_NO_VAL,
@@ -39,8 +45,21 @@ struct arg_opt
    const char *doc;
 };
 
-void arg_version ();
-void arg_help    (char *argv[], FILE *stream);
-void arg_parse   (int argc, char *argv[], int *remaining);
+typedef struct ArgsVal_Tag
+{
+   gboolean read_dir;
+   gboolean read_dir_recursive;
+   gboolean read_dot;
+   gboolean ignore_ext;
+   gboolean open_imagewin;
+   gboolean open_thumbwin;
+   gboolean exec_slideshow;
+   gfloat   slideshow_interval;     /* [sec] */
+} ArgsVal;
+
+void arg_version   (void);
+void arg_help      (char *argv[], FILE *stream);
+void arg_parse     (int argc, char *argv[], int *remaining);
+void args_val_init (void);
 
 #endif /* __ARGPARSE_H__ */
