@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: charset.c,v 1.10 2003/06/13 09:43:23 makeinu Exp $
+ * $Id: charset.c,v 1.11 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #include <string.h>
 #include "charset.h"
 #include "intl.h"
+#include "japanese.h"
 
 #ifdef USE_GTK2
 #
@@ -45,8 +46,6 @@ extern const char *locale_charset (void);
 #endif /* USE_GTK2 */
 
 
-extern const gchar *japanese_locale_charset (const gchar *locale);
-
 CharsetDetectLocaleFn charset_locale_fn_table[] = {
    japanese_locale_charset,
 };
@@ -72,10 +71,6 @@ gchar *charset_ascii_defs[] = {
 };
 gint charset_ascii_defs_num = sizeof (charset_ascii_defs) / sizeof (gchar*);
 
-extern gchar *japanese_conv (const gchar *src,
-                             const gchar *src_codeset,
-                             const gchar *dest_codeset);
-
 CharsetConvFn charset_conv_fn_table[] = {
    japanese_conv,
 };
@@ -141,8 +136,6 @@ charset_get_known_list (const gchar *lang)
  *  auto detect method for each language.
  *
  ******************************************************************************/
-extern const gchar *japanese_detect_charset (const gchar *str);
-
 CharsetAutoDetectFn auto_detect_fn_table[] ={
    NULL,
    japanese_detect_charset,
@@ -158,7 +151,7 @@ const gchar *charset_auto_detect_labels[] = {
 CharsetAutoDetectFn
 charset_get_auto_detect_func (CharsetAutoDetectType type)
 {
-   gint num = sizeof (auto_detect_fn_table) / sizeof (CharsetAutoDetectFn);
+   guint num = sizeof (auto_detect_fn_table) / sizeof (CharsetAutoDetectFn);
 
    if (type < 0 || type > num) return NULL;
 
