@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: charset.h,v 1.9 2003/06/13 09:43:23 makeinu Exp $
+ * $Id: charset.h,v 1.10 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #ifndef __CHARSET_H__
@@ -87,8 +87,8 @@ const gchar *get_lang               (void);
 /* wrapper for nl_langinfo() */
 void         charset_set_locale_charset   (const gchar *charset);
 void         charset_set_internal_charset (const gchar *charset);
-const gchar *charset_get_locale           ();
-const gchar *charset_get_internal         ();
+const gchar *charset_get_locale           (void);
+const gchar *charset_get_internal         (void);
 CharsetAutoDetectFn charset_get_auto_detect_func (CharsetAutoDetectType type);
 
 
