@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: compare_md5.c,v 1.3 2003/06/18 09:26:55 makeinu Exp $
+ * $Id: compare_md5.c,v 1.4 2004/04/08 10:38:50 makeinu Exp $
  */
 
 /*
@@ -96,7 +96,7 @@ duplicates_md5_get_data (GimvThumb *thumb)
    guchar bin_buffer[DIGEST_BIN_BYTES + 1];
    gboolean success;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB(thumb), NULL);
    g_return_val_if_fail (thumb->info, NULL);
 
    if (gimv_image_info_need_temp_file (thumb->info)) {
