@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: compare_similar.c,v 1.3 2003/06/18 09:26:55 makeinu Exp $
+ * $Id: compare_similar.c,v 1.4 2004/04/08 10:38:50 makeinu Exp $
  */
 
 /*
@@ -199,7 +199,7 @@ image_sim_new_from_thumb (GimvThumb *thumb)
    GdkBitmap *mask;
    ImageSimilarityData *data;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB(thumb), NULL);
 
    if (!gimv_thumb_has_thumbnail (thumb)) return NULL;
 
