@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview.c,v 1.77 2003/07/24 15:33:03 makeinu Exp $
+ * $Id: dirview.c,v 1.81 2004/09/21 08:44:31 makeinu Exp $
  */
 
 /*
@@ -306,7 +306,6 @@ dirview_create_ctree (DirView *dv)
                        GTK_SIGNAL_FUNC (cb_button_press), dv);
    gtk_signal_connect (GTK_OBJECT (dirtree),"button_release_event",
                        GTK_SIGNAL_FUNC (cb_button_release), dv);
-   SIGNAL_CONNECT_TRANSRATE_SCROLL(dirtree);
 
    gtk_signal_connect (GTK_OBJECT(dirtree), "key-press-event",
                        GTK_SIGNAL_FUNC (cb_key_press), dv);
@@ -471,7 +470,7 @@ dirview_insert_node (DirView *dv, GtkCTreeNode *parent, const gchar *path)
          dirview_insert_dummy_node (dv, node);
 
       /* set mark */
-      if (thumbview_find_opened_dir (dirnode->path)) {
+      if (gimv_thumb_view_find_opened_dir (dirnode->path)) {
          dirview_set_opened_mark (dv, dirnode->path);
       }
    }
@@ -716,21 +715,21 @@ idle_dirview_button_action (gpointer data)
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR_NONE);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR_NONE);
       }
       break;
    case MouseActLoadThumbRecursive:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR);
       }
       break;
    case MouseActLoadThumbRecursiveInOneTab:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR_ONE_TAB);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR_ONE_TAB);
       }
       break;
    case MouseActChangeTop:
@@ -1122,7 +1121,7 @@ cb_key_press (GtkWidget *widget, GdkEventKey *event, DirView *dv)
          if (!strcmp (node_text, ".") || !strcmp (node_text, "..")) {
             dirview_change_root (dv, dirnode->path);
          } else {
-            open_dir_images (dirnode->path, dv->tw,
+            open_dir_images (dirnode->path, dv->tw, NULL,
                              LOAD_CACHE, conf.scan_dir_recursive);
          }
          break;
@@ -1175,7 +1174,7 @@ cb_open_thumbnail (DirView *dv, ScanSubDirType scan_subdir, GtkWidget *menuitem)
    path = dirview_get_selected_path (dv);
    if (!path) return;
 
-   open_dir_images (path, dv->tw, LOAD_CACHE, scan_subdir);
+   open_dir_images (path, dv->tw, NULL, LOAD_CACHE, scan_subdir);
 
    g_free (path);
 }
@@ -1242,7 +1241,8 @@ cb_mkdir (DirView *dv, guint action, GtkWidget *menuitem)
    dirnode = gtk_ctree_node_get_row_data (GTK_CTREE(dv->dirtree), node);
    if (!dirnode) return;
 
-   success = make_dir_dialog (dirnode->path, GTK_WINDOW (dv->window));
+   success = make_dir_dialog
+      (dirnode->path, GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
    if (success) {
       refresh_dir_tree (dv, node);
@@ -1264,7 +1264,8 @@ cb_rename_dir (DirView *dv, guint action, GtkWidget *menuitem)
    dirnode = gtk_ctree_node_get_row_data (GTK_CTREE(dv->dirtree), node);
    if (!dirnode) return;
 
-   success = rename_dir_dialog (dirnode->path, GTK_WINDOW (dv->window));
+   success = rename_dir_dialog
+      (dirnode->path, GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
    if (success) {
       parent = (GTK_CTREE_ROW (node))->parent;
@@ -1290,7 +1291,7 @@ cb_delete_dir (DirView *dv, guint action, GtkWidget *menuitem)
 
    path = remove_slash (dirnode->path);
 
-   delete_dir (path, GTK_WINDOW (dv->window));
+   delete_dir (path, GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
    g_free (path);
 
    /* refresh dir tree */
@@ -1524,8 +1525,9 @@ cb_drag_data_received (GtkWidget *dirtree,
          g_snprintf (error_message, BUF_SIZE,
                      _("Permission denied: %s"),
                      dir_internal);
-         gtkutil_message_dialog (_("Error!!"), error_message,
-                                 GTK_WINDOW (dv->window));
+         gtkutil_message_dialog
+            (_("Error!!"), error_message,
+             GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
          g_free (dir_internal);
       }
@@ -1687,7 +1689,7 @@ dirview_change_root (DirView *dv, const gchar *root_dir)
    if (!root_node) return;
 
    /* set opened mark */
-   if (thumbview_find_opened_dir (dv->root_dir)) {
+   if (gimv_thumb_view_find_opened_dir (dv->root_dir)) {
       dirview_set_opened_mark (dv, dv->root_dir);
    }
 
@@ -1731,7 +1733,7 @@ dirview_change_dir (DirView *dv, const gchar *str)
    GtkCTreeNode *node;
    gchar *path, *row, *ptr;
    gboolean is_leaf, expanded;
-   gint length;
+   size_t length;
 
    g_return_if_fail (dv);
 
@@ -1975,15 +1977,9 @@ dirview_create_toolbar (DirView *dv)
    GtkWidget *toolbar;
    GtkWidget *button;
    GtkWidget *iconw;   
-   GtkWidget *container;
 
    g_return_val_if_fail (dv, NULL);
 
-   if (dv->tw)
-      container = GTK_WIDGET (dv->tw);
-   else
-      container = dv->window;
-
    toolbar = gtkutil_create_toolbar ();
 
    /* file open button */
@@ -2077,10 +2073,6 @@ dirview_create (const gchar *root_dir, GtkWidget *parent_win, GimvThumbWin *tw)
    else
       dv->root_dir = g_strdup (home);
 
-   if (tw)
-      dv->window = GTK_WIDGET (tw);
-   else
-      dv->window = NULL;
    dv->popup_menu        = NULL;
    dv->tw                = tw;
    dv->show_toolbar      = conf.dirview_show_toolbar;
