@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview2.c,v 1.37 2004/09/22 14:26:22 makeinu Exp $
+ * $Id: dirview2.c,v 1.38 2004/12/20 14:53:45 makeinu Exp $
  */
 
 #include "dirview.h"
@@ -1283,6 +1283,26 @@ insert_row (GtkTreeStore *store,
 }
 
 
+static gboolean
+is_in_view (GtkTreeView *treeview, GtkTreePath *treepath)
+{
+   GdkRectangle widget_area, cell_area;
+
+   if (!GTK_WIDGET_REALIZED (treeview))
+      return FALSE;
+
+   /* widget area */
+   gtkutil_get_widget_area (GTK_WIDGET (treeview), &widget_area);
+
+   gtk_tree_view_get_cell_area(treeview, treepath, NULL, &cell_area);
+
+   if (cell_area.y >= 0 && cell_area.y < widget_area.height)
+      return TRUE;
+   else
+      return FALSE;
+}
+
+
 static void
 adjust_tree (GtkTreeView *treeview, GtkTreeIter *iter)
 {
@@ -1305,8 +1325,9 @@ adjust_tree (GtkTreeView *treeview, GtkTreeIter *iter)
    }
 
    gtk_tree_selection_select_path (selection, treepath);
-   gtk_tree_view_scroll_to_cell (treeview, treepath, NULL,
-                                 TRUE, 0.0, 0.0);
+   if (!is_in_view(treeview, treepath))
+      gtk_tree_view_scroll_to_cell (treeview, treepath, NULL,
+                                    TRUE, 0.0, 0.0);
 
  FUNC_END:
    gtk_tree_path_free (treepath);
@@ -1826,7 +1847,7 @@ dirview_change_dir (DirView *dv, const gchar *str)
    GtkTreeModel *model;
    GtkTreeIter iter;
    gchar *destpath;
-   gboolean success;
+  gboolean success;
 
    g_return_if_fail (dv);
 
