@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dither.c,v 1.5 2003/06/13 09:43:25 makeinu Exp $
+ * $Id: dither.c,v 1.6 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #include <gtk/gtk.h>
@@ -54,7 +54,7 @@ ERROR0:
 }
 
 
-void ditherfinish()
+void ditherfinish(void)
 {
    if (evenerr) {
       g_free (evenerr);
