@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dither.h,v 1.5 2003/06/13 09:43:25 makeinu Exp $
+ * $Id: dither.h,v 1.6 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #ifndef __DITHER_H__
 #define __DITHER_H__
 
 guchar *ditherinit   (gint w);
-void    ditherfinish ();
+void    ditherfinish (void);
 void    ditherline   (guchar *theline,
                       gint    linenum,
                       gint    width);
