@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: exif_view.c,v 1.20 2003/08/01 13:41:06 makeinu Exp $
+ * $Id: exif_view.c,v 1.23 2004/09/22 15:37:11 makeinu Exp $
  */
 
 #include "gimageview.h"
@@ -87,7 +87,7 @@ exif_view_content_list_set_data (GtkWidget *clist,
                                  ExifContent *content)
 {
    const gchar *text[2];
-   gint i;
+   guint i;
 
    g_return_if_fail (clist);
    g_return_if_fail (content);
@@ -289,6 +289,10 @@ exif_view_create (const gchar *filename, GtkWindow *parent)
       scrolledwin = gtk_scrolled_window_new (NULL, NULL);
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
                                       GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+#ifdef USE_GTK2
+      gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+                                          GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
       gtk_container_set_border_width (GTK_CONTAINER (scrolledwin), 5);
       gtk_notebook_append_page (GTK_NOTEBOOK(notebook),
                                 scrolledwin, label);
