@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: fileload.c,v 1.46 2003/06/18 09:26:55 makeinu Exp $
+ * $Id: fileload.c,v 1.50 2004/06/17 03:49:42 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -43,8 +43,8 @@
 #include "gimv_icon_stock.h"
 #include "gimv_image_info.h"
 #include "gimv_image_win.h"
+#include "gimv_thumb_view.h"
 #include "gimv_thumb_win.h"
-#include "thumbnail_view.h"
 
 
 /* for filebrowser call back functions */
@@ -106,12 +106,6 @@ files_loader_new (void)
 }
 
 
-/*
- *  files_loader_delete:
- *     @ Free all data of FilesLoader structure
- *
- *  files : Pointer to FilesLoader structure.
- */
 void
 files_loader_delete (FilesLoader *files)
 {
@@ -194,13 +188,6 @@ cb_file_load_stop   (GtkWidget *widget, FilesLoader *files)
 }
 
 
-/*
- *  file_open_progress_window:
- *     @ Create popup window contains progress bar and stop button
- *       for image file open in image view window.
- *
- *  files : Pointer to FilesLoader structure (include various data for file open).
- */
 void
 files_loader_create_progress_window (FilesLoader *files)
 {
@@ -282,12 +269,6 @@ files_loader_progress_update (FilesLoader *files,
 }
 
 
-/*
- *  open_image_files_in_image_view:
- *
- *  files  : Pointer to FilesLoader structure.
- *  Return : Return TRUE if success or canceled by user.
- */
 gint
 open_image_files_in_image_view (FilesLoader *files)
 {
@@ -332,7 +313,7 @@ open_image_files_in_image_view (FilesLoader *files)
       /* Open Archive File */
       if (fr_archive_utils_get_file_name_ext (filename)) {
          g_print (_("The file is archive: %s\n"), filename);
-         open_archive_images (filename, NULL, LOAD_CACHE);
+         open_archive_images (filename, NULL, NULL, LOAD_CACHE);
 
          /* open iamge window */
       } else {
@@ -373,23 +354,12 @@ select_thumbnail_window (GimvThumbWin *tw)
 }
 
 
-/*
- *  open_image_files_in_thumbnail_view:
- *     @ Open images in thumbnail. Thumbnail view window and page will be
- *       selected automatically.
- *
- *  files  : Pointer to FilesLoader structure.
- *  tw     : Thumbnail window for open thumbnail
- *           (Pointer to ThumbWindow structure).
- *           if this value is NULL, choose other window or create it.
- *  Return : Return TRUE if success or canceled by user.
- */
 gint
-open_image_files_in_thumbnail_view (FilesLoader *files, GimvThumbWin *tw)
+open_image_files_in_thumbnail_view (FilesLoader *files,
+                                    GimvThumbWin *tw, GimvThumbView *tv_org)
 {
-   GimvThumbWin *tw_tmp;
-   ThumbView  *tv;
-   GtkWidget   *newtab;
+   GimvThumbWin  *tw_tmp;
+   GimvThumbView *tv;
 
    if (g_list_length(files->filelist) < 1) {
       return FALSE;
@@ -403,26 +373,17 @@ open_image_files_in_thumbnail_view (FilesLoader *files, GimvThumbWin *tw)
    /* select notebook page and open files */
    tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
 
-   if (tv && tv->mode == THUMB_VIEW_MODE_COLLECTION) {
-      thumbview_append_thumbnail (tv, files, FALSE);
+   if (!tv_org && tv && tv->mode == GIMV_THUMB_VIEW_MODE_COLLECTION) {
+      gimv_thumb_view_append_thumbnail (tv, files, FALSE);
    } else {
-      if (!(tw_tmp->pagenum) || tv) {
-         newtab = gimv_thumb_win_create_new_tab (tw_tmp);
-         if (!newtab)
-            return FALSE;
-      } else {
-         gint pagenum;
-         pagenum = gtk_notebook_get_current_page (GTK_NOTEBOOK(tw_tmp->notebook));
-         newtab = gtk_notebook_get_nth_page (GTK_NOTEBOOK(tw_tmp->notebook), pagenum);
-      }
+      if (tv_org)
+         tv = tv_org;
+      else
+         tv = gimv_thumb_win_create_new_tab (tw_tmp);
+      gimv_thumb_view_reload (tv, files, GIMV_THUMB_VIEW_MODE_COLLECTION);
 
-      /* open thumbnails */
-      tv = thumbview_create (files, tw_tmp, newtab, THUMB_VIEW_MODE_COLLECTION);
-
-      if (files->status == STOP || files->status < 0) {
+      if (files->status == STOP || files->status < 0)
          return files->status;
-      } else if (!tv)
-         return FALSE;
    }
 
    gimv_thumb_win_set_statusbar_page_info (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
@@ -431,13 +392,6 @@ open_image_files_in_thumbnail_view (FilesLoader *files, GimvThumbWin *tw)
 }
 
 
-/*
- *  open_image_files:
- *     @ Open image files. Window type will be automatically selected.
- *
- *  files  : Pointer to FilesLoader structure.
- *  Return : TRUE if success or canceled by user.
- */
 gint
 open_image_files (FilesLoader *files)
 {
@@ -446,34 +400,22 @@ open_image_files (FilesLoader *files)
    }
 
    if (conf.default_file_open_window == THUMBNAIL_WINDOW)
-      return open_image_files_in_thumbnail_view (files, NULL);
+      return open_image_files_in_thumbnail_view (files, NULL, NULL);
    else
       return open_image_files_in_image_view (files);
 }
 
 
-/*
- *  open_dir_images:
- *     @ Open all image files in specified directory.
- *
- *  dirname : Directory to scan.
- *  tw      : Thumbnail window for open.
- *            If this value is NULL, select automaticaly
- *            (include use image window or not).
- *  type    : How load thumbail.
- *  gboolean: scan subdir or not.
- *  Return  : Return TRUE if success or canceled by user. 
- */
 gint
 open_dir_images (const gchar   *dir,
                  GimvThumbWin  *tw,
+                 GimvThumbView *tv_org,
                  ThumbLoadType  type,
                  ScanSubDirType scan_subdir)
 {
    FilesLoader *files;
    GimvThumbWin *tw_tmp = NULL;
-   ThumbView *tv;
-   GtkWidget *newtab;
+   GimvThumbView *tv;
    gint retval = FALSE, flags;
    gchar *dirname;
    gboolean open_in_one_tab = FALSE;
@@ -506,12 +448,12 @@ open_dir_images (const gchar   *dir,
       return NO_OPEN_FILE;
    }
 
-   tv = thumbview_find_opened_dir (dirname);
-   if (tv && (tw || (!tw && conf.default_dir_open_window == THUMBNAIL_WINDOW))
+   tv = gimv_thumb_view_find_opened_dir (dirname);
+   if (!tv_org && tv && (tw || (!tw && conf.default_dir_open_window == THUMBNAIL_WINDOW))
        && scan_subdir != SCAN_SUB_DIR_ONE_TAB)
    {
       gint pagenum;
-      tw_tmp = tv->thumb_window;
+      tw_tmp = tv->tw;
       gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
       pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (tw_tmp->notebook),
                                        tv->container);
@@ -564,29 +506,20 @@ open_dir_images (const gchar   *dir,
       if (conf.thumbwin_raise_window)
          gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
 
-      tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
-      if (tw_tmp->pagenum < 1 || tv) {
-         newtab = gimv_thumb_win_create_new_tab (tw_tmp);
-         if (!newtab)
-            goto FUNC_END;
-      } else {
-         gint pagenum;
-         pagenum = gtk_notebook_get_current_page (GTK_NOTEBOOK(tw_tmp->notebook));
-         newtab = gtk_notebook_get_nth_page (GTK_NOTEBOOK(tw_tmp->notebook), pagenum);
-      }
+      if (tv_org)
+         tv = tv_org;
+      else
+         tv = gimv_thumb_win_create_new_tab (tw_tmp);
 
-      /* open thumbnails */
       if (open_in_one_tab) {
-         tv = thumbview_create (files, tw_tmp, newtab, THUMB_VIEW_MODE_RECURSIVE_DIR);
+         gimv_thumb_view_reload (tv, files, GIMV_THUMB_VIEW_MODE_RECURSIVE_DIR);
       } else {
-         tv = thumbview_create (files, tw_tmp, newtab, THUMB_VIEW_MODE_DIR);
+         gimv_thumb_view_reload (tv, files, GIMV_THUMB_VIEW_MODE_DIR);
       }
 
       /* error handling */
       if (files->status == STOP || files->status < 0) {
          retval = files->status;
-      } else if (!tv) {
-         goto FUNC_END;
       } else {
          retval = THUMB_LOAD_DONE;
       }
@@ -699,14 +632,13 @@ cb_archive_destroy (FRArchive *archive,
 
 
 gint
-open_archive_images (const gchar   *filename,
-                     GimvThumbWin  *tw,
-                     ThumbLoadType  type)
+open_archive_images (const gchar *filename,
+                     GimvThumbWin *tw, GimvThumbView *tv_org,
+                     ThumbLoadType type)
 {
    FRArchive *archive;
    GimvThumbWin *tw_tmp;
-   ThumbView *tv;
-   GtkWidget *newtab;
+   GimvThumbView *tv;
    gboolean success;
    gchar *ext, *temp_dir;
    FilesLoader *files;
@@ -715,10 +647,10 @@ open_archive_images (const gchar   *filename,
 
    g_return_val_if_fail (filename, THUMB_LOAD_DONE);
 
-   tv = thumbview_find_opened_archive (filename);
-   if (tv) {
+   tv = gimv_thumb_view_find_opened_archive (filename);
+   if (!tv_org && tv) {
       gint pagenum;
-      tw_tmp = tv->thumb_window;
+      tw_tmp = tv->tw;
       gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
       pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (tw_tmp->notebook),
                                        tv->container);
@@ -772,14 +704,10 @@ open_archive_images (const gchar   *filename,
    tw_tmp = select_thumbnail_window (tw);
    if (!tw_tmp) goto ERROR;
 
-   tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
-   if (tw_tmp->pagenum < 1 || tv) {
-      newtab = gimv_thumb_win_create_new_tab (tw_tmp);
-   } else {
-      gint pagenum;
-      pagenum = gtk_notebook_get_current_page (GTK_NOTEBOOK(tw_tmp->notebook));
-      newtab = gtk_notebook_get_nth_page (GTK_NOTEBOOK(tw_tmp->notebook), pagenum);
-   }
+   if (tv_org)
+      tv = tv_org;
+   else
+      tv = gimv_thumb_win_create_new_tab (tw_tmp);
 
    /* get file list from archive */
    success = fr_archive_load (archive, filename);
@@ -796,7 +724,7 @@ open_archive_images (const gchar   *filename,
    gtk_main ();   /* wait */
 
    if (archive->process->error == FR_PROC_ERROR_NONE) {
-      tv = thumbview_create (files, tw_tmp, newtab, THUMB_VIEW_MODE_ARCHIVE);
+      gimv_thumb_view_reload (tv, files, GIMV_THUMB_VIEW_MODE_ARCHIVE);
    }
 
 ERROR:
@@ -817,14 +745,6 @@ ERROR:
 }
 
 
-/*
- *  open_dirs:
- *     @ Open some directories.
- *
- *  files  : Pointer to FilesLoader structure.
- *  type   : How load thumbail (from cache or create from original image).
- *  Return : Return TRUE if success or canceled by user. 
- */
 gint
 open_dirs (FilesLoader *files, GimvThumbWin *tw,
            ThumbLoadType type, gboolean scan_subdir)
@@ -840,7 +760,7 @@ open_dirs (FilesLoader *files, GimvThumbWin *tw,
 
          while (gtk_events_pending()) gtk_main_iteration();
 
-         status = open_dir_images (files->dirlist->data, tw,
+         status = open_dir_images (files->dirlist->data, tw, NULL,
                                    type, scan_subdir);
 
          if (files->status == STOP || files->status < 0
@@ -860,15 +780,6 @@ open_dirs (FilesLoader *files, GimvThumbWin *tw,
 }
 
 
-/*
- *  open_images_dirs:
- *     @ Open some images and directories.
- *     @ Open window is selected automatically.
- *
- *  files  : Pointer to FilesLoader structure.
- *  type   : How load thumbail (from cache or create from original image).
- *  Return : Return TRUE if success or canceled by user. 
- */
 gint
 open_images_dirs (GList *list, GimvThumbWin *tw,
                   ThumbLoadType type, gboolean scan_subdir)
@@ -898,7 +809,7 @@ open_images_dirs (GList *list, GimvThumbWin *tw,
 
    if (files->filelist) {
       if (tw)
-         retval = open_image_files_in_thumbnail_view (files, tw);
+         retval = open_image_files_in_thumbnail_view (files, tw, NULL);
       else
          retval = open_image_files (files);
    }
@@ -912,14 +823,6 @@ open_images_dirs (GList *list, GimvThumbWin *tw,
 }
 
 
-/*
- *  filebrowser_open_files:
- *     @ Get selected files from filebrowser clist and open it.
- *
- *  filesel : Pointer to FileSel structure that store
- *            GtkFileSelection and thumbnail window for open.
- *  type    : Window type for open.
- */
 static void
 filebrowser_open_files (FileSel *filesel, ImgWinType type)
 {
@@ -945,7 +848,7 @@ filebrowser_open_files (FileSel *filesel, ImgWinType type)
 
    if (type == THUMBNAIL_WINDOW) {
       files->status = THUMB_LOADING;
-      open_image_files_in_thumbnail_view (files, filesel->tw);
+      open_image_files_in_thumbnail_view (files, filesel->tw, NULL);
    } else {
       files->status = IMAGE_LOADING;
       open_image_files_in_image_view (files);
@@ -988,7 +891,7 @@ filebrowser_open_files (FileSel *filesel, ImgWinType type)
 
       if (type == THUMBNAIL_WINDOW) {
          files->status = THUMB_LOADING;
-         open_image_files_in_thumbnail_view (files, filesel->tw);
+         open_image_files_in_thumbnail_view (files, filesel->tw, NULL);
       } else {
          files->status = IMAGE_LOADING;
          open_image_files_in_image_view (files);
@@ -1035,15 +938,6 @@ cb_filebrowser_add_thumbnail (GtkWidget *widget, FileSel *filesel)
 }
 
 
-/*
- *  cb_filebrowser_ok_sel:
- *     @ Callback function for filebrowser "OK" button.
- *       If specfied path is file, open in image window (Not look config).
- *       If directory, open window type is automatically ditermined.
- *
- *  widget  :
- *  filesel : User data (Pointer to GtkFileSelection thumbnail window for open).
- */
 static void
 cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
 {
@@ -1062,12 +956,12 @@ cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
    if (!stat(filename, &st)) {
       /* if path is directory */
       if (S_ISDIR(st.st_mode)) {
-         open_dir_images(filename, filesel->tw, LOAD_CACHE,
+         open_dir_images(filename, filesel->tw, NULL, LOAD_CACHE,
                          conf.scan_dir_recursive);
 
          /* if path is archvie file */
       } else if (fr_archive_utils_get_file_name_ext (filename)) {
-         open_archive_images (filename, filesel->tw, LOAD_CACHE);
+         open_archive_images (filename, filesel->tw, NULL, LOAD_CACHE);
 
          /* if path is file */
       } else if (!(conf.detect_filetype_by_ext)
@@ -1113,7 +1007,7 @@ cb_filebrowser_close (GtkWidget *widget, gpointer parent)
 GtkWidget *
 create_filebrowser (gpointer parent)
 {
-   GtkWidget *filebrowser, *bbox, *add_selected, *add_all, *label;
+   GtkWidget *filebrowser, *bbox, *add_selected, *add_all;
    FileSel *filesel;
 
    filebrowser = gtk_file_selection_new(_("Load file(s)"));
@@ -1174,6 +1068,11 @@ create_filebrowser (gpointer parent)
                       filesel);
    gtk_widget_show_all(bbox);
 
+#if 0
+   /*
+    * 2004-06-17 Takuro Ashie <ashie@homa.ne.jp>
+    * This code causes clash on latest Gtk+2.
+    */
    /*
     * Change the Cancel buttons caption to Close.
     */
@@ -1183,6 +1082,7 @@ create_filebrowser (gpointer parent)
                         gtk_container_children(GTK_CONTAINER(GTK_FILE_SELECTION(filebrowser)->cancel_button))->data);
    gtk_container_add(GTK_CONTAINER(GTK_FILE_SELECTION(filebrowser)->cancel_button), label);
    gtk_widget_show(label);
+#endif
 
    gtk_widget_show(filebrowser);
 
