@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: fr-archive.h,v 1.12 2003/06/13 09:43:27 makeinu Exp $
+ *  $Id: fr-archive.h,v 1.13 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #ifndef ARCHIVE_H
@@ -125,4 +125,11 @@ void         fr_archive_extract               (FRArchive *archive,
 
 gchar *      fr_archive_utils_get_file_name_ext (const char  *filename);
 
+/* for plugin loader */
+
+gboolean     fr_archive_plugin_regist         (const gchar *plugin_name,
+                                               const gchar *module_name,
+                                               gpointer     impl,
+                                               gint         size);
+
 #endif /* ARCHIVE_H */
