@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gfileutil.c,v 1.41 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: gfileutil.c,v 1.43 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #include <gtk/gtk.h>
@@ -37,6 +37,7 @@
 #include "gimv_comment.h"
 #include "gimv_image.h"
 #include "gimv_thumb.h"
+#include "gimv_thumb_cache.h"
 #include "gtkutils.h"
 #include "intl.h"
 #include "prefs.h"
@@ -292,7 +293,7 @@ get_dir_all (const gchar *dirname)
  *  dirname :
  *  Return  :
  */
-GList *
+static GList *
 get_dir_all_file (const gchar *dirname)
 {
    GList *filelist, *dirlist, *sub_dirlist, *node;
@@ -708,7 +709,7 @@ ERROR0:
 }
 
 
-gboolean
+static gboolean
 copy_dir_check_source (const gchar *from_dir, gboolean show_error,
                        GtkWindow *window)
 {
@@ -759,7 +760,7 @@ ERROR:
 }
 
 
-gboolean
+static gboolean
 copy_dir_check_dest (const gchar *from_path, const gchar *dirname,
                      const gchar *to_dir, gboolean show_error,
                      GtkWindow *window)
@@ -824,7 +825,7 @@ ERROR:
  *  show_error :
  *  Return     : TRUE if success to copy directory.
  */
-gboolean
+static gboolean
 copy_dir (const gchar *from_path, const gchar *dir,
           ConfirmType *action, gboolean show_error,
           GtkWindow *window)
@@ -874,7 +875,7 @@ copy_dir (const gchar *from_path, const gchar *dir,
    length = g_list_length (filelist);
 
    while (node) {
-      gint len;
+      guint len;
       gchar *filename = node->data;
       gchar *tmpstr;
 
