@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimageview.h,v 1.17 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: gimageview.h,v 1.18 2004/04/08 13:39:25 makeinu Exp $
  */
 
 #ifndef __GIMAGEVIEW_H__
@@ -53,7 +53,7 @@ typedef struct GimvImageInfo_Tag   GimvImageInfo;
 typedef struct GimvImageView_Tag   GimvImageView;
 typedef struct GimvImageWin_Tag    GimvImageWin;
 typedef struct GimvThumb_Tag       GimvThumb;
-typedef struct ThumbView_Tag       ThumbView;
+typedef struct GimvThumbView_Tag   GimvThumbView;
 typedef struct GimvThumbWin_Tag    GimvThumbWin;
 typedef struct DirView_Tag         DirView;
 typedef struct GimvComment_Tag     GimvComment;
