@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_anim.c,v 1.15 2003/07/20 14:38:10 makeinu Exp $
+ * $Id: gimv_anim.c,v 1.17 2004/06/17 06:37:26 makeinu Exp $
  */
 
 #include "gimv_anim.h"
@@ -38,10 +38,10 @@ static void gimv_anim_destroy       (GtkObject     *object);
 static GimvImageClass *parent_class = NULL;
 
 
-guint
+GtkType
 gimv_anim_get_type (void)
 {
-   static guint gimv_anim_type = 0;
+   static GtkType gimv_anim_type = 0;
 
    if (!gimv_anim_type) {
       static const GtkTypeInfo gimv_anim_info = {
@@ -81,11 +81,6 @@ gimv_anim_init (GimvAnim *anim)
    anim->anim = NULL;
    anim->current_frame_idx = -1;
    anim->table = NULL;
-
-#ifdef USE_GTK2
-   gtk_object_ref (GTK_OBJECT (anim));
-   gtk_object_sink (GTK_OBJECT (anim));
-#endif
 }
 
 
