@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_anim.h,v 1.7 2003/07/20 14:38:10 makeinu Exp $
+ * $Id: gimv_anim.h,v 1.8 2004/03/07 11:53:30 makeinu Exp $
  */
 
 #ifndef __GIMV_ANIM_H__
@@ -67,7 +67,7 @@ struct GimvAnimFuncTable_Tag
 };
 
 
-guint      gimv_anim_get_type     (void);
+GtkType    gimv_anim_get_type     (void);
 GimvAnim  *gimv_anim_new          (void);
 
 /* public */
