@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_comment.c,v 1.2 2003/09/28 11:00:10 makeinu Exp $
+ * $Id: gimv_comment.c,v 1.3 2004/03/07 11:53:30 makeinu Exp $
  */
 
 /*
@@ -97,10 +97,10 @@ GList *gimv_comment_data_entry_list = NULL;
  *   GimvComment class funcs
  *
  ******************************************************************************/
-guint
+GtkType
 gimv_comment_get_type ()
 {
-   static guint gimv_comment_type = 0;
+   static GtkType gimv_comment_type = 0;
 
    if (!gimv_comment_type) {
       static const GtkTypeInfo gimv_comment_info = {
