@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_comment_view.c,v 1.3 2003/09/28 05:27:48 makeinu Exp $
+ * $Id: gimv_comment_view.c,v 1.6 2004/09/22 15:37:11 makeinu Exp $
  */
 
 #include "gimv_comment_view.h"
@@ -287,7 +287,7 @@ cb_clist_unselect_row (GtkCList *clist, gint row, gint col,
 }
 
 
-void
+static void
 cb_clist_row_move (GtkCList *clist,
                    gint arg1, gint arg2,
                    GimvCommentView *cv)
@@ -543,6 +543,10 @@ create_data_page (GimvCommentView *cv)
    scrolledwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_box_pack_start(GTK_BOX(vbox), scrolledwin, TRUE, TRUE, 0);
 
 #ifdef ENABLE_TREEVIEW
@@ -674,6 +678,10 @@ create_note_page (GimvCommentView *cv)
    cv->note_page = scrolledwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_widget_show (scrolledwin);
 
 #ifdef USE_GTK2
