@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_dlist.c,v 1.2 2003/06/13 09:43:29 makeinu Exp $
+ * $Id: gimv_dlist.c,v 1.6 2004/09/22 15:37:11 makeinu Exp $
  */
 
 #include "gimv_dlist.h"
@@ -65,10 +65,10 @@ static GtkHBoxClass *parent_class = NULL;
 static gint gimv_dlist_signals[LAST_SIGNAL] = {0};
 
 
-guint
+GtkType
 gimv_dlist_get_type (void)
 {
-   static guint gimv_dlist_type = 0;
+   static GtkType gimv_dlist_type = 0;
 
 #if (GTK_MAJOR_VERSION >= 2)
    if (!gimv_dlist_type) {
@@ -287,7 +287,7 @@ cb_gimv_dlist_unselect_row (GtkCList *clist, gint row, gint col,
 }
 
 
-gint
+static gint
 idle_gimv_dlist_row_move (gpointer data)
 {
    GimvDList *dslist = data;
@@ -712,6 +712,10 @@ gimv_dlist_new (const gchar *clist1_title,
    scrollwin1 = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin1),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwin1),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_container_set_border_width(GTK_CONTAINER(scrollwin1), 5);
    gtk_box_pack_start (GTK_BOX (vbox1), scrollwin1, TRUE, TRUE, 0);
    gtk_widget_show (scrollwin1);
@@ -797,6 +801,10 @@ gimv_dlist_new (const gchar *clist1_title,
    scrollwin2 = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin2),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwin2),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_container_set_border_width(GTK_CONTAINER(scrollwin2), 5);
    gtk_box_pack_start (GTK_BOX (vbox2), scrollwin2, TRUE, TRUE, 0);
    gtk_widget_show (scrollwin2);
