@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_dlist.h,v 1.2 2003/06/13 09:43:29 makeinu Exp $
+ * $Id: gimv_dlist.h,v 1.3 2004/03/07 11:53:30 makeinu Exp $
  */
 
 #ifndef __GIMV_DLIST_H__
@@ -76,7 +76,7 @@ struct GimvDListClass_Tag {
  *  "enabled" or "clist2" means right side CList (or TreeView).
  */
 
-guint         gimv_dlist_get_type              (void);
+GtkType       gimv_dlist_get_type              (void);
 
 GtkWidget    *gimv_dlist_new                   (const gchar  *clist1_title,
                                                 const gchar  *clist2_title);
