@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_dupl_finder.c,v 1.3 2004/04/08 10:38:51 makeinu Exp $
+ * $Id: gimv_dupl_finder.c,v 1.5 2004/10/16 12:11:23 makeinu Exp $
  */
 
 #include "gimv_dupl_finder.h"
@@ -381,7 +381,7 @@ gimv_dupl_finder_start (GimvDuplFinder *finder)
    gtk_signal_emit (GTK_OBJECT (finder), gimv_dupl_finder_signals[START_SIGNAL]);
 
    if (!finder->table)
-      finder->table = g_hash_table_new (g_direct_hash, g_str_equal);
+      finder->table = g_hash_table_new (g_direct_hash, g_direct_equal);
 
    finder->cur1 = finder->dest_list;
    finder->cur2 = g_list_next (finder->dest_list);
