@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_dupl_win.c,v 1.2 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: gimv_dupl_win.c,v 1.5 2004/04/08 13:39:25 makeinu Exp $
  */
 
 #include "gimv_dupl_win.h"
@@ -128,10 +128,10 @@ gint simwin_column_num = sizeof (simwin_titles) / sizeof (gchar *);
 static GtkDialogClass *parent_class = NULL;
 
 
-guint
+GtkType
 gimv_dupl_win_get_type (void)
 {
-   static guint gimv_dupl_win_type = 0;
+   static GtkType gimv_dupl_win_type = 0;
 
    if (!gimv_dupl_win_type) {
       static const GtkTypeInfo gimv_dupl_win_info = {
@@ -349,7 +349,7 @@ gimv_dupl_win_destroy (GtkObject *object)
    g_return_if_fail (sw);
 
    if (sw->priv) {
-      g_list_foreach (sw->priv->thumb_list, (GFunc) gimv_thumb_unref, NULL);
+      g_list_foreach (sw->priv->thumb_list, (GFunc) gtk_object_unref, NULL);
       g_list_free (sw->priv->thumb_list);
       sw->priv->thumb_list = NULL;
       g_free (sw->priv);
@@ -369,7 +369,7 @@ gimv_dupl_win_destroy (GtkObject *object)
 static void
 ghfunc_select_thumb (GimvThumb *thumb)
 {
-   thumbview_set_selection (thumb, TRUE);
+   gimv_thumb_view_set_selection (thumb, TRUE);
 }
 
 
@@ -379,7 +379,7 @@ cb_select_all_button (GtkButton *button, GimvDuplWin *sw)
    g_return_if_fail (sw);
    if (!sw->tv) return;
 
-   thumbview_set_selection_all (sw->tv, FALSE);
+   gimv_thumb_view_set_selection_all (sw->tv, FALSE);
    g_list_foreach (sw->priv->thumb_list, (GFunc) ghfunc_select_thumb, NULL);
 }
 
@@ -454,21 +454,24 @@ cb_finder_found (GimvDuplFinder *finder, GimvDuplPair *pair, GimvDuplWin *sw)
 static void
 cb_select_thumb (GimvThumb *thumb, GimvDuplWin *sw)
 {
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
    g_return_if_fail (sw);
 
   if (conf.simwin_sel_thumbview) {
-      thumbview_set_selection_all (sw->tv, FALSE);
-      thumbview_set_selection (thumb, TRUE);
-      thumbview_adjust (sw->tv, thumb);
+      gimv_thumb_view_set_selection_all (sw->tv, FALSE);
+      gimv_thumb_view_set_selection (thumb, TRUE);
+      gimv_thumb_view_adjust (sw->tv, thumb);
    }
 
    if (conf.simwin_sel_preview)
-      thumbview_open_image (sw->tv, thumb, THUMB_VIEW_OPEN_IMAGE_PREVIEW);
+      gimv_thumb_view_open_image (sw->tv, thumb,
+                                  GIMV_THUMB_VIEW_OPEN_IMAGE_PREVIEW);
    if (conf.simwin_sel_new_win)
-      thumbview_open_image (sw->tv, thumb, THUMB_VIEW_OPEN_IMAGE_NEW_WIN);
+      gimv_thumb_view_open_image (sw->tv, thumb,
+                                  GIMV_THUMB_VIEW_OPEN_IMAGE_NEW_WIN);
    if (conf.simwin_sel_shared_win)
-      thumbview_open_image (sw->tv, thumb, THUMB_VIEW_OPEN_IMAGE_SHARED_WIN);
+      gimv_thumb_view_open_image (sw->tv, thumb,
+                                  GIMV_THUMB_VIEW_OPEN_IMAGE_SHARED_WIN);
 }
 
 
@@ -493,7 +496,7 @@ cb_tree_cursor_changed (GtkTreeView *treeview, GimvDuplWin *sw)
                        COLUMN_THUMBDATA, &thumb,
                        COLUMN_TERMINATOR);
 
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
    cb_select_thumb (thumb, sw);
 }
@@ -577,7 +580,7 @@ insert_node (GimvDuplWin *sw,
    GdkBitmap *thumb_mask, *icon_mask;
    gchar *text[32], accuracy[32], *tmpstr;
 
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
    gimv_thumb_get_thumb (thumb, &thumb_pixmap, &thumb_mask);
    gimv_thumb_get_icon (thumb,  &icon_pixmap,  &icon_mask);
@@ -603,7 +606,7 @@ insert_node (GimvDuplWin *sw,
    text[3] = charset_locale_to_internal (tmpstr);
    g_free (tmpstr);
 
-   gimv_thumb_ref (thumb);
+   gtk_object_ref (GTK_OBJECT(thumb));
    sw->priv->thumb_list = g_list_append (sw->priv->thumb_list, thumb);
 
    model = gtk_tree_view_get_model (GTK_TREE_VIEW (sw->ctree));
@@ -644,7 +647,7 @@ set_pixtext (GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
    g_return_if_fail (node);
 
    thumb = gtk_ctree_node_get_row_data (ctree, node);
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
    if (thumbnail)
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
@@ -697,7 +700,7 @@ cb_ctree_select_row (GtkCTree *ctree, GList *node, gint column, GimvDuplWin *sw)
    if (!sw->tv) return;
 
    thumb = gtk_ctree_node_get_row_data (ctree, GTK_CTREE_NODE (node));
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
    cb_select_thumb (thumb, sw);
 }
@@ -714,7 +717,7 @@ insert_node (GimvDuplWin *sw,
    GdkBitmap *mask;
    gchar *text[32], accuracy[32], *tmpstr;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    if (GTK_TOGGLE_BUTTON (sw->radio_thumb)->active)
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
@@ -747,7 +750,7 @@ insert_node (GimvDuplWin *sw,
                                  pixmap, mask,
                                  pixmap, mask,
                                  FALSE, FALSE);
-   gimv_thumb_ref (thumb);
+   gtk_object_ref (GTK_OBJECT(thumb));
    sw->priv->thumb_list = g_list_append (sw->priv->thumb_list, thumb);
    gtk_ctree_node_set_row_data (GTK_CTREE (sw->ctree), node, thumb);
 
@@ -785,7 +788,7 @@ gimv_dupl_win_new (gint thumbnail_size)
 
 
 void
-gimv_dupl_win_set_relation (GimvDuplWin *sw, ThumbView *tv)
+gimv_dupl_win_set_relation (GimvDuplWin *sw, GimvThumbView *tv)
 {
    g_return_if_fail (sw);
    g_return_if_fail (tv);
@@ -814,8 +817,8 @@ gimv_dupl_win_set_thumb (GimvDuplWin *sw,
                          gfloat     similar)
 {
    g_return_if_fail (sw);
-   g_return_if_fail (thumb1);
-   g_return_if_fail (thumb2);
+   g_return_if_fail (GIMV_IS_THUMB (thumb1));
+   g_return_if_fail (GIMV_IS_THUMB (thumb2));
 
 #ifdef ENABLE_TREEVIEW
 {
