@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_elist.c,v 1.2 2003/06/13 09:43:29 makeinu Exp $
+ * $Id: gimv_elist.c,v 1.6 2004/09/22 15:37:11 makeinu Exp $
  */
 
 #include "gimv_elist.h"
@@ -78,10 +78,10 @@ static GtkVBoxClass *parent_class = NULL;
 static gint gimv_elist_signals[LAST_SIGNAL] = {0};
 
 
-guint
+GtkType
 gimv_elist_get_type (void)
 {
-   static guint gimv_elist_type = 0;
+   static GtkType gimv_elist_type = 0;
 
 #if (GTK_MAJOR_VERSION >= 2)
    if (!gimv_elist_type) {
@@ -361,7 +361,7 @@ cb_editlist_unselect_row (GtkCList *clist, gint row, gint col,
 }
 
 
-gint
+static gint
 idle_editlist_row_move (gpointer data)
 {
    GimvEList *editlist = data;
@@ -955,6 +955,10 @@ gimv_elist_new (gint colnum)
    scrollwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_container_set_border_width(GTK_CONTAINER (scrollwin), 5);
    gtk_box_pack_start (GTK_BOX (hbox), scrollwin, TRUE, TRUE, 0);
    gtk_widget_set_usize (scrollwin, -1, 120);
