@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_elist.h,v 1.3 2003/07/05 16:41:11 makeinu Exp $
+ * $Id: gimv_elist.h,v 1.4 2004/03/07 11:53:30 makeinu Exp $
  */
 
 
@@ -146,7 +146,7 @@ struct GimvEListColumnFuncTable_Tag {
 };
 
 
-guint         gimv_elist_get_type              (void);
+GtkType       gimv_elist_get_type              (void);
 GtkWidget    *gimv_elist_new                   (gint          colnum);
 GtkWidget    *gimv_elist_new_with_titles       (gint          colnum,
                                                 gchar        *titles[]);
