@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_hpaned.c,v 1.2 2003/06/13 09:43:30 makeinu Exp $
+ * $Id: gimv_hpaned.c,v 1.3 2004/03/07 11:53:30 makeinu Exp $
  */
 
 /*
@@ -52,10 +52,10 @@ static gint gimv_hpaned_button_release   (GtkWidget *widget,
                                           GdkEventButton *event);
 
 
-guint
+GtkType
 gimv_hpaned_get_type (void)
 {
-   static guint hpaned_type = 0;
+   static GtkType hpaned_type = 0;
 	
    if (!hpaned_type) {
       static const GtkTypeInfo hpaned_info =	{
