@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_hpaned.h,v 1.2 2003/06/13 09:43:30 makeinu Exp $
+ * $Id: gimv_hpaned.h,v 1.3 2004/03/07 11:53:30 makeinu Exp $
  */
 
 /*
@@ -62,7 +62,7 @@ struct _GimvHPanedClass
 };
 
 
-guint      gimv_hpaned_get_type (void);
+GtkType    gimv_hpaned_get_type (void);
 GtkWidget* gimv_hpaned_new      (void);
 
 #else /* USE_NORMAL_PANED */
