@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image.c,v 1.66 2003/07/20 14:38:10 makeinu Exp $
+ * $Id: gimv_image.c,v 1.68 2004/09/21 08:44:31 makeinu Exp $
  */
 
 #include "gimageview.h"
@@ -54,10 +54,10 @@ static void gimv_image_backend_init  (void);
 static GtkObjectClass *parent_class = NULL;
 
 
-guint
+GtkType
 gimv_image_get_type (void)
 {
-   static guint gimv_image_type = 0;
+   static GtkType gimv_image_type = 0;
 
    if (!gimv_image_type) {
       static const GtkTypeInfo gimv_image_info = {
@@ -400,7 +400,7 @@ gimv_image_rotate (GimvImage *image, GimvImageAngle abs_angle)
       angle = abs_angle;
    }
 
-   if (image->angle == angle)
+   if (image->angle == (GimvImageAngle) angle)
       return image;
 
    rotate = angle - image->angle;
