@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_info.c,v 1.4 2003/07/20 14:38:10 makeinu Exp $
+ * $Id: gimv_image_info.c,v 1.6 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -142,8 +142,8 @@ gimv_image_info_get_url (const gchar *url)
 
 GimvImageInfo *
 gimv_image_info_get_with_archive (const gchar *filename,
-                             FRArchive   *archive,
-                             struct stat *st)
+                                  FRArchive   *archive,
+                                  struct stat *st)
 {
    GimvImageInfo *info;
    gchar buf[MAX_PATH_LEN];
@@ -395,33 +395,6 @@ gimv_image_info_unset_flags (GimvImageInfo *info, GimvImageInfoFlags flags)
 }
 
 
-gboolean
-gimv_image_info_set_data_from_image (GimvImageInfo *info, GimvImage *image)
-{
-   gboolean is_exist;
-
-   g_return_val_if_fail (info, FALSE);
-
-   if (!image) return FALSE;
-
-   if (gimv_image_info_is_in_archive (info)) {
-      /* FIXME!! should we call stat? */
-   } else {
-      is_exist = !stat (info->filename, &info->st);
-      if (!is_exist) return FALSE;
-   }
-
-   if (GIMV_IS_ANIM (image)) {
-      info->flags |= GIMV_IMAGE_INFO_ANIMATION_FLAG;
-   }
-
-   gimv_image_get_size (image, &info->width, &info->height);
-   info->flags |= GIMV_IMAGE_INFO_SYNCED_FLAG;
-
-   return TRUE;
-}
-
-
 gboolean
 gimv_image_info_is_dir (GimvImageInfo *info)
 {
