@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_loader.c,v 1.8 2003/08/14 09:08:50 makeinu Exp $
+ * $Id: gimv_image_loader.c,v 1.9 2004/03/07 11:53:30 makeinu Exp $
  */
 
 #include "gimv_image_loader.h"
@@ -131,10 +131,10 @@ gimv_image_loader_plugin_regist (const gchar *plugin_name,
  *
  *
  ****************************************************************************/
-guint
+GtkType
 gimv_image_loader_get_type (void)
 {
-   static guint gimv_image_loader_type = 0;
+   static GtkType gimv_image_loader_type = 0;
 
    if (!gimv_image_loader_type) {
       static const GtkTypeInfo gimv_image_loader_info = {
