@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_view.h,v 1.8 2003/08/01 16:21:25 makeinu Exp $
+ * $Id: gimv_image_view.h,v 1.11 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #ifndef __GIMV_IMAGE_VIEW_H__
@@ -201,7 +201,7 @@ struct GimvImageViewClass_Tag
 
 
 GList     *gimv_image_view_get_list               (void);
-guint      gimv_image_view_get_type               (void);
+GtkType    gimv_image_view_get_type               (void);
 GtkWidget *gimv_image_view_new                    (GimvImageInfo  *info);
 
 void       gimv_image_view_change_image           (GimvImageView  *iv,
@@ -354,7 +354,7 @@ void       gimv_image_view_nth                    (GimvImageView  *iv,
  *  GimvImageView Embeder Plugin interface
  *
  ****************************************************************************/
-#define GIMV_IMAGE_VIEW_IF_VERSION 4
+#define GIMV_IMAGE_VIEW_IF_VERSION 5
 
 struct GimvImageViewPlugin_Tag
 {
@@ -406,4 +406,10 @@ void gimv_image_view_playable_set_status   (GimvImageView *iv,
 void gimv_image_view_playable_set_position (GimvImageView *iv,
                                             gfloat     pos); /* [%] */
 
+/* for plugin loader */
+gboolean gimv_image_view_plugin_regist (const gchar *plugin_name,
+                                        const gchar *module_name,
+                                        gpointer     impl,
+                                        gint         size);
+
 #endif /* __GIMV_IMAGE_VIEW_H__ */
