@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_win.c,v 1.17 2004/09/29 08:53:55 makeinu Exp $
+ * $Id: gimv_image_win.c,v 1.19 2004/12/20 15:57:07 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -2480,7 +2480,7 @@ gimv_image_win_change_image (GimvImageWin *iw, GimvImageInfo *info)
    gtk_object_get (GTK_OBJECT (iw->iv),
                    "default_zoom", &default_zoom,
                    NULL);
-   if ((default_zoom > 0) && conf.imgwin_fit_to_image
+   if ((default_zoom > 1) && conf.imgwin_fit_to_image
        && !(iw->priv->flags & GimvImageWinMaximizeFlag))
    {
       gdk_window_resize (GTK_WIDGET(iw)->window,
@@ -2575,6 +2575,7 @@ static gboolean
 timeout_slideshow (GimvImageWin *iw)
 {
    GList *current;
+   GimvImageViewPlayableStatus status;
 
    current = gimv_image_view_image_list_current (iw->iv);
 
@@ -2587,6 +2588,14 @@ timeout_slideshow (GimvImageWin *iw)
       return FALSE;
    }
 
+   // Movies, in contrast to pictues, should not be interrupted during slideshows.
+   status = gimv_image_view_playable_get_status(iw->iv);
+   if (status != GimvImageViewPlayableDisable &&
+       status != GimvImageViewPlayableStop)
+   {
+      return TRUE;
+   }
+
    gimv_image_view_next (iw->iv);
 
    return TRUE;
