@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_win.h,v 1.6 2003/07/05 16:41:11 makeinu Exp $
+ * $Id: gimv_image_win.h,v 1.7 2004/03/07 11:53:31 makeinu Exp $
  */
 
 #ifndef __GIMV_IMAGE_WIN_H__
@@ -123,7 +123,7 @@ struct GimvImageWinClass_Tag
 };
 
 
-guint         gimv_image_win_get_type                  (void);
+GtkType       gimv_image_win_get_type                  (void);
 GtkWidget    *gimv_image_win_new                       (GimvImageInfo *info);
 GimvImageWin *gimv_image_win_open_window               (GimvImageInfo *info);
 GimvImageWin *gimv_image_win_open_shared_window        (GimvImageInfo *info);
