@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_io.c,v 1.9 2003/06/18 09:26:56 makeinu Exp $
+ * $Id: gimv_io.c,v 1.10 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #include <sys/types.h>
@@ -232,7 +232,7 @@ gimv_io_getc (GimvIO *gio, GimvIOStatus *status)
 GimvIOStatus
 gimv_io_fgets (GimvIO *gio, gchar *buf, guint count)
 {
-   gint i;
+   guint i;
    guint bytes_read;
    guint len = 0;
 
