@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_io.h,v 1.4 2003/06/13 09:43:31 makeinu Exp $
+ * $Id: gimv_io.h,v 1.5 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #ifndef __GIMV_IO__
@@ -121,5 +121,10 @@ GimvIOStatus   gimv_io_fgets (GimvIO       *gio,
                               gchar        *buf,
                               guint         count);
 
+/* for plugin loader */
+gboolean       gimv_io_plugin_regist (const gchar *plugin_name,
+                                      const gchar *module_name,
+                                      gpointer     impl,
+                                      gint         size);
 
 #endif /* __GIMV_IO__ */
