@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_nav_win.c,v 1.3 2003/07/07 15:24:21 makeinu Exp $
+ * $Id: gimv_nav_win.c,v 1.4 2004/03/07 11:53:31 makeinu Exp $
  */
 
 /*
@@ -81,10 +81,10 @@ static void      navwin_grab_pointer        (GimvNavWin      *navwin);
 static void      navwin_set_win_pos_size    (GimvNavWin *navwin);
 
 
-guint
+GtkType
 gimv_nav_win_get_type (void)
 {
-   static guint gimv_nav_win_type = 0;
+   static GtkType gimv_nav_win_type = 0;
 
    if (!gimv_nav_win_type) {
       static const GtkTypeInfo gimv_nav_win_info = {
