@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_plugin.h,v 1.3 2003/06/14 03:39:50 makeinu Exp $
+ * $Id: gimv_plugin.h,v 1.4 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #ifndef __GIMV_PLUGIN_H__
@@ -202,7 +202,7 @@ prefix##_prefs_get_value (const gchar *key, gpointer *value)
 {                                                                               \
    GimvPluginPrefsEntry *entry = NULL;                                          \
    gboolean success;                                                            \
-   gint i;                                                                      \
+   guint i;                                                                     \
                                                                                 \
    g_return_val_if_fail(key && value, FALSE);                                   \
                                                                                 \
@@ -243,7 +243,7 @@ prefix##_prefs_get_value (const gchar *key, gpointer *value)
 
 #define GIMV_PLUGIN_PREFS_GET_ALL(prefix, table, src_struct_p, dest_struct)     \
 {                                                                               \
-   gint i;                                                                      \
+   guint i;                                                                     \
    src_struct_p = g_malloc0(sizeof(dest_struct));                               \
    for (i = 0; i < sizeof (table) / sizeof (GimvPluginPrefsEntry); i++) {       \
       prefix##_prefs_get_value(table[i].key, table[i].value);                   \
@@ -270,7 +270,7 @@ prefix##_prefs_get_value (const gchar *key, gpointer *value)
 
 #define GIMV_PLUGIN_PREFS_APPLY_ALL(table, pname, ptype, action, src_struct_p, dest_struct)\
 {                                                                               \
-   gint i;                                                                      \
+   guint i;                                                                     \
                                                                                 \
    for (i = 0;                                                                  \
         i < sizeof (table) / sizeof (GimvPluginPrefsEntry);                     \
@@ -324,7 +324,7 @@ prefix##_prefs_get_value (const gchar *key, gpointer *value)
 
 #define GIMV_PLUGIN_PREFS_FREE_ALL(table, src_struct_p, dest_struct)            \
 {                                                                               \
-   gint i;                                                                      \
+   guint i;                                                                     \
                                                                                 \
    for (i = 0;                                                                  \
         i < sizeof (table) / sizeof (GimvPluginPrefsEntry);                     \
