@@ -74,10 +74,10 @@ static GtkObjectClass *parent_class = NULL;
 static gint gimv_prefs_signals[LAST_SIGNAL] = {0};
 
 
-guint
+GtkType
 gimv_prefs_get_type (void)
 {
-   static guint gimv_prefs_type = 0;
+   static GtkType gimv_prefs_type = 0;
 
    if (!gimv_prefs_type) {
       static const GtkTypeInfo gimv_prefs_info = {
@@ -240,7 +240,7 @@ const static gchar hex[16]={'0', '1', '2', '3', '4', '5', '6', '7',
  * flag,TRUE:signed,FALSE:unsigned
  * RET,TRUE:normal exit,FALSE:error
  */
-gboolean
+static gboolean
 misc_str_to_val(gint *value,const gchar *str,const gint radix,
 		const gboolean flag)
 {
@@ -308,7 +308,7 @@ misc_str_to_val(gint *value,const gchar *str,const gint radix,
  * flag,TRUE:signed,FALSE:unsigned
  * RET,array of value
  */
-guint8 *
+static guint8 *
 misc_str_to_array(gint *size,const gchar *text,
 		  const gint radix,const gboolean flag)
 {
@@ -640,8 +640,8 @@ gimv_prefs_get_size (GimvPrefs *profile,
  */
 gboolean
 gimv_prefs_get_value (GimvPrefs *profile,
-		      const gchar *section,const gchar *key,
-		      gpointer value,const gint size,const guint type)
+                      const gchar *section,const gchar *key,
+                      gpointer value,const gint size,const guint type)
 {
 	guint8 *array;
 	gint n;
@@ -675,7 +675,7 @@ gimv_prefs_get_value (GimvPrefs *profile,
 	switch (type)
 	{
 	case GIMV_PREFS_VALUE_TYPE_BOOL:
-		if (size < sizeof(gboolean))
+		if (size < (gint) sizeof(gboolean))
 			return FALSE;
 		if (strcasecmp (p->value, "true") == 0)
 			*((gboolean *)value) = TRUE;
@@ -685,12 +685,12 @@ gimv_prefs_get_value (GimvPrefs *profile,
 			return FALSE;
 		break;
 	case GIMV_PREFS_VALUE_TYPE_INT:
-		if (size < sizeof(gint))
+		if (size < (gint) sizeof(gint))
 			return FALSE;
 		misc_str_to_val((gint *)value, p->value, 10, TRUE);
 		break;
 	case GIMV_PREFS_VALUE_TYPE_STRING:
-		if (size < g_strlen(p->value) + 1)
+		if (size < (gint) g_strlen(p->value) + 1)
 			return FALSE;
 		strcpy((gchar *)value,p->value);
 		break;
