@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_prefs_win.c,v 1.4 2003/07/19 12:42:13 makeinu Exp $
+ * $Id: gimv_prefs_win.c,v 1.8 2004/09/22 15:37:11 makeinu Exp $
  */
 
 #include "gimv_prefs_win.h"
@@ -238,7 +238,7 @@ prefs_win_create_page (GimvPrefsWinPagePrivate *priv)
 }
 
 
-void
+static void
 prefs_win_set_page (const gchar *path)
 {
    GimvPrefsWinPagePrivate *priv = NULL;
@@ -830,6 +830,10 @@ gimv_prefs_win_open (const gchar *path, GtkWindow *parent)
    scrolledwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_widget_set_usize (scrolledwin, 170, -1);
    gtk_widget_show (scrolledwin);
 
@@ -844,9 +848,9 @@ gimv_prefs_win_open (const gchar *path, GtkWindow *parent)
    /* button */
 #ifdef USE_GTK2
    gtk_dialog_add_buttons (GTK_DIALOG (prefs_window),
-                           GTK_STOCK_OK,     GTK_RESPONSE_ACCEPT,
                            GTK_STOCK_APPLY,  GTK_RESPONSE_APPLY,
                            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                           GTK_STOCK_OK,     GTK_RESPONSE_ACCEPT,
                            NULL);
    gtk_signal_connect_object (GTK_OBJECT (prefs_window), "response",
                               GTK_SIGNAL_FUNC (cb_dialog_response),
