@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_vpaned.c,v 1.2 2003/06/13 09:43:33 makeinu Exp $
+ * $Id: gimv_vpaned.c,v 1.3 2004/03/07 11:53:31 makeinu Exp $
  */
 
 /*
@@ -51,10 +51,10 @@ static gint gimv_vpaned_button_press     (GtkWidget *widget,
 static gint gimv_vpaned_button_release   (GtkWidget *widget,
                                           GdkEventButton *event);
 
-guint
+GtkType
 gimv_vpaned_get_type (void)
 {
-   static guint vpaned_type = 0;
+   static GtkType vpaned_type = 0;
 
    if (!vpaned_type) {
       static const GtkTypeInfo vpaned_info = {
