@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_vpaned.h,v 1.2 2003/06/13 09:43:33 makeinu Exp $
+ * $Id: gimv_vpaned.h,v 1.3 2004/03/07 11:53:31 makeinu Exp $
  */
 
 /*
@@ -64,7 +64,7 @@ struct _GimvVPanedClass
 };
 
 
-guint      gimv_vpaned_get_type (void);
+GtkType    gimv_vpaned_get_type (void);
 GtkWidget* gimv_vpaned_new      (void);
 
 #else /* USE_NORMAL_PANED */
