@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_zalbum.c,v 1.2 2003/06/13 09:43:33 makeinu Exp $
+ * $Id: gimv_zalbum.c,v 1.5 2004/09/21 08:44:32 makeinu Exp $
  */
 
 /*
@@ -244,6 +244,15 @@ gimv_zalbum_finalize (GtkObject *object)
 
 guint
 gimv_zalbum_add (GimvZAlbum *album, const gchar *name)
+{
+   g_return_val_if_fail (GIMV_IS_ZALBUM (album), 0);
+
+   return gimv_zalbum_insert (album, GIMV_ZLIST(album)->cells->len, name);
+}
+
+
+guint
+gimv_zalbum_insert (GimvZAlbum *album, guint pos, const gchar *name)
 {
    GimvZAlbumCell *cell;
 
@@ -262,7 +271,33 @@ gimv_zalbum_add (GimvZAlbum *album, const gchar *name)
 
    album->len++;
 
-   return gimv_zlist_add (GIMV_ZLIST (album), cell);
+   return gimv_zlist_insert (GIMV_ZLIST (album), pos, cell);
+}
+
+
+void        
+gimv_zalbum_remove (GimvZAlbum *album, guint pos)
+{
+   GimvZAlbumCell *cell;
+
+   g_return_if_fail (GIMV_IS_ZALBUM (album));
+
+   cell = GIMV_ZLIST_CELL_FROM_INDEX (GIMV_ZLIST (album), pos);
+   g_return_if_fail (cell);
+
+   gimv_zlist_remove(GIMV_ZLIST(album), cell);
+
+   g_free ((gpointer) cell->name);
+   if (cell->ipix)
+      gdk_pixmap_unref (cell->ipix);
+   cell->ipix = NULL;
+
+   if (cell->user_data && cell->destroy)
+      cell->destroy (cell->user_data);
+   cell->destroy = NULL;
+   cell->user_data = NULL;
+
+   g_free (cell);
 }
 
 
@@ -326,9 +361,9 @@ gimv_zalbum_cell_size_request (GimvZList *list, gpointer cell, GtkRequisition *r
 
 static void
 gimv_zalbum_draw_cell (GimvZList *list,
-                  gpointer cell,
-                  GdkRectangle *cell_area,
-                  GdkRectangle *area)
+                       gpointer cell,
+                       GdkRectangle *cell_area,
+                       GdkRectangle *area)
 {
    g_return_if_fail (list && cell);
 
@@ -383,8 +418,8 @@ draw_cell_pixmap (GdkWindow    *window,
 
 static void
 gimv_zalbum_draw (GimvZAlbum *album, GimvZAlbumCell *cell,
-             GdkRectangle *cell_area,
-             GdkRectangle *area)
+                  GdkRectangle *cell_area,
+                  GdkRectangle *area)
 {
    GtkWidget *widget;
    gint text_area_height, v_text_area_height, xdest, ydest;
@@ -505,9 +540,9 @@ gimv_zalbum_draw (GimvZAlbum *album, GimvZAlbumCell *cell,
    }
 
    gimv_zalbum_draw_string (widget, cell, cell->name,
-                       xdest, ydest,
-                       cell_area->width, text_area_height,
-                       center);
+                            xdest, ydest,
+                            cell_area->width, text_area_height,
+                            center);
 
 }
 
@@ -647,10 +682,10 @@ make_string (GdkFont *font, gint max_width,
 
 static void
 gimv_zalbum_draw_string (GtkWidget *widget, GimvZAlbumCell *cell,
-                    const gchar *string,
-                    gint x, gint y,
-                    gint max_width, gint max_height,
-                    gint center)
+                         const gchar *string,
+                         gint x, gint y,
+                         gint max_width, gint max_height,
+                         gint center)
 {
 #ifdef USE_GTK2
    gchar buffer[STRING_BUFFER_SIZE];
@@ -759,8 +794,10 @@ gimv_zalbum_draw_string (GtkWidget *widget, GimvZAlbumCell *cell,
 
 
 static void
-gimv_zalbum_prepare_cell (GimvZAlbum *album, GimvZAlbumCell *cell, GdkRectangle *cell_area,
-                     GdkRectangle *area)
+gimv_zalbum_prepare_cell (GimvZAlbum *album,
+                          GimvZAlbumCell *cell,
+                          GdkRectangle *cell_area,
+                          GdkRectangle *area)
 {
    GtkWidget *widget;
    GdkRectangle intersect_area;
@@ -812,7 +849,7 @@ gimv_zalbum_set_label_position (GimvZAlbum *album, GimvZAlbumLabelPosition pos)
 
 void
 gimv_zalbum_set_min_pixmap_size (GimvZAlbum *album,
-                            guint width, guint height)
+                                 guint width, guint height)
 {
    g_return_if_fail (GIMV_IS_ZALBUM (album));
 
@@ -823,7 +860,7 @@ gimv_zalbum_set_min_pixmap_size (GimvZAlbum *album,
 
 void
 gimv_zalbum_set_min_cell_size (GimvZAlbum *album,
-                          guint width, guint height)
+                               guint width, guint height)
 {
    g_return_if_fail (GIMV_IS_ZALBUM (album));
 
@@ -894,7 +931,8 @@ gimv_zalbum_update_max_cell_size (GimvZAlbum *album, GimvZAlbumCell *cell)
 
 
 void
-gimv_zalbum_set_pixmap (GimvZAlbum *album, guint idx, GdkPixmap *pixmap, GdkBitmap *mask)
+gimv_zalbum_set_pixmap (GimvZAlbum *album, guint idx,
+                        GdkPixmap *pixmap, GdkBitmap *mask)
 {
    GimvZAlbumCell *cell;
 
@@ -932,9 +970,9 @@ gimv_zalbum_set_cell_data (GimvZAlbum *album, guint idx, gpointer user_data)
 
 void
 gimv_zalbum_set_cell_data_full (GimvZAlbum *album,
-                           guint idx,
-                           gpointer user_data,
-                           GtkDestroyNotify  destroy)
+                                guint idx,
+                                gpointer user_data,
+                                GtkDestroyNotify  destroy)
 {
    GimvZAlbumCell *cell;
 
