@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_zalbum.h,v 1.2 2003/06/13 09:43:33 makeinu Exp $
+ * $Id: gimv_zalbum.h,v 1.5 2004/09/21 08:44:32 makeinu Exp $
  */
 
 /*
@@ -78,7 +78,7 @@ struct _GimvZAlbum
    gint max_cell_width;
    gint max_cell_height;
 
-   gint len;
+   guint len;
 };
 
 struct _GimvZAlbumClass
@@ -103,6 +103,11 @@ GtkType    gimv_zalbum_get_type                  (void);
 GtkWidget *gimv_zalbum_new                       (void);
 guint      gimv_zalbum_add                       (GimvZAlbum       *album,
                                                   const gchar      *name);
+guint      gimv_zalbum_insert                    (GimvZAlbum       *album,
+                                                  guint             pos,
+                                                  const gchar      *name);
+void       gimv_zalbum_remove                    (GimvZAlbum       *album,
+                                                  guint             pos);
 void       gimv_zalbum_set_label_position        (GimvZAlbum       *album,
                                                   GimvZAlbumLabelPosition pos);
 void       gimv_zalbum_set_min_pixmap_size       (GimvZAlbum       *album,
