@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_zlist.c,v 1.2 2003/06/13 09:43:33 makeinu Exp $
+ * $Id: gimv_zlist.c,v 1.5 2004/09/21 08:44:32 makeinu Exp $
  */
 
 /*
@@ -39,7 +39,7 @@
 #include "gtk2-compat.h"
 #include "gimv_zlist.h"
 
-#define bw(widget)                  (gint) GTK_CONTAINER(widget)->border_width
+#define bw(widget) ((gint) GTK_CONTAINER(widget)->border_width)
 
 #define CELL_COL_FROM_X(list, x) \
    (GIMV_SCROLLED_VX (list, (x) - (list)->x_pad - bw (list)) / (list)->cell_width)
@@ -51,8 +51,8 @@
 #define CELL_Y_FROM_ROW(list, row) \
    (GIMV_SCROLLED_Y (list, (row) * (list)->cell_height + (list)->y_pad)) 
 
-#define LIST_WIDTH(list)            ((list)->columns * (list)->cell_width)
-#define LIST_HEIGHT(list)           ((list)->rows * (list)->cell_height)
+#define LIST_WIDTH(list)  ((list)->columns * (list)->cell_width /* + (list)->cell_x_pad */)
+#define LIST_HEIGHT(list) ((list)->rows * (list)->cell_height /* + (list)->cell_y_pad */)
 
 #define HIGHLIGHT_SIZE 2
 
@@ -305,7 +305,8 @@ gimv_zlist_class_init (GimvZListClass *klass)
                       GTK_CLASS_TYPE(object_class),
                       GTK_SIGNAL_OFFSET(GimvZListClass, cell_draw),
                       gtk_marshal_NONE__POINTER_POINTER_POINTER,
-                      GTK_TYPE_NONE, 3, GTK_TYPE_POINTER, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+                      GTK_TYPE_NONE, 3,
+                      GTK_TYPE_POINTER, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
    gimv_zlist_signals [CELL_SIZE_REQUEST] = 
       gtk_signal_new ("cell_size_request",
@@ -313,7 +314,8 @@ gimv_zlist_class_init (GimvZListClass *klass)
                       GTK_CLASS_TYPE(object_class),
                       GTK_SIGNAL_OFFSET(GimvZListClass, cell_size_request),
                       gtk_marshal_NONE__POINTER_POINTER,
-                      GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+                      GTK_TYPE_NONE, 2,
+                      GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
    gimv_zlist_signals [CELL_DRAW_FOCUS] = 
       gtk_signal_new ("cell_draw_focus",
@@ -488,6 +490,7 @@ gimv_zlist_map (GtkWidget *widget)
 {
    GTK_WIDGET_SET_FLAGS(widget, GTK_MAPPED);
    gdk_window_show (widget->window);
+   gimv_zlist_update(GIMV_ZLIST (widget));
 }
 
 
@@ -674,12 +677,6 @@ gimv_zlist_get_cell_area (GimvZList *list, gint index, GdkRectangle *area)
 }
 
 
-void
-gimv_zlist_get_virtual_cell_area (GimvZList *list, gint index, GdkRectangle *area)
-{
-}
-
-
 static void        
 gimv_zlist_draw_horizontal_list (GtkWidget *widget, GdkRectangle *area)
 {
@@ -764,6 +761,12 @@ gimv_zlist_draw_horizontal_list (GtkWidget *widget, GdkRectangle *area)
       gdk_window_clear_area (widget->window,
                              CELL_X_FROM_COL(list, j), area->y,
                              c, area->height);
+   /* clear the bottom of the list */
+   c = area->y + area->height - CELL_Y_FROM_ROW(list, last_row);
+   if (c > 0)
+      gdk_window_clear_area (widget->window,
+                             area->x, CELL_Y_FROM_ROW(list, last_row),
+                             area->width, c);
 }
 
 
@@ -844,6 +847,12 @@ gimv_zlist_draw_vertical_list (GtkWidget *widget, GdkRectangle *area)
       } /* columns loop */
    } /* rows loop */
 
+   /* clear the right of the list  XXX should hasppen */
+   c = area->x + area->width - CELL_X_FROM_COL(list, last_column);
+   if (c > 0)
+      gdk_window_clear_area (widget->window,
+                             CELL_X_FROM_COL(list, last_column), area->y,
+                             c, area->height);
    /* clear the bottom of the list */
    c = area->y + area->height - CELL_Y_FROM_ROW(list, i);
    if (c > 0)
@@ -951,8 +960,8 @@ gimv_zlist_draw (GtkWidget *widget, GdkRectangle *area)
 
 static void
 gimv_zlist_redraw_selection_region (GtkWidget *widget,
-                               gint prev_x, gint prev_y,
-                               gint next_x, gint next_y)
+                                    gint prev_x, gint prev_y,
+                                    gint next_x, gint next_y)
 {
    GimvScrolled *scrolled;
    GdkRectangle widget_area, area, draw_area;
@@ -1234,12 +1243,12 @@ gimv_zlist_motion_notify (GtkWidget *widget, GdkEventMotion *event)
          end_y   = MAX (scrolled->drag_start_vy, GIMV_SCROLLED_VY (scrolled, event->y));
 
          gimv_zlist_cell_select_by_pixel_region (list,
-                                            start_x, start_y,
-                                            end_x, end_y);
+                                                 start_x, start_y,
+                                                 end_x, end_y);
 
          gimv_zlist_redraw_selection_region (widget,
-                                        prev_x, prev_y,
-                                        event->x, event->y);
+                                             prev_x, prev_y,
+                                             event->x, event->y);
       }
    }
 
@@ -1320,15 +1329,15 @@ gimv_zlist_key_press (GtkWidget *widget, GdkEventKey *event)
       case GDK_Right:
          direction = GTK_DIR_RIGHT;
          break;
-         /*
-           case GDK_Tab:
-           case GDK_ISO_Left_Tab:
-           if (event->state & GDK_SHIFT_MASK)
-           direction = GTK_DIR_TAB_BACKWARD;
-           else
-           direction = GTK_DIR_TAB_FORWARD;
-           break;
-         */
+      /*
+      case GDK_Tab:
+      case GDK_ISO_Left_Tab:
+         if (event->state & GDK_SHIFT_MASK)
+            direction = GTK_DIR_TAB_BACKWARD;
+         else
+            direction = GTK_DIR_TAB_FORWARD;
+          break;
+      */
       case GDK_Page_Up:
          gimv_scrolled_page_up (GIMV_SCROLLED (widget));
          break;
@@ -1381,10 +1390,10 @@ gimv_zlist_focus_out (GtkWidget *widget, GdkEventFocus *event)
 
 static gint        
 gimv_zlist_drag_motion (GtkWidget      *widget,
-                   GdkDragContext *context,
-                   gint            x,
-                   gint            y,
-                   guint           time)
+                        GdkDragContext *context,
+                        gint            x,
+                        gint            y,
+                        guint           time)
 {
    GimvZList *list;
    gint index, retval = FALSE;
@@ -1408,8 +1417,8 @@ gimv_zlist_drag_motion (GtkWidget      *widget,
    if (index < 0)
       return retval || FALSE;
    /*
-     if (g_list_find (ZLIST(widget)->selection, GUINT_TO_POINTER(index)))
-     return TRUE;
+   if (g_list_find (ZLIST(widget)->selection, GUINT_TO_POINTER(index)))
+      return TRUE;
    */
    return retval || FALSE;
 }
@@ -1417,10 +1426,10 @@ gimv_zlist_drag_motion (GtkWidget      *widget,
 
 static gint        
 gimv_zlist_drag_drop (GtkWidget *widget,
-                 GdkDragContext *context,
-                 gint x,
-                 gint y,
-                 guint time)
+                      GdkDragContext *context,
+                      gint x,
+                      gint y,
+                      guint time)
 {
    GimvZList *list;
 
@@ -1435,8 +1444,8 @@ gimv_zlist_drag_drop (GtkWidget *widget,
 
 static void        
 gimv_zlist_drag_leave (GtkWidget *widget,
-                  GdkDragContext *context,
-                  guint time)
+                       GdkDragContext *context,
+                       guint time)
 {
    GimvZList *list;
 
@@ -1507,20 +1516,19 @@ gimv_zlist_unhighlight (GtkWidget *widget)
 
 static void        
 gimv_zlist_forall (GtkContainer *container,
-              gboolean include_internals,
-              GtkCallback callback,
-              gpointer callback_data)
+                   gboolean include_internals,
+                   GtkCallback callback,
+                   gpointer callback_data)
 {
-  
    /*
-     GimvZList *list;
-     gint i;
+   GimvZList *list;
+   gint i;
 
-     list = ZLIST(container);
+   list = ZLIST(container);
 
-     if (include_internals)
-     for (i = 0; i < list->cell_count; i++)
-     (* callback) (GIMV_ZLIST_CELL_FROM_INDEX (list, i), callback_data);
+   if (include_internals)
+   for (i = 0; i < list->cell_count; i++)
+      (* callback) (GIMV_ZLIST_CELL_FROM_INDEX (list, i), callback_data);
    */
 }
 
@@ -1571,13 +1579,24 @@ gimv_zlist_focus (GtkContainer *container, GtkDirectionType dir)
 
 guint
 gimv_zlist_add (GimvZList *list, gpointer cell)
+{
+   g_return_val_if_fail (GIMV_IS_ZLIST (list), 0);
+
+   return gimv_zlist_insert (list, list->cells->len, cell);
+}
+
+
+guint
+gimv_zlist_insert (GimvZList *list, guint pos, gpointer cell)
 {
    GtkRequisition requisition = { 0 };
    gint adjust = FALSE;
-   guint retval;
 
-   list->cells = g_array_append_val (list->cells, cell);
-   retval = list->cells->len - 1;
+   g_return_val_if_fail (GIMV_IS_ZLIST (list), 0);
+
+   if (pos > list->cells->len)
+      pos = list->cells->len;
+   list->cells = g_array_insert_val (list->cells, pos, cell);
 
 #ifdef USE_GTK2
    g_signal_emit (G_OBJECT(list), gimv_zlist_signals [CELL_SIZE_REQUEST], 0,
@@ -1601,11 +1620,13 @@ gimv_zlist_add (GimvZList *list, gpointer cell)
 
    list->cell_count++;
 
-   if (requisition.width  + list->cell_x_pad > list->cell_width
-       || requisition.height + list->cell_y_pad > list->cell_height)
+   if (requisition.width  + list->cell_x_pad > list->cell_width ||
+       requisition.height + list->cell_y_pad > list->cell_height)
    {
-      list->cell_width  = MAX(list->cell_width,  requisition.width  + list->cell_x_pad);
-      list->cell_height = MAX(list->cell_height, requisition.height + list->cell_y_pad);
+      list->cell_width
+         = MAX(list->cell_width, requisition.width + list->cell_x_pad);
+      list->cell_height
+         = MAX(list->cell_height, requisition.height + list->cell_y_pad);
 
       gimv_zlist_update (list);
       WIDGET_DRAW (GTK_WIDGET (list));
@@ -1615,10 +1636,11 @@ gimv_zlist_add (GimvZList *list, gpointer cell)
       if (adjust)
          gimv_zlist_adjust_adjustments (GIMV_SCROLLED(list));
 
+      gimv_zlist_update (list);
       gimv_zlist_draw_cell (list, list->cell_count - 1);
    }
 
-   return retval;
+   return pos;
 }
 
 
@@ -1668,6 +1690,8 @@ gimv_zlist_remove (GimvZList *list, gpointer cell)
    /* using gdk_window_copy_area will be faster but harder too */
    area.width  = GTK_WIDGET(list)->allocation.width  - area.x;
    area.height = GTK_WIDGET(list)->allocation.height - area.y; 
+
+   gimv_zlist_update (list);
    gimv_zlist_draw (GTK_WIDGET(list), &area); 
 
    if (list->flags & GIMV_ZLIST_HORIZONTAL) {
@@ -1706,7 +1730,7 @@ gimv_zlist_adjust_adjustments (GimvScrolled *scrolled)
       adj->page_increment = adj->page_size;
       adj->step_increment = list->cell_width;
       adj->lower          = 0;
-      adj->upper          = LIST_WIDTH(list) + 2 * list->x_pad;
+      adj->upper          = LIST_WIDTH(list) + 2 * list->x_pad + list->cell_x_pad;
 
 #ifdef USE_GTK2
       g_signal_emit_by_name (G_OBJECT(adj), "changed");
@@ -1722,7 +1746,7 @@ gimv_zlist_adjust_adjustments (GimvScrolled *scrolled)
       adj->page_increment = adj->page_size;
       adj->step_increment = list->cell_height;
       adj->lower          = 0;
-      adj->upper          = LIST_HEIGHT(list) + 2 * list->y_pad;
+      adj->upper          = LIST_HEIGHT(list) + 2 * list->y_pad + list->cell_y_pad;
 
 #ifdef USE_GTK2
       g_signal_emit_by_name (G_OBJECT(adj), "changed");
@@ -2177,10 +2201,11 @@ select_each_cell_by_region (GimvZList *list, gint index, gboolean in_region)
 
 void
 gimv_zlist_cell_select_by_region (GimvZList *list,
-                             guint start_col, guint start_row,
-                             guint end_col, guint end_row)
+                                  guint start_col, guint start_row,
+                                  guint end_col, guint end_row)
 {
-   gint index = 0, i, j, col, row, cols, rows;
+   gint index = 0, i, j, cols, rows;
+   guint col, row;
 
    g_return_if_fail (list);
    g_return_if_fail (GIMV_IS_ZLIST (list));
@@ -2227,8 +2252,8 @@ gimv_zlist_cell_select_by_region (GimvZList *list,
 
 void
 gimv_zlist_cell_select_by_pixel_region (GimvZList *list,
-                                   gint start_x, gint start_y,
-                                   gint end_x, gint end_y)
+                                        gint start_x, gint start_y,
+                                        gint end_x, gint end_y)
 {
    gint start_col, start_row, end_col, end_row, cell_x, cell_y;
 
@@ -2253,12 +2278,12 @@ gimv_zlist_cell_select_by_pixel_region (GimvZList *list,
    end_row   = end_y   / list->cell_height;
 
    /*
-     cell_x = CELL_X_FROM_COL(list, start_col);
-     if (start_x  < list->cell_x_pad * 2 + cell_x && start_col > 1)
-     start_col--;
-     cell_y = CELL_Y_FROM_ROW(list, start_row);
-     if (start_y < list->cell_y_pad * 2 + cell_y && start_row > 1)
-     start_row--;
+   cell_x = CELL_X_FROM_COL(list, start_col);
+   if (start_x  < list->cell_x_pad * 2 + cell_x && start_col > 1)
+      start_col--;
+      cell_y = CELL_Y_FROM_ROW(list, start_row);
+   if (start_y < list->cell_y_pad * 2 + cell_y && start_row > 1)
+      start_row--;
    */
 
    cell_x = CELL_X_FROM_COL(list, end_col);
@@ -2278,8 +2303,8 @@ gimv_zlist_cell_select_by_pixel_region (GimvZList *list,
    }
 
    gimv_zlist_cell_select_by_region (list,
-                                start_col, start_row,
-                                end_col, end_row);
+                                     start_col, start_row,
+                                     end_col, end_row);
 }
 
 
