@@ -28,7 +28,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gtk_prop.c,v 1.11 2003/06/18 09:26:56 makeinu Exp $
+ * $Id: gtk_prop.c,v 1.12 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -449,8 +449,9 @@ dlg_prop (const gchar *path, fprop * prop, gint flags)
    }
 
    if (flags & GTK_PROP_EDITABLE) {
-      gint i;
-      for (i = 0; i < sizeof (perm) / sizeof (GtkWidget *); i++) {
+      gint i, n_perms;
+      n_perms = sizeof (perm) / sizeof (GtkWidget *);
+      for (i = 0; i < n_perms; i++) {
          gtk_widget_set_sensitive (perm[i], FALSE);
       }
    }
@@ -495,8 +496,9 @@ dlg_prop (const gchar *path, fprop * prop, gint flags)
    gtk_table_attach (GTK_TABLE (table), owner[3], 1, 2, 1, 2, 0, 0, X_PAD, 0);
 
    if (flags & GTK_PROP_EDITABLE) {
-      gint i;
-      for (i = 0; i < sizeof (owner) / sizeof (GtkWidget *); i++) {
+      gint i, n_owners;
+      n_owners = sizeof (owner) / sizeof (GtkWidget *);
+      for (i = 0; i < n_owners; i++) {
          gtk_widget_set_sensitive (owner[i], FALSE);
       }
    }
