@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gtkutils.c,v 1.29 2004/09/22 14:26:23 makeinu Exp $
+ * $Id: gtkutils.c,v 1.30 2004/10/03 14:53:55 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -581,8 +581,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
 
       dialog.iv1 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv1),
-                      "default_zoom",     "2",
-                      "default_rotation", "0",
+                      "default_zoom",     3,
+                      "default_rotation", 0,
                       "keep_aspect",     TRUE,
                       NULL);
       gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv1));
@@ -600,8 +600,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
 
       dialog.iv2 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv2),
-                      "default_zoom",     "2",
-                      "default_rotation", "0",
+                      "default_zoom",     3,
+                      "default_rotation", 0,
                       "keep_aspect",     TRUE,
                       NULL);
       gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv2));
