@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_draw.c,v 1.1.2.8 2003/06/09 12:46:12 makeinu Exp $
+ * $Id: image_view_draw.c,v 1.5 2003/07/20 14:38:10 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,8 +28,8 @@
 #include "cursors.h"
 #include "gimv_anim.h"
 #include "gimv_image_view.h"
+#include "gimv_thumb_cache.h"
 #include "prefs.h"
-#include "thumbnail_support.h"
 
 
 static gboolean cb_image_configure         (GtkWidget         *widget,
@@ -45,7 +45,7 @@ static void         imageview_draw_create_thumbnail     (GimvImageView *iv,
                                                          const gchar *type);
 
 static gboolean     imageview_draw_is_playable          (GimvImageView *iv,
-                                                         ImageInfo *info);
+                                                         GimvImageInfo *info);
 static void         imageview_animation_play            (GimvImageView *iv);
 static void         imageview_animation_stop            (GimvImageView *iv);
 #if 0
@@ -108,11 +108,10 @@ cb_destroy (GtkWidget *widget, GimvImageView *iv)
 
 
 static void
-cb_load_end_create_thumbnail (GimvImageView *iv, ImageInfo *info,
+cb_load_end_create_thumbnail (GimvImageView *iv, GimvImageInfo *info,
                               gboolean cancel, gpointer data)
 {
    GimvImage *imcache;
-   ThumbCacheSaveInfo *save_info;
    gchar *filename;
    gboolean free_buf = GPOINTER_TO_INT (data);
    gpointer id_p;
@@ -130,16 +129,14 @@ cb_load_end_create_thumbnail (GimvImageView *iv, ImageInfo *info,
    if (!iv->image) return;
    if (iv->info != iv->loader->info) return;
 
-   filename = image_info_get_path_with_archive (iv->info);
-   save_info = thumbsupport_save_info_new (iv->info, NULL);
+   filename = gimv_image_info_get_path_with_archive (iv->info);
 
    /* FIXME: conf.cache_write_type is hard coded */
-   imcache = thumbsupport_save_thumbnail_cache (filename,
-                                                conf.cache_write_type,
-                                                iv->image,
-                                                save_info);
+   imcache = gimv_thumb_cache_save (filename,
+                                    conf.cache_write_type,
+                                    iv->image,
+                                    iv->info);
 
-   thumbsupport_save_info_delete (save_info);
    g_free (filename);
 
    if (free_buf)
@@ -225,7 +222,7 @@ timeout_animation (gpointer data)
    gint idx, interval;
 
    if (!iv->image) goto END;
-   if (!gimv_image_is_anim (iv->image)) goto END;
+   if (!GIMV_IS_ANIM (iv->image)) goto END;
 
    idx = gimv_anim_iterate ((GimvAnim *) iv->image);
 
@@ -264,7 +261,7 @@ idle_animation_play (gpointer data)
    if (!GIMV_IS_IMAGE_VIEW (iv)) goto END;
    if (!iv->info) goto END;
 
-   if (!image_info_is_animation (iv->info)) goto END;
+   if (!gimv_image_info_is_animation (iv->info)) goto END;
 
    imageview_animation_stop (iv);
 
@@ -354,12 +351,12 @@ imageview_draw_create_thumbnail (GimvImageView *iv, const gchar *cache_write_typ
 
 
 static gboolean
-imageview_draw_is_playable (GimvImageView *iv, ImageInfo *info)
+imageview_draw_is_playable (GimvImageView *iv, GimvImageInfo *info)
 {
    g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
    if (!info) return FALSE;
 
-   return image_info_is_animation (info);
+   return gimv_image_info_is_animation (info);
 }
 
 
@@ -380,7 +377,7 @@ imageview_animation_stop (GimvImageView *iv)
    imageview_animation_pause (iv);
 
    if (!iv->info) return;
-   if (!image_info_is_animation (iv->info)) return;
+   if (!gimv_image_info_is_animation (iv->info)) return;
 
    gimv_anim_seek ((GimvAnim *) iv->image, 0);
 
@@ -441,7 +438,7 @@ imageview_draw_get_status (GimvImageView *iv)
 
    g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), GimvImageViewPlayableDisable);
 
-   if (!iv->info || !image_info_is_animation (iv->info))
+   if (!iv->info || !gimv_image_info_is_animation (iv->info))
       return GimvImageViewPlayableDisable;
 
    timer_p = g_hash_table_lookup (animation_id_table, iv);
