@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: japanese.c,v 1.8 2003/06/13 09:43:37 makeinu Exp $
+ * $Id: japanese.c,v 1.9 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -26,6 +26,7 @@
 #include <string.h>
 
 #include "charset.h"
+#include "japanese.h"
 
 /* force convert hankaku SJIS character to zenkaku */
 #undef NO_HANKAKU_SJIS
@@ -102,17 +103,22 @@ static const gchar *locale_sjis[] = {
 const gchar *
 japanese_locale_charset (const gchar *locale)
 {
-   gint i;
+   gint i, n_locale_euc, n_locale_jis, n_locale_sjis;
 
    if (!locale || !*locale) return NULL;
 
-   for (i = 0; i < sizeof (locale_euc) / sizeof (gchar*); i++)
+   n_locale_euc = sizeof (locale_euc) / sizeof (gchar*);
+   for (i = 0; i < n_locale_euc; i++)
       if (!g_strcasecmp (locale_euc[i], locale))
          return CHARSET_EUC_JP;
-   for (i = 0; i < sizeof (locale_jis) / sizeof (gchar*); i++)
+
+   n_locale_jis = sizeof (locale_jis) / sizeof (gchar*);
+   for (i = 0; i < n_locale_jis; i++)
       if (!g_strcasecmp (locale_jis[i], locale))
          return CHARSET_JIS;
-   for (i = 0; i < sizeof (locale_sjis) / sizeof (gchar*); i++)
+
+   n_locale_sjis = sizeof (locale_sjis) / sizeof (gchar*);
+   for (i = 0; i < n_locale_sjis; i++)
       if (!g_strcasecmp (locale_sjis[i], locale))
          return CHARSET_SJIS;
 
