@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs.c,v 1.76 2003/06/15 16:14:53 makeinu Exp $
+ * $Id: prefs.c,v 1.81 2004/09/29 06:13:50 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -147,12 +147,11 @@ static ConfParam param_imageview [] = {
    {"imgwin_fullscreen_bg_green", D_INT,  "0",     &conf.imgwin_fullscreen_bg_color[1]},
    {"imgwin_fullscreen_bg_blue",  D_INT,  "0",     &conf.imgwin_fullscreen_bg_color[2]},
 
-   {"imgview_fit_image_to_win",   D_BOOL,   "TRUE",    &conf.imgview_fit_image_to_win},
-   {"imgview_fit_image_zoom_out_only", D_BOOL, "TRUE", &conf.imgview_fit_image_zoom_out_only},
+   {"imgview_default_zoom",       D_ENUM,   "3",       &conf.imgview_default_zoom},
+   {"imgview_default_rotation",   D_ENUM,   "0",       &conf.imgview_default_rotation},
    {"imgview_keep_aspect",        D_BOOL,   "TRUE",    &conf.imgview_keep_aspect},
    {"imgview_scale",              D_FLOAT,  "100.0",   &conf.imgview_scale},
    {"imgview_buffer",             D_BOOL,   "FALSE",   &conf.imgview_buffer},
-   {"imgview_auto_rotation",      D_BOOL,   "FALSE",   &conf.imgview_auto_rotation},
    {"imgview_scrollbar",          D_BOOL,   "TRUE",    &conf.imgview_scrollbar},
    {"imgview_player_visible",     D_ENUM,   "2",       &conf.imgview_player_visible},
    {"imgview_scroll_nolimit",     D_BOOL,   "FALSE",   &conf.imgview_scroll_nolimit},
@@ -190,7 +189,7 @@ static ConfParam param_thumbview [] = {
    {"thumbwin_raise_window",    D_BOOL,   "TRUE",  &conf.thumbwin_raise_window},
    {"thumbwin_toolbar_style",   D_ENUM,   "0",     &conf.thumbwin_toolbar_style},
 
-   {"thumbwin_disp_mode",       D_STRING, DEFAULT_DISP_MODE, &conf.thumbwin_disp_mode},
+   {"thumbwin_disp_mode",       D_STRING, GIMV_THUMB_VIEW_DEFAULT_SUMMARY_MODE, &conf.thumbwin_disp_mode},
    {"thumbwin_tab_pos",         D_ENUM,   "2",     &conf.thumbwin_tab_pos},
    {"thumbwin_move_to_newtab",  D_BOOL,   "TRUE",  &conf.thumbwin_move_to_newtab},
    {"thumbwin_show_tab_close",  D_BOOL,   "TRUE",  &conf.thumbwin_show_tab_close},
@@ -221,14 +220,13 @@ static ConfParam param_thumbalbum [] = {
 };
 
 static ConfParam param_preview [] = {
-   {"preview_fit_image_to_frame", D_BOOL, "TRUE",  &conf.preview_fit_image_to_frame},
-   {"preview_fit_image_zoom_out_only", D_BOOL, "TRUE", &conf.preview_fit_image_zoom_out_only},
+   {"preview_zoom",               D_ENUM, "3",     &conf.preview_zoom},
+   {"preview_rotation",           D_ENUM, "0",     &conf.preview_rotation},
    {"preview_keep_aspect",        D_BOOL, "TRUE",  &conf.preview_keep_aspect},
    {"preview_scale",              D_FLOAT,"100.0", &conf.preview_scale},
    {"preview_scrollbar",          D_BOOL, "TRUE",  &conf.preview_scrollbar},
    {"preview_player_visible",     D_ENUM, "2",     &conf.preview_player_visible},
    {"preview_buffer",             D_BOOL, "FALSE", &conf.preview_buffer},
-   {"preview_auto_rotation",      D_BOOL, "FALSE", &conf.preview_auto_rotation},
    {"preview_mouse_button",       D_STRING,
     "0,0,0,0; -1,-2,0,0; -4,0,0,0; 5,0,0,0; 2,0,0,0; 1,0,0,0",
     &conf.preview_mouse_button},
@@ -271,21 +269,22 @@ static ConfParam param_comment [] = {
 };
 
 static ConfParam param_slideshow [] = {
-   {"slideshow_fit_to_win",     D_BOOL, "FALSE", &conf.slideshow_fit_to_win},
-   {"slideshow_img_scale",      D_FLOAT,"100.0", &conf.slideshow_img_scale},
-   {"slideshow_screen_mode",    D_ENUM, "0",     &conf.slideshow_screen_mode},
-   {"slideshow_menubar",        D_BOOL, "FALSE", &conf.slideshow_menubar},
-   {"slideshow_toolbar",        D_BOOL, "FALSE", &conf.slideshow_toolbar},
-   {"slideshow_player",         D_BOOL, "FALSE", &conf.slideshow_player},
-   {"slideshow_statusbar",      D_BOOL, "FALSE", &conf.slideshow_statusbar},
-   {"slideshow_scrollbar",      D_BOOL, "FALSE", &conf.slideshow_scrollbar},
-   {"slideshow_keep_aspcet",    D_BOOL, "TRUE",  &conf.slideshow_keep_aspect},
-   {"slideshow_interval",       D_FLOAT,"5.00",  &conf.slideshow_interval},
-   {"slideshow_repeat",         D_BOOL, "FALSE", &conf.slideshow_repeat},
-   {"slideshow_set_bg",         D_BOOL, "FALSE", &conf.slideshow_set_bg},
-   {"slideshow_bg_red",         D_INT,  "0",     &conf.slideshow_bg_color[0]},
-   {"slideshow_bg_green",       D_INT,  "0",     &conf.slideshow_bg_color[1]},
-   {"slideshow_bg_blue",        D_INT,  "0",     &conf.slideshow_bg_color[2]},
+   {"slideshow_zoom",             D_ENUM, "3",     &conf.slideshow_zoom},
+   {"slideshow_rotation",         D_ENUM, "0",     &conf.slideshow_rotation},
+   {"slideshow_img_scale",        D_FLOAT,"100.0", &conf.slideshow_img_scale},
+   {"slideshow_screen_mode",      D_ENUM, "0",     &conf.slideshow_screen_mode},
+   {"slideshow_menubar",          D_BOOL, "FALSE", &conf.slideshow_menubar},
+   {"slideshow_toolbar",          D_BOOL, "FALSE", &conf.slideshow_toolbar},
+   {"slideshow_player",           D_BOOL, "FALSE", &conf.slideshow_player},
+   {"slideshow_statusbar",        D_BOOL, "FALSE", &conf.slideshow_statusbar},
+   {"slideshow_scrollbar",        D_BOOL, "FALSE", &conf.slideshow_scrollbar},
+   {"slideshow_keep_aspcet",      D_BOOL, "TRUE",  &conf.slideshow_keep_aspect},
+   {"slideshow_interval",         D_FLOAT,"5.00",  &conf.slideshow_interval},
+   {"slideshow_repeat",           D_BOOL, "FALSE", &conf.slideshow_repeat},
+   {"slideshow_set_bg",           D_BOOL, "FALSE", &conf.slideshow_set_bg},
+   {"slideshow_bg_red",           D_INT,  "0",     &conf.slideshow_bg_color[0]},
+   {"slideshow_bg_green",         D_INT,  "0",     &conf.slideshow_bg_color[1]},
+   {"slideshow_bg_blue",          D_INT,  "0",     &conf.slideshow_bg_color[2]},
    {NULL, D_NULL, NULL, NULL}
 };
 
@@ -485,7 +484,7 @@ store_config (gpointer data, gchar *val, DataType type)
  *  prefs_load_config_default:
  *     @ Load default config.
  */
-void
+static void
 prefs_load_config_default (PrefsSection *sections)
 {
    gint i, j;
@@ -503,7 +502,7 @@ prefs_load_config_default (PrefsSection *sections)
  *  prefs_load_rc:
  *     @ Load config from disk.
  */
-void
+static void
 prefs_load_rc (gchar *filename, PrefsSection *sections)
 {
    gchar rcfile[MAX_PATH_LEN];
@@ -576,7 +575,7 @@ prefs_load_config (void)
  *  prefs_save_rc:
  *     @ Save config to disk.
  */
-void
+static void
 prefs_save_rc (gchar *filename, PrefsSection *sections)
 {
    gchar dir[MAX_PATH_LEN], rcfile[MAX_PATH_LEN];
@@ -702,7 +701,8 @@ prefs_mouse_get_num_from_event (GdkEventButton *event, const gchar *string)
       bid = 0;
    else
       bid = event->button;
-   g_return_val_if_fail (bid >= 0 && bid < 6, 0);
+   if (bid < 0 || bid > 5)
+      return 0;
 
    /* get modifier id */
    if (event->state & GDK_SHIFT_MASK)
