@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs.h,v 1.58 2003/07/05 16:41:11 makeinu Exp $
+ * $Id: prefs.h,v 1.60 2004/09/22 14:26:23 makeinu Exp $
  */
 
 #ifndef __PREFS_H__
@@ -102,10 +102,9 @@ typedef struct _Config {
 
    gfloat     imgview_scale;
    gboolean   imgview_keep_aspect;
-   gboolean   imgview_fit_image_to_win;
-   gboolean   imgview_fit_image_zoom_out_only;
+   gint       imgview_default_zoom;
+   gint       imgview_default_rotation;
    gboolean   imgview_buffer;
-   gboolean   imgview_auto_rotation;
    gboolean   imgview_scrollbar;
    gint       imgview_player_visible;
    gboolean   imgview_scroll_nolimit;
@@ -176,13 +175,12 @@ typedef struct _Config {
 
    /* Preview */
    gfloat     preview_scale;
+   gint       preview_zoom;
+   gint       preview_rotation;
    gboolean   preview_keep_aspect;
-   gboolean   preview_fit_image_to_frame;
-   gboolean   preview_fit_image_zoom_out_only;
    gboolean   preview_scrollbar;
    gint       preview_player_visible;
    gboolean   preview_buffer;
-   gboolean   preview_auto_rotation;
    gchar     *preview_mouse_button;
 
    /* Thumbnail Cache */
@@ -200,7 +198,8 @@ typedef struct _Config {
    gchar     *movie_default_view_mode;
 
    /* Slide Show */
-   gboolean   slideshow_fit_to_win;
+   gint       slideshow_zoom;
+   gint       slideshow_rotation;
    gfloat     slideshow_img_scale;
    gint       slideshow_screen_mode;
    gboolean   slideshow_menubar;
