@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_common.c,v 1.5 2003/06/13 09:43:43 makeinu Exp $
+ * $Id: prefs_ui_common.c,v 1.6 2004/09/22 14:26:23 makeinu Exp $
  */
 
 #include <string.h>
@@ -531,7 +531,7 @@ cb_filename_charset_conv (GtkWidget *widget, gpointer data)
 GtkWidget *
 prefs_common_page (void)
 {
-   GtkWidget *main_vbox, *frame, *table, *vbox;
+   GtkWidget *main_vbox, *frame, *table, *vbox, *alignment;
 #if HAVE_GDK_PIXBUF
    GtkWidget *hbox;
 #endif /* HAVE_GDK_PIXBUF */
@@ -550,39 +550,48 @@ prefs_common_page (void)
    gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
    gtk_box_pack_start(GTK_BOX(main_vbox), frame, FALSE, TRUE, 0);
 
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (frame), alignment);
+
    table = gtk_table_new (3, 2, FALSE);
    gtk_container_set_border_width(GTK_CONTAINER(table), 5);
-   gtk_container_add (GTK_CONTAINER (frame), table);
+   gtk_container_add (GTK_CONTAINER (alignment), table);
 
    /* File Open Window Selection */
    label = gtk_label_new (_("File Open Window"));
-   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                     GTK_EXPAND, GTK_FILL, 0, 0);
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
    option_menu = create_option_menu_simple (open_window_items,
                                             conf.default_file_open_window,
                                             &config_changed->default_file_open_window);
    gtk_table_attach (GTK_TABLE (table), option_menu, 1, 2, 0, 1,
-                     GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+                     GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 1);
 
    /* Directory Open Window Selection */
    label = gtk_label_new (_("Directory Open Window"));
-   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                     GTK_EXPAND, GTK_FILL, 0, 0);
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
    option_menu = create_option_menu_simple (open_window_items,
                                             conf.default_dir_open_window,
                                             &config_changed->default_dir_open_window);
    gtk_table_attach (GTK_TABLE (table), option_menu, 1, 2, 1, 2,
-                     GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+                     GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 1);
 
    /* Archive Open Window Selection */
    label = gtk_label_new (_("Archive Open Window"));
-   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                     GTK_EXPAND, GTK_FILL, 0, 0);
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 2, 3,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
    option_menu = create_option_menu_simple (open_window_items,
                                             conf.default_arc_open_window,
                                             &config_changed->default_arc_open_window);
    gtk_table_attach (GTK_TABLE (table), option_menu, 1, 2, 2, 3,
-                     GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+                     GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 1);
    gtk_widget_set_sensitive (option_menu, FALSE);
 
 
