@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_etc.c,v 1.5 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: prefs_ui_etc.c,v 1.9 2004/09/29 03:45:56 makeinu Exp $
  */
 
 #include <string.h>
@@ -30,6 +30,7 @@
 #include "gimv_elist.h"
 #include "gtk2-compat.h"
 #include "gtkutils.h"
+#include "menu.h"
 #include "prefs.h"
 #include "prefs_ui_etc.h"
 #include "gimv_prefs_ui_utils.h"
@@ -50,12 +51,20 @@ typedef struct PrefsWin_Tag {
    GtkWidget *comment_status_toggle;
    GtkWidget *comment_auto_toggle;
    GtkWidget *comment_disp_toggle;
+
+   /* slideshow */
+   GtkWidget *slideshow_scale_spin;
+   GtkWidget *slideshow_fit_only_zoom_out;
 } PrefsWin;
 
 static PrefsWin  prefs_win;
 extern Config   *config_changed;
 extern Config   *config_prechanged;
 
+/* next two imported from prefs_ui_imagewin.c */
+
+extern const gchar *rotate_menu_items[];
+extern const gchar *zoom_menu_items[];
 
 static gint
 cb_dummy (GtkWidget *button, gpointer data)
@@ -64,7 +73,7 @@ cb_dummy (GtkWidget *button, gpointer data)
 }
 
 
-void
+static void
 set_sensitive_cache_write (void)
 {
    GtkWidget *option_menu = prefs_win.cache_write_type;
@@ -101,7 +110,7 @@ cb_cache_write_type (GtkWidget *widget, gchar *data)
 }
 
 
-void
+static void
 cb_cache_write_prefs_ok (GtkWidget *widget)
 {
    g_return_if_fail (GTK_IS_WINDOW (widget));
@@ -496,6 +505,18 @@ cb_comment_charset_changed (GtkEditable *entry, gpointer data)
       = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
 }
 
+static void
+cb_zoom_menu (GtkWidget *menu)
+{
+   config_changed->slideshow_zoom =
+      GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(menu), "num"));
+
+   gtk_widget_set_sensitive (prefs_win.slideshow_scale_spin,
+                             config_changed->slideshow_zoom == 0 ||
+                             config_changed->slideshow_zoom == 1);
+}
+
+
 
 /*******************************************************************************
  *  prefs_cache_page:
@@ -813,8 +834,8 @@ GtkWidget *
 prefs_slideshow_page (void)
 {
    GtkWidget *main_vbox, *frame;
-   GtkWidget *hbox, *vbox;
-   GtkWidget *label;
+   GtkWidget *hbox, *vbox, *table, *alignment;
+   GtkWidget *label, *option_menu;
    GtkWidget *spinner, *toggle, *button;
    GtkAdjustment *adj;
 
@@ -849,14 +870,6 @@ prefs_slideshow_page (void)
                                          &config_changed->slideshow_repeat);
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 
-   /* fit to window */
-   toggle = gtkutil_create_check_button (_("Auto resize to window size"),
-                                         conf.slideshow_fit_to_win,
-                                         gtkutil_get_data_from_toggle_cb,
-                                         &config_changed->slideshow_fit_to_win);
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-
-
 #if 0
    /********************************************** 
     * Show/Hide Frame
@@ -888,6 +901,75 @@ prefs_slideshow_page (void)
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 #endif
 
+   /********************************************** 
+    * Image Frame
+    **********************************************/
+   gimv_prefs_ui_create_frame(_("Image"), frame, vbox, main_vbox, FALSE);
+
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
+
+   table = gtk_table_new (2, 2, FALSE);
+   gtk_container_add (GTK_CONTAINER (alignment), table);
+
+   /* Zoom menu */
+   label = gtk_label_new (_("Zoom:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu (zoom_menu_items,
+                                     conf.slideshow_zoom,
+                                     cb_zoom_menu, NULL);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   /* Rotate menu */
+   label = gtk_label_new (_("Rotation:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu_simple (rotate_menu_items,
+                                            conf.slideshow_rotation,
+                                            &config_changed->slideshow_rotation);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   /* Keep Aspect Ratio */
+   toggle = gtkutil_create_check_button (_("Keep aspect rario"),
+                                         conf.slideshow_keep_aspect,
+                                         gtkutil_get_data_from_toggle_cb,
+                                         &config_changed->slideshow_keep_aspect);
+   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+
+   /* Default Image Scale Spinner */
+   hbox = gtk_hbox_new (FALSE, 5);
+   gtk_container_set_border_width (GTK_CONTAINER(hbox), 5);
+   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+   label = gtk_label_new (_("Default Image Scale"));
+   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+   adj = (GtkAdjustment *) gtk_adjustment_new (conf.slideshow_img_scale,
+                                               1.0, 10000.0, 1.0, 5.0, 0.0);
+   spinner = gtkutil_create_spin_button (adj);
+   gtk_widget_set_usize(spinner, 50, -1);
+   prefs_win.slideshow_scale_spin = spinner;
+   gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
+                       GTK_SIGNAL_FUNC (gtkutil_get_data_from_adjustment_by_int_cb),
+                       &config_changed->slideshow_img_scale);
+   gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
+   label = gtk_label_new (_("%"));
+   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+   gtk_widget_set_sensitive (prefs_win.slideshow_scale_spin,
+                             conf.slideshow_zoom == 0 ||
+                             conf.slideshow_zoom == 1);
+
 
    /********************************************** 
     * Back Ground Frame
@@ -908,6 +990,7 @@ prefs_slideshow_page (void)
                                       config_changed->slideshow_bg_color);
    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
+   /* show all */
    gtk_widget_show_all (main_vbox);
 
    return main_vbox;
@@ -968,4 +1051,3 @@ prefs_comment_apply (GimvPrefsWinAction action)
    gimv_comment_update_data_entry_list ();
    return FALSE;
 }
-
