@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_imagewin.c,v 1.4 2003/06/13 09:43:44 makeinu Exp $
+ * $Id: prefs_ui_imagewin.c,v 1.8 2004/09/29 03:45:56 makeinu Exp $
  */
 
 #include <string.h>
@@ -46,7 +46,6 @@ typedef struct PrefsWin_Tag {
    GtkWidget *imgwin_scrollbar_toggle;
    GtkWidget *imgwin_player_label;
    GtkWidget *imgwin_player_radio[3];
-   GtkWidget *image_fit_only_zoom_out;
    GtkWidget *image_scale_spin;
 } PrefsWin;
 
@@ -56,6 +55,28 @@ extern Config   *config_changed;
 extern Config   *config_prechanged;
 
 
+const gchar *rotate_menu_items[] = {
+   N_("0 degrees"),
+   N_("90 degrees CCW"),
+   N_("180 degrees"),
+   N_("90 degrees CW"),
+   N_("Do not change"),
+#ifdef ENABLE_EXIF
+   N_("Automatic EXIF"),
+#endif
+   NULL
+};
+
+const gchar *zoom_menu_items[] = {
+   N_("Default image scale"),
+   N_("Do not change"),
+   N_("Fit image to window"),
+   N_("Fit image to window (zoom out only)"),
+   N_("Fit image to width"),
+   N_("Fit image to height"),
+   NULL
+};
+
 static void
 set_sensitive_imgwin_state (void)
 {
@@ -91,14 +112,14 @@ cb_save_imgwin_state (GtkWidget *toggle)
 
 
 static void
-cb_fit_image_to_win (GtkWidget *toggle)
+cb_zoom_menu (GtkWidget *menu)
 {
-   config_changed->imgview_fit_image_to_win =
-      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(toggle));
-   gtk_widget_set_sensitive (prefs_win.image_fit_only_zoom_out,
-                             config_changed->imgview_fit_image_to_win);
+   config_changed->imgview_default_zoom =
+      GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(menu), "num"));
+
    gtk_widget_set_sensitive (prefs_win.image_scale_spin,
-                             !config_changed->imgview_fit_image_to_win);
+                             config_changed->imgview_default_zoom == 0 ||
+                             config_changed->imgview_default_zoom == 1);
 }
 
 
@@ -361,9 +382,11 @@ prefs_imagewin_image_page (void)
    GtkWidget *frame;
    GtkWidget *hbox, *vbox;
    GtkWidget *label;
+   GtkWidget *option_menu;
    GtkAdjustment *adj;
    GtkWidget *spinner;
    GtkWidget *toggle;
+   GtkWidget *table, *alignment;
 
    main_vbox = gtk_vbox_new (FALSE, 0);
    gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 5);
@@ -373,22 +396,44 @@ prefs_imagewin_image_page (void)
     **********************************************/
    gimv_prefs_ui_create_frame(_("Image"), frame, vbox, main_vbox, FALSE);
 
-   /* Auto resize image to window size */
-   toggle = gtkutil_create_check_button (_("Auto resize to window size when opening"),
-                                         conf.imgview_fit_image_to_win,
-                                         cb_fit_image_to_win, NULL);
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
 
-   /* Zoom out only */
-   toggle = gtkutil_create_check_button (_("Do not zoom in when fit to window automatically."),
-                                         conf.imgview_fit_image_zoom_out_only,
-                                         gtkutil_get_data_from_toggle_cb,
-                                         &config_changed->imgview_fit_image_zoom_out_only);
-   prefs_win.image_fit_only_zoom_out = toggle;
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+   table = gtk_table_new (2, 2, FALSE);
+   gtk_container_add (GTK_CONTAINER (alignment), table);
+
+   /* Default zoom action menu */
+   label = gtk_label_new (_("Zoom:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu (zoom_menu_items,
+                                     conf.imgview_default_zoom,
+                                     cb_zoom_menu, NULL);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   /* Rotate on image change */
+   label = gtk_label_new (_("Rotation:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu_simple (rotate_menu_items,
+                                            conf.imgview_default_rotation,
+                                            &config_changed->imgview_default_rotation);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
 
    /* Keep Aspect Ratio */
-   toggle = gtkutil_create_check_button (_("Keep aspect rario"),
+   toggle = gtkutil_create_check_button (_("Keep aspect ratio"),
                                          conf.imgview_keep_aspect,
                                          gtkutil_get_data_from_toggle_cb,
                                          &config_changed->imgview_keep_aspect);
@@ -406,15 +451,11 @@ prefs_imagewin_image_page (void)
    gtk_widget_set_usize(spinner, 50, -1);
    prefs_win.image_scale_spin = spinner;
    gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-                       GTK_SIGNAL_FUNC (gtkutil_get_data_from_adjustment_by_int_cb),
+                       GTK_SIGNAL_FUNC (gtkutil_get_data_from_adjustment_by_float_cb),
                        &config_changed->imgview_scale);
    gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
    label = gtk_label_new (_("%"));
    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-   /*
-   gtk_widget_set_sensitive (prefs_win.image_scale_spin,
-                             !conf.imgview_fit_image_to_win);
-   */
 
    /* keep original image on memory or not */
    toggle = gtkutil_create_check_button (_("Keep original image on memory"),
@@ -423,19 +464,12 @@ prefs_imagewin_image_page (void)
                                          &config_changed->imgview_buffer);
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 
-#ifdef ENABLE_EXIF
-   /* enable or disable automatic rotation by exif data */
-   toggle = gtkutil_create_check_button (_("Automatic rotation by EXIF data"),
-                                         conf.imgview_auto_rotation,
-                                         gtkutil_get_data_from_toggle_cb,
-                                         &config_changed->imgview_auto_rotation);
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-#endif /* ENABLE_EXIF */
-   gtk_widget_set_sensitive (prefs_win.image_fit_only_zoom_out,
-                             conf.imgview_fit_image_to_win);
+  
    gtk_widget_set_sensitive (prefs_win.image_scale_spin,
-                             !conf.imgview_fit_image_to_win);
+                             conf.imgview_default_zoom == 0 ||
+                             conf.imgview_default_zoom == 1);
 
+   /* show all */
    gtk_widget_show_all (main_vbox);
 
    return main_vbox;
@@ -485,15 +519,15 @@ prefs_ui_imagewin_image_apply (GimvPrefsWinAction action)
       iw = node->data;
 
       if (iw->iv) {
-         if (!dest->imgview_fit_image_to_win) {
+         if (!dest->imgview_default_zoom) {
             gtk_object_set (GTK_OBJECT (iw->iv),
                             "x_scale", dest->imgview_scale,
                             "y_scale", dest->imgview_scale,
                             NULL);
          }
          gtk_object_set (GTK_OBJECT (iw->iv),
-                         "fit_when_change",   dest->imgview_fit_image_to_win,
-                         "fit_zoom_out_only", dest->imgview_fit_image_zoom_out_only,
+                         "default_zoom",     dest->imgview_default_zoom,
+                         "default_rotation", dest->imgview_default_rotation,
                          NULL);
       }
    }
