@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_movie.c,v 1.1.2.4 2003/06/09 12:46:13 makeinu Exp $
+ * $Id: prefs_ui_movie.c,v 1.3 2003/07/06 16:46:21 makeinu Exp $
  */
 
 #include "prefs_ui_movie.h"
@@ -52,7 +52,7 @@ cb_movie_view_mode (GtkWidget *widget, gpointer data)
 GtkWidget *
 prefs_movie_page (void)
 {
-   GtkWidget *main_vbox, *hbox;
+   GtkWidget *main_vbox, *hbox, *vbox;
    GtkWidget *label, *option_menu;
    gint i, defval = 0;
 
@@ -83,8 +83,13 @@ prefs_movie_page (void)
    gtk_widget_show (hbox);
 
    if (movie_view_modes_len > 1) {
+      vbox = gtk_vbox_new (FALSE, 0);
+      gtk_container_set_border_width(GTK_CONTAINER (vbox), 0);
+      gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+      gtk_widget_show (vbox);
+
       label = gtk_label_new (_("Default view mode for movie and audio: "));
-      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+      gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 2);
       gtk_widget_show (label);
 
       for (i = 0; conf.movie_default_view_mode && movie_view_modes[i]; i++) {
@@ -96,7 +101,7 @@ prefs_movie_page (void)
 
       option_menu = create_option_menu (movie_view_modes, defval,
                                         cb_movie_view_mode, NULL);
-      gtk_box_pack_start (GTK_BOX (hbox), option_menu, FALSE, FALSE, 2);
+      gtk_box_pack_start (GTK_BOX (vbox), option_menu, FALSE, FALSE, 2);
       gtk_widget_show (option_menu);
 
    } else {
