@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_plugin.c,v 1.2 2003/06/13 09:43:44 makeinu Exp $
+ * $Id: prefs_ui_plugin.c,v 1.4 2004/09/22 15:37:12 makeinu Exp $
  */
 
 #include <string.h>
@@ -111,6 +111,10 @@ create_plugin_admin_widget (GList *plugin_list)
    scrollwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_container_set_border_width(GTK_CONTAINER(scrollwin), 5);
    gtk_box_pack_start (GTK_BOX (hbox), scrollwin, TRUE, TRUE, 0);
    gtk_widget_set_usize (scrollwin, -1, 200);
