@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_thumbwin.c,v 1.6 2003/06/18 09:26:56 makeinu Exp $
+ * $Id: prefs_ui_thumbwin.c,v 1.15 2004/09/29 03:45:56 makeinu Exp $
  */
 
 #include <string.h>
@@ -28,12 +28,13 @@
 #include "dirview.h"
 #include "gimv_prefs_ui_utils.h"
 #include "gimv_prefs_win.h"
+#include "gimv_thumb_view.h"
 #include "gimv_thumb_win.h"
 #include "gtkutils.h"
 #include "gtk2-compat.h"
 #include "menu.h"
 #include "prefs.h"
-#include "thumbnail_view.h"
+#include "prefs_ui_thumbwin.h"
 
 
 typedef struct PrefsWin_Tag {
@@ -194,6 +195,10 @@ static const gchar *preview_mouse_items[] = {
    NULL
 };
 
+/* next two imported from prefs_ui_imagewin.c */
+
+extern const gchar *rotate_menu_items[];
+extern const gchar *zoom_menu_items[];
 
 extern Config   *config_changed;
 extern Config   *config_prechanged;
@@ -323,12 +328,10 @@ set_sensitive_preview (void)
    if (prefs_win.preview_scrollbar_toggle)
       gtk_widget_set_sensitive (prefs_win.preview_scrollbar_toggle,
                                 !config_changed->thumbwin_save_win_state);
-   if (prefs_win.preview_fit_only_zoom_out)
-      gtk_widget_set_sensitive (prefs_win.preview_fit_only_zoom_out,
-                                config_changed->preview_fit_image_to_frame);
    if (prefs_win.preview_scale_spin)
       gtk_widget_set_sensitive (prefs_win.preview_scale_spin,
-                                !config_changed->preview_fit_image_to_frame);
+                                config_changed->preview_zoom == 0 ||
+                                config_changed->preview_zoom == 1);
 }
 
 
@@ -345,24 +348,24 @@ cb_save_thumbwin_state (GtkWidget *toggle)
 static void
 cb_default_disp_mode (GtkWidget *widget)
 {
-   gchar *tmpstr;
+   const gchar *tmpstr;
    gint disp_mode;
 
    disp_mode = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "num"));
-   tmpstr = thumbview_num_to_label (disp_mode);
+   tmpstr = gimv_thumb_view_num_to_label (disp_mode);
    if (tmpstr)
-      config_changed->thumbwin_disp_mode = tmpstr;
+      config_changed->thumbwin_disp_mode = (gchar *) tmpstr;
    else
-      config_changed->thumbwin_disp_mode = DEFAULT_DISP_MODE;
+      config_changed->thumbwin_disp_mode = GIMV_THUMB_VIEW_DEFAULT_SUMMARY_MODE;
 }
 
 
 static void
-cb_fit_image_to_frame (GtkWidget *toggle)
+cb_zoom_menu (GtkWidget *menu)
 {
-   config_changed->preview_fit_image_to_frame =
-      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(toggle));
-   set_sensitive_preview ();
+   config_changed->preview_zoom =
+      GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(menu), "num"));
+   set_sensitive_preview();
 }
 
 
@@ -758,14 +761,12 @@ prefs_thumbview_page (void)
    hbox = gtk_hbox_new (FALSE, 0);
    gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
 
-   disp_mode_labels = thumbview_get_disp_mode_labels (&num);
+   disp_mode_labels = gimv_thumb_view_get_summary_mode_labels (&num);
 
    label = gtk_label_new (_("Default display mode"));
    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 5);
 
-   disp_mode = thumbview_label_to_num (conf.thumbwin_disp_mode);
-   if (disp_mode < 0)
-      disp_mode = DEFAULT_DISP_MODE_NUM;
+   disp_mode = gimv_thumb_view_label_to_num (conf.thumbwin_disp_mode);
    option_menu = create_option_menu ((const gchar **)disp_mode_labels,
                                      disp_mode,
                                      cb_default_disp_mode,
@@ -1007,8 +1008,8 @@ prefs_dirview_mouse_page (void)
 GtkWidget *
 prefs_preview_page (void)
 {
-   GtkWidget *main_vbox, *frame, *vbox, *hbox;
-   GtkWidget *spinner, *toggle, *label;
+   GtkWidget *main_vbox, *frame, *vbox, *hbox, *table, *alignment;
+   GtkWidget *spinner, *toggle, *label, *option_menu;
    GtkAdjustment *adj;
 
    main_vbox = gtk_vbox_new (FALSE, 0);
@@ -1022,22 +1023,47 @@ prefs_preview_page (void)
     **********************************************/
    gimv_prefs_ui_create_frame (_("Image"), frame, vbox, main_vbox, FALSE);
 
-   /* Auto resize image to window size */
-   toggle = gtkutil_create_check_button (_("Auto resize to frame size when open image"),
-                                         conf.preview_fit_image_to_frame,
-                                         cb_fit_image_to_frame, NULL);
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
 
-   /* Zoom out only */
-   toggle = gtkutil_create_check_button (_("Do not zoom in when fit to window automatically."),
-                                         conf.preview_fit_image_zoom_out_only,
-                                         gtkutil_get_data_from_toggle_cb,
-                                         &config_changed->preview_fit_image_zoom_out_only);
-   prefs_win.preview_fit_only_zoom_out = toggle;
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+   table = gtk_table_new (2, 2, FALSE);
+   gtk_container_add (GTK_CONTAINER (alignment), table);
+
+   /* Zoom menu */
+   label = gtk_label_new (_("Zoom:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu (zoom_menu_items,
+                                     conf.preview_zoom,
+                                     cb_zoom_menu, NULL);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   /* Rotate menu */
+   label = gtk_label_new (_("Rotation:"));
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+
+   option_menu = create_option_menu_simple (rotate_menu_items,
+                                            conf.preview_rotation,
+                                            &config_changed->preview_rotation);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), option_menu);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+#if 0
+   gtk_box_pack_start (GTK_BOX (hbox), option_menu, FALSE, FALSE, 0);
+#endif
 
    /* Keep Aspect Ratio */
-   toggle = gtkutil_create_check_button (_("Keep aspect rario"),
+   toggle = gtkutil_create_check_button (_("Keep aspect ratio"),
                                          conf.preview_keep_aspect,
                                          gtkutil_get_data_from_toggle_cb,
                                          &config_changed->preview_keep_aspect);
@@ -1054,7 +1080,7 @@ prefs_preview_page (void)
    prefs_win.preview_scale_spin = spinner = gtkutil_create_spin_button (adj);
    gtk_widget_set_usize(spinner, 50, -1);
    gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-                       GTK_SIGNAL_FUNC (gtkutil_get_data_from_adjustment_by_int_cb),
+                       GTK_SIGNAL_FUNC (gtkutil_get_data_from_adjustment_by_float_cb),
                        &config_changed->preview_scale);
    gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
    label = gtk_label_new (_("%"));
@@ -1075,15 +1101,6 @@ prefs_preview_page (void)
                                          &config_changed->preview_buffer);
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 
-#ifdef ENABLE_EXIF
-   /* enable or disable automatic rotation by exif data */
-   toggle = gtkutil_create_check_button (_("Automatic rotation by EXIF data"),
-                                         conf.preview_auto_rotation,
-                                         gtkutil_get_data_from_toggle_cb,
-                                         &config_changed->preview_auto_rotation);
-   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-#endif /* ENABLE_EXIF */
-
    set_sensitive_preview  ();
 
    gtk_widget_show_all (main_vbox);
@@ -1159,9 +1176,9 @@ prefs_ui_thumbwin_tab_apply (GimvPrefsWinAction action)
    }
 
    /* tab label */
-   for (node = thumbview_get_list(); node; node = g_list_next (node)) {
-      ThumbView *tv = node->data;
-      thumbview_reset_tab_label (tv, NULL);
+   for (node = gimv_thumb_view_get_list(); node; node = g_list_next (node)) {
+      GimvThumbView *tv = node->data;
+      gimv_thumb_view_reset_tab_label (tv, NULL);
    }
 
    return FALSE;
@@ -1223,15 +1240,18 @@ prefs_ui_preview_apply (GimvPrefsWinAction action)
       tw = node->data;
 
       if (tw->iv) {
-         if (!dest->preview_fit_image_to_frame) {
+         if (dest->preview_zoom == 0) {
             gtk_object_set (GTK_OBJECT (tw->iv),
                             "x_scale", dest->preview_scale,
                             "y_scale", dest->preview_scale,
                             NULL);
          }
          gtk_object_set (GTK_OBJECT (tw->iv),
-                         "fit_when_change",   dest->preview_fit_image_to_frame,
-                         "fit_zoom_out_only", dest->preview_fit_image_zoom_out_only,
+                         "default_zoom",       dest->preview_zoom,
+                         "default_rotation",   dest->preview_rotation,
+                         "keep_aspect",        dest->preview_keep_aspect,
+                         "keep_buffer",        dest->preview_buffer,
+                         "show_scrollbar",     dest->preview_scrollbar,
                          NULL);
       }
    }
