@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: thumbnail_view_album.c,v 1.4 2003/06/18 09:26:56 makeinu Exp $
+ * $Id: thumbnail_view_album.c,v 1.16 2004/09/21 08:44:32 makeinu Exp $
  */
 
 #include <string.h>
@@ -27,12 +27,12 @@
 
 #include "dnd.h"
 #include "gimv_thumb.h"
+#include "gimv_thumb_view.h"
 #include "gimv_thumb_win.h"
 #include "gimv_zalbum.h"
 #include "gtk2-compat.h"
 #include "gtkutils.h"
 #include "prefs.h"
-#include "thumbnail_view.h"
 
 
 #define THUMBALBUM_LABEL  "Album"
@@ -40,49 +40,43 @@
 #define THUMBALBUM3_LABEL "Album 3"
 
 
-static GList     *thumbalbum_append_thumb_frames      (ThumbView      *tv,
-                                                       GList          *start,
-                                                       gchar          *dest_mode);
-static GtkWidget *thumbalbum_add_thumbnail            (GimvThumb      *thumb,
-                                                       gchar          *dest_mode,
-                                                       ThumbLoadType   type);
-static void       thumbalbum_redraw                   (ThumbView      *tv,
-                                                       gchar          *mode,
-                                                       GtkWidget      *scroll_win,
-                                                       GList         **loadlist);
-#if 0
-static GtkWidget *thumbalbum_resize                   (ThumbView      *tv);
-#endif
-static gboolean   thumbalbum_refresh_thumbnail        (GimvThumb      *thumb,
-                                                       ThumbLoadType   type);
-static void       thumbalbum_adjust                   (ThumbView      *tv,
+static void       thumbalbum_freeze                   (GimvThumbView  *tv);
+static void       thumbalbum_thaw                     (GimvThumbView  *tv);
+static void       thumbalbum_append_thumb_frame       (GimvThumbView  *tv,
+                                                       GimvThumb      *thumb,
+                                                       const gchar    *dest_mode);
+static void       thumbalbum_update_thumbnail         (GimvThumbView  *tv,
+                                                       GimvThumb      *thumb,
+                                                       const gchar    *dest_mode);
+static GList     *thumbalbum_get_load_list            (GimvThumbView  *tv);
+static void       thumbalbum_remove_thumbnail         (GimvThumbView  *tv,
                                                        GimvThumb      *thumb);
-static GtkWidget *thumbalbum_create                   (ThumbView      *tv,
-                                                       gchar          *dest_mode);
-static void       thumbalbum_remove_thumbview_data    (ThumbView      *tv);
-static gboolean   thumbalbum_set_selection            (GimvThumb      *thumb,
+static void       thumbalbum_adjust                   (GimvThumbView  *tv,
+                                                       GimvThumb      *thumb);
+static GtkWidget *thumbalbum_create                   (GimvThumbView  *tv,
+                                                       const gchar    *dest_mode);
+static gboolean   thumbalbum_set_selection            (GimvThumbView  *tv,
+                                                       GimvThumb      *thumb,
                                                        gboolean        select);
-static void       thumbalbum_set_focus                (ThumbView      *tv,
+static void       thumbalbum_set_focus                (GimvThumbView  *tv,
                                                        GimvThumb      *thumb);
-static GimvThumb *thumbalbum_get_focus                (ThumbView      *tv);
-static gboolean   thumbalbum_thumbnail_is_in_viewport (ThumbView      *tv,
+static GimvThumb *thumbalbum_get_focus                (GimvThumbView  *tv);
+static gboolean   thumbalbum_thumbnail_is_in_viewport (GimvThumbView  *tv,
                                                        GimvThumb      *thumb);
 
-ThumbViewPlugin thumbalbum_modes[] =
+GimvThumbViewPlugin thumbalbum_modes[] =
 {
    {GIMV_THUMBNAIL_VIEW_IF_VERSION,
     N_("Album"),
     0,
     thumbalbum_create,
-    thumbalbum_append_thumb_frames,
-    thumbalbum_add_thumbnail,
-    thumbalbum_refresh_thumbnail,
-    NULL,
-    thumbalbum_redraw,
-    NULL,
+    thumbalbum_freeze,
+    thumbalbum_thaw,
+    thumbalbum_append_thumb_frame,
+    thumbalbum_update_thumbnail,
+    thumbalbum_remove_thumbnail,
+    thumbalbum_get_load_list,
     thumbalbum_adjust,
-    thumbalbum_remove_thumbview_data,
-    NULL,
     thumbalbum_set_selection,
     thumbalbum_set_focus,
     thumbalbum_get_focus,
@@ -92,15 +86,13 @@ ThumbViewPlugin thumbalbum_modes[] =
     N_("Album 2"),
     10,
     thumbalbum_create,
-    thumbalbum_append_thumb_frames,
-    thumbalbum_add_thumbnail,
-    thumbalbum_refresh_thumbnail,
-    NULL,
-    thumbalbum_redraw,
-    NULL,
+    thumbalbum_freeze,
+    thumbalbum_thaw,
+    thumbalbum_append_thumb_frame,
+    thumbalbum_update_thumbnail,
+    thumbalbum_remove_thumbnail,
+    thumbalbum_get_load_list,
     thumbalbum_adjust,
-    thumbalbum_remove_thumbview_data,
-    NULL,
     thumbalbum_set_selection,
     thumbalbum_set_focus,
     thumbalbum_get_focus,
@@ -110,21 +102,20 @@ ThumbViewPlugin thumbalbum_modes[] =
     N_("Album 3"),
     20,
     thumbalbum_create,
-    thumbalbum_append_thumb_frames,
-    thumbalbum_add_thumbnail,
-    thumbalbum_refresh_thumbnail,
-    NULL,
-    thumbalbum_redraw,
-    NULL,
+    thumbalbum_freeze,
+    thumbalbum_thaw,
+    thumbalbum_append_thumb_frame,
+    thumbalbum_update_thumbnail,
+    thumbalbum_remove_thumbnail,
+    thumbalbum_get_load_list,
     thumbalbum_adjust,
-    thumbalbum_remove_thumbview_data,
-    NULL,
     thumbalbum_set_selection,
     thumbalbum_set_focus,
     thumbalbum_get_focus,
     thumbalbum_thumbnail_is_in_viewport},
 };
-gint thumbalbum_modes_num = sizeof (thumbalbum_modes) / sizeof (ThumbViewPlugin);
+gint thumbalbum_modes_num
+   = sizeof (thumbalbum_modes) / sizeof (GimvThumbViewPlugin);
 
 
 typedef struct ThumbViewData_Tag
@@ -146,25 +137,25 @@ gchar *album_create_label_str       (GimvThumb *thumb);
 static gboolean
 cb_album_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    gint row;
    GimvThumb *thumb;
    gboolean retval = event->button == 3 ? TRUE : FALSE;
 
-   g_return_val_if_fail (tv, retval);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), retval);
 
    row = gimv_zlist_cell_index_from_xy (GIMV_ZLIST (widget), event->x, event->y);
    if (row < 0) {
       gtk_drag_source_unset (widget);
       gtk_object_set_data (GTK_OBJECT (widget), "drag-unset", GINT_TO_POINTER (1));
-      gimv_thumb_win_notebook_drag_src_unset (tv->thumb_window);   /* FIXME!! */
+      gimv_thumb_win_notebook_drag_src_unset (tv->tw);   /* FIXME!! */
       return retval;
    }
 
    thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (widget), row);
    if (!thumb) return retval;
 
-   retval = thumbview_thumb_button_press_cb (widget, event, thumb);
+   retval = gimv_thumb_view_thumb_button_press_cb (widget, event, thumb);
 
    return retval;
 }
@@ -173,13 +164,13 @@ cb_album_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
 static gboolean
 cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-   ThumbView *tv = data;
+   GimvThumbView *tv = data;
    GimvThumb *thumb;
    gint row;
    gpointer dnd_unset;
    gboolean retval;
 
-   g_return_val_if_fail (tv, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
 
    dnd_unset = gtk_object_get_data (GTK_OBJECT (widget), "drag-unset");
    if (dnd_unset)
@@ -188,14 +179,14 @@ cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
 
    row = gimv_zlist_cell_index_from_xy (GIMV_ZLIST (widget), event->x, event->y);
    if (row < 0) {
-      gimv_thumb_win_notebook_drag_src_reset (tv->thumb_window);   /* FIXME!! */
+      gimv_thumb_win_notebook_drag_src_reset (tv->tw);   /* FIXME!! */
       return FALSE;
    }
 
    thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (widget), row);
    if (!thumb) return FALSE;
 
-   retval = thumbview_thumb_button_release_cb (widget, event, thumb);
+   retval = gimv_thumb_view_thumb_button_release_cb (widget, event, thumb);
 
    gtk_widget_grab_focus (widget);
    thumbalbum_set_focus (tv, thumb);
@@ -205,29 +196,29 @@ cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
 
 
 static void
-cb_select_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
+cb_select_cell (GimvZAlbum *album, gint idx, GimvThumbView *tv)
 {
    GimvThumb *thumb;
 
    g_return_if_fail (GIMV_IS_ZALBUM (album));
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
    thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (album), idx);
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
    thumb->selected = TRUE;
 }
 
 static void
-cb_unselect_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
+cb_unselect_cell (GimvZAlbum *album, gint idx, GimvThumbView *tv)
 {
    GimvThumb *thumb;
 
    g_return_if_fail (GIMV_IS_ZALBUM (album));
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
    thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (album), idx);
-   g_return_if_fail (thumb);
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
    thumb->selected = FALSE;
 }
@@ -236,16 +227,17 @@ cb_unselect_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
 static gboolean
 cb_album_key_press (GtkWidget *widget,
                     GdkEventKey *event,
-                    ThumbView *tv)
+                    GimvThumbView *tv)
 {
    GimvThumb *thumb = NULL;
 
-   g_return_val_if_fail (tv, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
 
    if (GIMV_ZLIST (widget)->focus >= 0)
-      thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (widget), GIMV_ZLIST (widget)->focus);
+      thumb = gimv_zalbum_get_cell_data (GIMV_ZALBUM (widget),
+                                         GIMV_ZLIST (widget)->focus);
 
-   if (thumbview_thumb_key_press_cb(widget, event, thumb))
+   if (gimv_thumb_view_thumb_key_press_cb(widget, event, thumb))
       return FALSE;
 
    {
@@ -255,9 +247,10 @@ cb_album_key_press (GtkWidget *widget,
       case GDK_Up:
       case GDK_Down:
          if (event->state & GDK_SHIFT_MASK) {
-            thumbview_set_selection_all (tv, FALSE);
-            thumbview_set_selection (thumb, TRUE);
-            thumbview_open_image (tv, thumb, THUMB_VIEW_OPEN_IMAGE_PREVIEW);
+            gimv_thumb_view_set_selection_all (tv, FALSE);
+            gimv_thumb_view_set_selection (thumb, TRUE);
+            gimv_thumb_view_open_image (tv, thumb,
+                                        GIMV_THUMB_VIEW_OPEN_IMAGE_PREVIEW);
          }
          return TRUE;
       case GDK_Return:
@@ -265,17 +258,18 @@ cb_album_key_press (GtkWidget *widget,
          if (event->state & GDK_SHIFT_MASK || event->state & GDK_CONTROL_MASK) {
             /* is there somteing to do? */
          } else {
-            thumbview_set_selection_all (tv, FALSE);
+            gimv_thumb_view_set_selection_all (tv, FALSE);
          }
-         thumbview_set_selection (thumb, TRUE);
-         thumbview_open_image (tv, thumb, THUMB_VIEW_OPEN_IMAGE_AUTO);
+         gimv_thumb_view_set_selection (thumb, TRUE);
+         gimv_thumb_view_open_image (tv, thumb,
+                                     GIMV_THUMB_VIEW_OPEN_IMAGE_AUTO);
          break;
       case GDK_space:
          if (!thumb) break;
-         thumbview_set_selection (thumb, !thumb->selected);
+         gimv_thumb_view_set_selection (thumb, !thumb->selected);
          break;
       case GDK_Delete:
-         thumbview_delete_files (tv);
+         gimv_thumb_view_delete_files (tv);
          break;
       default:
          break;
@@ -292,17 +286,18 @@ cb_album_key_press (GtkWidget *widget,
  *
  ******************************************************************************/
 static ThumbViewData *
-thumbalbum_new (ThumbView *tv)
+thumbalbum_new (GimvThumbView *tv)
 {
    ThumbViewData *tv_data;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    if (!tv_data) {
       tv_data = g_new0 (ThumbViewData, 1);
       tv_data->album = NULL;
-      g_hash_table_insert (tv->disp_mode_data, THUMBALBUM_LABEL, tv_data);
+      gtk_object_set_data_full (GTK_OBJECT (tv), THUMBALBUM_LABEL, tv_data,
+                                (GtkDestroyNotify) g_free);
    }
 
    return tv_data;
@@ -310,21 +305,58 @@ thumbalbum_new (ThumbView *tv)
 
 
 
-static gboolean
-thumbalbum_append_thumb_frame (ThumbView *tv, GimvThumb *thumb, gchar *dest_mode)
+/******************************************************************************
+ *
+ *   public functions.
+ *
+ ******************************************************************************/
+static void
+thumbalbum_freeze (GimvThumbView *tv)
+{
+   ThumbViewData *tv_data;
+
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
+   g_return_if_fail (tv_data && GIMV_IS_ZALBUM (tv_data->album));
+
+   gimv_zalbum_freeze (tv_data->album);
+}
+
+
+static void
+thumbalbum_thaw (GimvThumbView *tv)
+{
+   ThumbViewData *tv_data;
+
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
+   g_return_if_fail (tv_data && GIMV_IS_ZALBUM (tv_data->album));
+
+   gimv_zalbum_thawn (tv_data->album);
+}
+
+
+static void
+thumbalbum_append_thumb_frame (GimvThumbView *tv, GimvThumb *thumb,
+                               const gchar *dest_mode)
 {
    ThumbViewData *tv_data;
    const gchar *filename;
    gchar *label;
    GdkPixmap *pixmap = NULL;
    GdkBitmap *mask = NULL;
+   gint pos;
    guint idx;
 
-   g_return_val_if_fail (tv, FALSE);
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
-   g_return_val_if_fail (tv_data, FALSE);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
+   g_return_if_fail (tv_data);
+
+   pos = g_list_index (tv->thumblist, thumb);
 
    filename = g_basename(gimv_image_info_get_path (thumb->info));
 
@@ -334,93 +366,40 @@ thumbalbum_append_thumb_frame (ThumbView *tv, GimvThumb *thumb, gchar *dest_mode
       label = gimv_filename_to_internal (filename);
    }
 
-   idx = gimv_zalbum_add (GIMV_ZALBUM (tv_data->album), label);
+   idx = gimv_zalbum_insert (GIMV_ZALBUM (tv_data->album), pos, label);
    g_free (label);
 
-   gimv_zalbum_set_cell_data (GIMV_ZALBUM (tv_data->album), idx, (gpointer) thumb);
+   gimv_zalbum_set_cell_data (GIMV_ZALBUM (tv_data->album), idx, thumb);
 
-   thumbalbum_set_selection (thumb, thumb->selected);
+   thumbalbum_set_selection (tv, thumb, thumb->selected);
 
    if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
       gimv_thumb_get_icon (thumb, &pixmap, &mask);
    } else {
       gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
-   if (!pixmap) return FALSE;
 
-   gimv_zalbum_set_pixmap (GIMV_ZALBUM (tv_data->album), idx, pixmap, mask);
-
-   return TRUE;
+   if (pixmap)
+      gimv_zalbum_set_pixmap (GIMV_ZALBUM (tv_data->album), idx, pixmap, mask);
 }
 
 
-/******************************************************************************
- *
- *   public functions.
- *
- ******************************************************************************/
 static void
-thumbalbum_remove_thumbview_data (ThumbView *tv)
+thumbalbum_update_thumbnail (GimvThumbView *tv, GimvThumb *thumb,
+                             const gchar *dest_mode)
 {
    ThumbViewData *tv_data;
-
-   if (!tv) return;
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
-   if (!tv_data) return;
-
-   g_hash_table_remove (tv->disp_mode_data, THUMBALBUM_LABEL); 
-   g_free (tv_data);
-}
-
-
-static GList *
-thumbalbum_append_thumb_frames (ThumbView *tv,
-                                 GList *start,
-                                 gchar *dest_mode)
-{
-   GList *node, *loadlist = NULL;
-   gboolean thumb_loaded;
-
-   g_return_val_if_fail (tv, FALSE);
-
-   node = start;
-   while (node) {
-      GimvThumb  *thumb = node->data;
-
-      thumb_loaded = thumbalbum_append_thumb_frame (tv, thumb, dest_mode);
-      if (!thumb_loaded)
-         loadlist = g_list_append (loadlist, thumb);
-
-      node = g_list_next (node);
-   }
-
-   return loadlist;
-}
-
-
-static GtkWidget *
-thumbalbum_add_thumbnail (GimvThumb *thumb,
-                           gchar *dest_mode,
-                           ThumbLoadType type)
-{
-   ThumbView *tv;
-   ThumbViewData *tv_data;
    GdkPixmap *pixmap = NULL;
    GdkBitmap *mask = NULL;
-   GList *node;
    gint pos;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, NULL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
+   g_return_if_fail (tv_data && tv_data->album);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
-   g_return_val_if_fail (tv_data && tv_data->album, NULL);
-
-   node = g_list_find (tv->thumblist, thumb);
-   pos = g_list_position (tv->thumblist, node);
+   pos = g_list_index (tv->thumblist, thumb);
 
    /* set thumbnail */
    if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
@@ -430,118 +409,68 @@ thumbalbum_add_thumbnail (GimvThumb *thumb,
    }
    if (pixmap)
       gimv_zalbum_set_pixmap (GIMV_ZALBUM (tv_data->album), pos, pixmap, mask);
-
-   return NULL;
 }
 
 
-static void
-thumbalbum_redraw (ThumbView *tv, gchar *dest_mode,
-                    GtkWidget *scroll_win, GList **loadlist)
+static GList *
+thumbalbum_get_load_list (GimvThumbView *tv)
 {
-   ThumbViewData *tv_data;
-   GList *node;
+   GList *loadlist = NULL, *node;
 
-   g_return_if_fail (tv);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   node = g_list_find (thumbview_get_list(), tv);
-   if (!node) return;
-
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
-   if (!tv_data)
-      tv_data = thumbalbum_new (tv);
-
-   if (scroll_win) {
-      if (GTK_BIN (tv->container)->child)
-         gtk_widget_destroy (GTK_BIN (tv->container)->child);   
-      tv_data->album = thumbalbum_create (tv, dest_mode);
-      gtk_container_add (GTK_CONTAINER (scroll_win), tv_data->album);
-   }
-
-   if (!loadlist) return;
-
-   /* create thumbnail load list */
-   *loadlist = NULL;
-   node = tv->thumblist;
-   while (node) {
+   for (node = tv->thumblist; node; node = g_list_next (node)) {
       GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
-      if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
+      if (!strcmp (THUMBALBUM2_LABEL, tv->summary_mode)) {
          gimv_thumb_get_icon (thumb, &pixmap, &mask);
       } else {
          gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       }
       if (!pixmap)
-         *loadlist = g_list_append (*loadlist, thumb);
-
-      node = g_list_next (node);
+         loadlist = g_list_append (loadlist, thumb);
    }
+
+   return loadlist;
 }
 
 
-#if 0
-static GtkWidget *
-thumbalbum_resize (ThumbView *tv)
+static void
+thumbalbum_remove_thumbnail (GimvThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
-   GList *node;
+   gint pos;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
+   g_return_if_fail (GIMV_IS_THUMB (thumb));
 
-   node = g_list_find (thumbview_get_list(), tv);
-   if (!node) return NULL;
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
+   g_return_if_fail (tv_data && tv_data->album);
 
-   thumbalbum_redraw (tv, tv->disp_mode, tv->container, NULL);;
+   pos = g_list_index (tv->thumblist, thumb);
+   g_return_if_fail (pos >= 0);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
-   g_return_val_if_fail (tv_data, NULL);
-
-   return tv_data->album;
-}
-#endif
-
-
-gboolean
-thumbalbum_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
-{
-   GtkWidget *widget;
-   ThumbView *tv;
-
-   if (!thumb) return FALSE;
-
-   tv = thumb->thumb_view;
-   if (!tv) return FALSE;
-
-   widget = thumbalbum_add_thumbnail (thumb, tv->disp_mode, type);
-
-   if (widget)
-      return TRUE;
-   else
-      return FALSE;
+   gimv_zalbum_remove (GIMV_ZALBUM (tv_data->album), pos);
 }
 
 
 static gboolean
-thumbalbum_set_selection (GimvThumb *thumb, gboolean select)
+thumbalbum_set_selection (GimvThumbView *tv, GimvThumb *thumb, gboolean select)
 {
-   ThumbView *tv;
    ThumbViewData *tv_data;
-   GList *node;
    gint pos;
 
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv = thumb->thumb_view;
-   g_return_val_if_fail (tv, FALSE);
    if (g_list_length (tv->thumblist) < 1) return FALSE;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    g_return_val_if_fail (tv_data && tv_data->album, FALSE);
 
-   node = g_list_find (tv->thumblist, thumb);
-   pos = g_list_position (tv->thumblist, node);
+   pos = g_list_index (tv->thumblist, thumb);
 
    if (pos >= 0) {
       thumb->selected = select;
@@ -556,14 +485,14 @@ thumbalbum_set_selection (GimvThumb *thumb, gboolean select)
 
 
 static void
-thumbalbum_set_focus (ThumbView *tv, GimvThumb *thumb)
+thumbalbum_set_focus (GimvThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    gint pos;
 
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    g_return_if_fail (tv_data && tv_data->album);
 
    pos = g_list_index (tv->thumblist, thumb);
@@ -576,15 +505,15 @@ thumbalbum_set_focus (ThumbView *tv, GimvThumb *thumb)
 
 
 static GimvThumb *
-thumbalbum_get_focus (ThumbView *tv)
+thumbalbum_get_focus (GimvThumbView *tv)
 {
    ThumbViewData *tv_data;
    gint pos;
    GList *node;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    g_return_val_if_fail (tv_data && tv_data->album, NULL);
 
    pos = GIMV_ZLIST (tv_data->album)->focus;
@@ -599,7 +528,7 @@ thumbalbum_get_focus (ThumbView *tv)
 
 
 static gboolean
-thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
+thumbalbum_thumbnail_is_in_viewport (GimvThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    GList *node;
@@ -607,10 +536,10 @@ thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
    gboolean success;
    GdkRectangle area, cell_area, intersect_area;
 
-   g_return_val_if_fail (tv, FALSE);
-   g_return_val_if_fail (thumb, FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), FALSE);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), FALSE);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
    node = g_list_find (tv->thumblist, thumb);
@@ -632,23 +561,21 @@ thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 
 
 static void
-thumbalbum_adjust (ThumbView *tv, GimvThumb *thumb)
+thumbalbum_adjust (GimvThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    GList *node;
    gint pos;
 
-   g_return_if_fail (tv);
+   g_return_if_fail (GIMV_IS_THUMB_VIEW (tv));
 
-   node = g_list_find (thumbview_get_list(), tv);
+   node = g_list_find (gimv_thumb_view_get_list(), tv);
    if (!node) return;
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    g_return_if_fail (tv_data);
 
-   node = g_list_find (tv->thumblist, thumb);
-   if (!node) return;
-   pos = g_list_position (tv->thumblist, node);
+   pos = g_list_index (tv->thumblist, thumb);
 
    gimv_zlist_moveto (GIMV_ZLIST (tv_data->album), pos);
 
@@ -657,13 +584,13 @@ thumbalbum_adjust (ThumbView *tv, GimvThumb *thumb)
 
 
 static GtkWidget *
-thumbalbum_create (ThumbView *tv, gchar *dest_mode)
+thumbalbum_create (GimvThumbView *tv, const gchar *dest_mode)
 {
    ThumbViewData *tv_data;
 
-   g_return_val_if_fail (tv, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB_VIEW (tv), NULL);
 
-   tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
+   tv_data = gtk_object_get_data (GTK_OBJECT (tv), THUMBALBUM_LABEL);
    if (!tv_data) {
       tv_data = thumbalbum_new (tv);
       g_return_val_if_fail (tv_data, NULL);
@@ -686,13 +613,13 @@ thumbalbum_create (ThumbView *tv, gchar *dest_mode)
       gimv_zalbum_set_label_position (GIMV_ZALBUM (tv_data->album),
                                       GIMV_ZALBUM_CELL_LABEL_RIGHT);
       gimv_zalbum_set_min_pixmap_size (GIMV_ZALBUM (tv_data->album),
-                                       tv->ThumbnailSize,
-                                       tv->ThumbnailSize);
+                                       tv->thumb_size,
+                                       tv->thumb_size);
    } else {
       gtk_widget_set_name (tv_data->album, "Thumbnail2Mode");
       gimv_zalbum_set_min_pixmap_size (GIMV_ZALBUM (tv_data->album),
-                                       tv->ThumbnailSize,
-                                       tv->ThumbnailSize);
+                                       tv->thumb_size,
+                                       tv->thumb_size);
    }
 
    gimv_scrolled_set_auto_scroll (GIMV_SCROLLED (tv_data->album),
@@ -737,19 +664,27 @@ thumbalbum_create (ThumbView *tv, gchar *dest_mode)
    gtk_object_set_data (GTK_OBJECT (tv_data->album), "gimv-tab", tv);
 
    gtk_signal_connect_after (GTK_OBJECT (tv_data->album), "drag_begin",
-                             GTK_SIGNAL_FUNC (thumbview_drag_begin_cb), tv);
+                             GTK_SIGNAL_FUNC (gimv_thumb_view_drag_begin_cb),
+                             tv);
    gtk_signal_connect_after (GTK_OBJECT (tv_data->album), "drag_data_get",
-                             GTK_SIGNAL_FUNC (thumbview_drag_data_get_cb), tv);
+                             GTK_SIGNAL_FUNC (gimv_thumb_view_drag_data_get_cb),
+                             tv);
    gtk_signal_connect_after (GTK_OBJECT (tv_data->album), "drag_data_received",
-                             GTK_SIGNAL_FUNC (thumbview_drag_data_received_cb), tv);
+                             GTK_SIGNAL_FUNC (gimv_thumb_view_drag_data_received_cb),
+                             tv);
    gtk_signal_connect_after (GTK_OBJECT (tv_data->album), "drag-data-delete",
-                             GTK_SIGNAL_FUNC (thumbview_drag_data_delete_cb), tv);
+                             GTK_SIGNAL_FUNC (gimv_thumb_view_drag_data_delete_cb),
+                             tv);
    gtk_signal_connect_after (GTK_OBJECT (tv_data->album), "drag_end",
-                             GTK_SIGNAL_FUNC (thumbview_drag_end_cb), tv);
+                             GTK_SIGNAL_FUNC (gimv_thumb_view_drag_end_cb), tv);
 
    /* append thumbnail frames */
    if (tv->thumblist) {
-      thumbalbum_append_thumb_frames (tv, tv->thumblist, dest_mode);
+      GList *node;
+
+      for (node = tv->thumblist; node; node = g_list_next (node))
+         thumbalbum_append_thumb_frame (tv, node->data, dest_mode);
+
       gimv_zlist_cell_set_focus (GIMV_ZLIST (tv_data->album), 0);
    }
 
@@ -771,7 +706,7 @@ label_filename (GimvThumb *thumb)
    gchar *tmpstr;
    gchar buf[BUF_SIZE];
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    filename = g_basename(gimv_image_info_get_path (thumb->info));
 
@@ -793,7 +728,7 @@ label_size (GimvThumb *thumb)
 {
    gchar *size_str, buf[BUF_SIZE];
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    size_str = fileutil_size2str (thumb->info->st.st_size, FALSE);
    if (show_data_title)
@@ -811,7 +746,7 @@ label_mtime (GimvThumb *thumb)
 {
    gchar *time_str, *str;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    time_str = fileutil_time2str (thumb->info->st.st_mtime);
    if (show_data_title)
@@ -830,7 +765,7 @@ label_image_type (GimvThumb *thumb)
    gchar buf[BUF_SIZE];
    const gchar *filename;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    filename = gimv_image_info_get_path (thumb->info);
    if (show_data_title)
@@ -865,7 +800,7 @@ album_create_label_str (GimvThumb *thumb)
    GList *node;
    gchar *label;
 
-   g_return_val_if_fail (thumb, NULL);
+   g_return_val_if_fail (GIMV_IS_THUMB (thumb), NULL);
 
    /* create icon label string */
    node = album_title_idx_list;
@@ -889,7 +824,7 @@ album_create_label_str (GimvThumb *thumb)
 
    return label;
 }
-gint
+static gint
 album_get_title_idx (const gchar *title)
 {
    gint i;
